@@ -30,7 +30,6 @@
 
 
 #include <xercesc/framework/MemBufInputSource.hpp>
-#include <xercesc/util/PlatformUtils.hpp>
 
 
 
@@ -82,38 +81,27 @@ class XPathWrapperImpl
 {
 public:
 
-	XPathWrapper::CharVectorTypeVectorType
+    typedef XPathWrapper::CharVectorTypeVectorType  CharVectorTypeVectorType;
+
+    void
 	evaluate(
 		const char*		xml,
 		const char*		context, 
 		const char*		expr,
-		ostream&		errorStream)
+		ostream&		errorStream,
+        CharVectorTypeVectorType& theResultList)
 	{
 #if defined(XALAN_STRICT_ANSI_HEADERS)
 		using std::strlen;
 #endif
 
-		XALAN_USING_XERCES(XMLPlatformUtils)
-		XALAN_USING_XERCES(XMLException)
-
-		//initialize Xerces...
-		try
-		{
-			XMLPlatformUtils::Initialize();
-		}
-		catch(const XMLException&)
-		{
-			errorStream << "XMLPlatformUtils::Initialize() failed!" << endl;
-
-			throw;
-		}
-
-		XPathWrapper::CharVectorTypeVectorType	theResultList;
 
 		{
 			// Just hoist everything...
 			XALAN_CPP_NAMESPACE_USE
 
+            typedef XPathConstructionContext::GetAndReleaseCachedString     GetAndReleaseCachedString;
+
 			// Initialize the XPath subsystem...
 			XPathInit						theInit;
 
@@ -126,6 +114,8 @@ public:
 
 			XalanElement*	rootElem = 0;
 
+            XALAN_USING_XERCES(XMLException)
+
 			try
 			{
 				XALAN_USING_XERCES(MemBufInputSource)
@@ -159,15 +149,25 @@ public:
 				// first get the context nodeset
 				XPath* const	contextXPath = theXPathFactory.create();
 
-				theXPathProcessor.initXPath(*contextXPath,
-											theXPathConstructionContext,
-											XalanDOMString(context),
-											ElementPrefixResolverProxy(rootElem, theEnvSupport, theDOMSupport));
+                const ElementPrefixResolverProxy    thePrefixResolver(rootElem, theEnvSupport, theDOMSupport);
+
+                const GetAndReleaseCachedString     theGuard(theXPathConstructionContext);
+
+                XalanDOMString&     theString = theGuard.get();
+
+                theString = context;
+
+				theXPathProcessor.initXPath(
+                    *contextXPath,
+					theXPathConstructionContext,
+					theString,
+					thePrefixResolver);
 
 	   			XObjectPtr	xObj =
-					contextXPath->execute(rootElem,
-										  ElementPrefixResolverProxy(rootElem, theEnvSupport, theDOMSupport),
-										  theExecutionContext);
+					contextXPath->execute(
+                        rootElem,
+						thePrefixResolver,
+						theExecutionContext);
 
 				const NodeRefListBase&	contextNodeList = xObj->nodeset();
 
@@ -199,14 +199,19 @@ public:
 
 					// and now get the result of the primary xpath expression
 					XPath* const	xpath = theXPathFactory.create();
-					theXPathProcessor.initXPath(*xpath,
-												theXPathConstructionContext,
-												TranscodeFromLocalCodePage(expr),
-												ElementPrefixResolverProxy(rootElem, theEnvSupport, theDOMSupport));
 
-					xObj = xpath->execute(contextNodeList.item(0),
-										  ElementPrefixResolverProxy(rootElem, theEnvSupport, theDOMSupport),
-										  theExecutionContext);
+                    theString = expr;
+
+					theXPathProcessor.initXPath(
+                        *xpath,
+						theXPathConstructionContext,
+						theString,
+						thePrefixResolver);
+
+					xObj = xpath->execute(
+                        contextNodeList.item(0),
+						thePrefixResolver,
+						theExecutionContext);
 
 					// now encode the results.  For all types but nodelist, we'll just convert it to a string
 					// but, for nodelist, we'll convert each node to a string and return a list of them
@@ -254,11 +259,7 @@ public:
 				throw;
 			}
 
-			// Shut down Xerces...
-			XMLPlatformUtils::Terminate();
 		}
-
-		return theResultList;
 	}
 };
 
@@ -281,17 +282,19 @@ XPathWrapper::~XPathWrapper()
 
 
 
-XPathWrapper::CharVectorTypeVectorType
+void
 XPathWrapper::evaluate(
 		const char*		xml, 
 		const char*		context, 
-		const char*		path)
+		const char*		path,
+        CharVectorTypeVectorType& theResult)
 {
-	return pImpl->evaluate(
+	pImpl->evaluate(
 			xml,
 			context,
 			path,
-			cerr);
+			cerr,
+            theResult);
 }
 
 
