@@ -27,7 +27,6 @@
 
 
 #include <algorithm>
-#include <vector>
 
 
 
@@ -48,7 +47,6 @@
 
 
 
-#include <xalanc/Include/XalanAutoPtr.hpp>
 #include <xalanc/Include/STLHelper.hpp>
 
 
@@ -348,7 +346,7 @@ OutputString(
 {
 	if (theString.empty() == false)
 	{
-		theStream << c_str(theString);
+		theStream.write(&*theString.begin(), theString.size());
 	}
 }
 
@@ -369,43 +367,18 @@ OutputString(XalanOutputStream&		theStream,
 XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(void)
 OutputString(
 			ostream&				theStream,
-			const XalanDOMChar*		theString)
+			const XalanDOMChar*		theString,
+            MemoryManager&          theMemoryManager)
 {
-	OutputString(theStream, TranscodeToLocalCodePage(theString));
+    CharVectorType  theVector(theMemoryManager);
+
+    TranscodeToLocalCodePage(theString, theVector, false, '?');
+
+	OutputString(theStream, theVector);
 }
 
 
 
-XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString)
-substring(
-			const XalanDOMChar*			theString,
-			XalanDOMString::size_type	theStartIndex,
-			XalanDOMString::size_type	theEndIndex)
-{
-	assert(theString != 0);
-
-	const XalanDOMString::size_type		theStringLength = length(theString);
-
-	// $$$ ToDo: In Java-land, any failing of this
-	// assertion would result in an exception being thrown.
-	assert(theStartIndex <= theStringLength);
-
-	if (theStartIndex == theStringLength)
-	{
-		// This is allowed, and should return an empty string.
-		return XalanDOMString();
-	}
-	else
-	{
-		const XalanDOMString::size_type		theLength = theEndIndex == XalanDOMString::npos ? theStringLength - theStartIndex :
-													theEndIndex - theStartIndex;
-		assert(theStartIndex + theLength <= theStringLength);
-
-		return XalanDOMString(theString + theStartIndex, theLength);
-	}
-}
-
-
 
 XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString&)
 substring(
@@ -478,42 +451,6 @@ substring(
 }
 
 
-
-XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString)
-substring(
-			const XalanDOMString&		theString,
-			XalanDOMString::size_type	theStartIndex,
-			XalanDOMString::size_type	theEndIndex)
-{
-	const XalanDOMString::size_type		theStringLength = length(theString);
-
-	assert(theStartIndex <= theStringLength);
-
-	if (theStartIndex == theStringLength)
-	{
-		// This is allowed, and should return an empty string.
-		return XalanDOMString();
-	}
-	else
-	{
-		const XalanDOMString::size_type		theLength = theEndIndex == XalanDOMString::npos ? theStringLength - theStartIndex :
-													theEndIndex - theStartIndex;
-
-		if (theLength == 0)
-		{
-			return XalanDOMString();
-		}
-		else
-		{
-			assert(theStartIndex + theLength <= theStringLength);
-
-			return theString.substr(theStartIndex, theLength);
-		}
-	}
-}
-
-
-
 template <class InputIteratorType, class OutputIteratorType, class FunctionType>
 OutputIteratorType
 TransformString(
@@ -540,16 +477,15 @@ TransformString(
 
 
 template <class FunctionType>
-XalanDOMString
+XalanDOMString&
 TransformString(
 			const XalanDOMChar*			theInputString,
 			XalanDOMString::size_type	theInputStringLength,
-			FunctionType				theFunction)
+			FunctionType				theFunction,
+            XalanDOMString&             theConvertedString)
 {
 	assert(theInputString != 0);
 
-	XalanDOMString	theConvertedString;
-
 	TransformString(
 			theInputString,
 			theInputString + theInputStringLength,
@@ -562,56 +498,113 @@ TransformString(
 
 
 template <class FunctionType>
-XalanDOMString
+XalanDOMString&
 TransformXalanDOMString(
 			const XalanDOMString&	theInputString,
-			FunctionType			theFunction)
+			FunctionType			theFunction,
+            XalanDOMString&         theResult)
 {
 	const XalanDOMString::size_type		theStringLength = length(theInputString);
 
 	if (theStringLength == 0)
 	{
-		return theInputString;
+        theResult = theInputString;
 	}
 	else
 	{
 		const XalanDOMChar* const	theBuffer = c_wstr(theInputString);
 		assert(theBuffer != 0);
 
-		return TransformString(theBuffer, theStringLength, theFunction);
+        TransformString(theBuffer, theStringLength, theFunction, theResult);	
 	}
+
+    return theResult;
 }
 
 
 
-XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString)
-toLowerCaseASCII(const XalanDOMChar*	theString)
+template <class FunctionType>
+XalanDOMString&
+TransformString(
+			FunctionType		theFunction,
+            XalanDOMString&     theString)
 {
-	return TransformString(theString, length(theString), toLowerASCII);
+	TransformString(
+			theString.begin(),
+			theString.end(),
+			theString.begin(),
+			theFunction);
+
+	return theString;
 }
 
 
 
-XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString)
-toLowerCaseASCII(const XalanDOMString&	theString)
+XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString&)
+toLowerCaseASCII(
+            const XalanDOMChar*     theString,
+            XalanDOMString&         theResult)
 {
-	return TransformXalanDOMString(theString, toLowerASCII);
+    TransformString(theString, length(theString), toLowerASCII, theResult);
+
+	return theResult;
 }
 
 
 
-XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString)
-toUpperCaseASCII(const XalanDOMChar*	theString)
+XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString&)
+toLowerCaseASCII(
+            const XalanDOMString&	theString,
+            XalanDOMString&         theResult)
 {
-	return TransformString(theString, length(theString), toUpperASCII);
+    TransformXalanDOMString(theString, toLowerASCII, theResult);
+
+	return theResult;
 }
 
 
 
-XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString)
-toUpperCaseASCII(const XalanDOMString&	theString)
+XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString&)
+toLowerCaseASCII(XalanDOMString&    theString)
 {
-	return TransformXalanDOMString(theString, toUpperASCII);
+    TransformString(toLowerASCII, theString);
+
+	return theString;
+}
+
+
+
+
+XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString&)
+toUpperCaseASCII(
+            const XalanDOMChar*     theString,
+            XalanDOMString&         theResult)
+{
+    TransformString(theString, length(theString), toUpperASCII, theResult);
+
+	return theResult;
+}
+
+
+
+XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString&)
+toUpperCaseASCII(
+            const XalanDOMString&	theString,
+            XalanDOMString&         theResult)
+{
+    TransformXalanDOMString(theString, toUpperASCII, theResult);
+
+	return theResult;
+}
+
+
+
+XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString&)
+toUpperCaseASCII(XalanDOMString&    theString)
+{
+    TransformString(toUpperASCII, theString);
+
+	return theString;
 }
 
 
@@ -922,15 +915,14 @@ equalsIgnoreCaseASCII(
 
 
 
-XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMCharVectorType)
+XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMCharVectorType&)
 MakeXalanDOMCharVector(
 			const char*		data,
+            XalanDOMCharVectorType& theResult,
 			bool			fTranscode)
 {
 	assert(data != 0);
 
-	XalanDOMCharVectorType	theResult;
-
 	if (fTranscode == true)
 	{
 		// Create a vector which includes the terminating 0.
@@ -958,15 +950,19 @@ MakeXalanDOMCharVector(
 
 
 
-XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMCharVectorType)
-MakeXalanDOMCharVector(const XalanDOMChar*	data)
+XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMCharVectorType&)
+MakeXalanDOMCharVector(const XalanDOMChar*	data,
+                       XalanDOMCharVectorType& theResult)
 {
 	assert(data != 0);
 
 	const XalanDOMString::size_type		theLength = length(data);
 
+    XalanDOMCharVectorType tmpVector(data, data + theLength + 1,theResult.getMemoryManager());
+
+    theResult.swap(tmpVector);
 	// Create a vector which includes the terminating 0.
-	return XalanDOMCharVectorType(data, data + theLength + 1);
+	return theResult;
 }
 
 
@@ -1091,18 +1087,23 @@ WideStringToUnsignedLong(const XalanDOMChar*	theString)
 
 
 XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(double)
-WideStringToDouble(const XalanDOMChar*	theString)
+WideStringToDouble(const XalanDOMChar*	theString,
+                   MemoryManagerType&   theManager)
 {
-	return DoubleSupport::toDouble(theString);
+	return DoubleSupport::toDouble(theString, theManager);
 }
 
 
 
-XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString)
-trim(const XalanDOMString&	theString)
+XALAN_PLATFORMSUPPORT_EXPORT_FUNCTION(XalanDOMString&)
+trim(const XalanDOMString&	theString,
+     XalanDOMString& theResult)
 {
 	if (isEmpty(theString))
-		return theString;
+    {
+        theResult.erase();
+		return theResult;
+    }
 
 	const XalanDOMString::size_type		strLen = length(theString);
 	assert(strLen > 0);
@@ -1121,7 +1122,9 @@ trim(const XalanDOMString&	theString)
 		if (!isXMLWhitespace(charAt(theString, trailingSpace)))
 			break;
 
-	return substring(theString, leadingSpace, trailingSpace +1);
+    substring(theString, theResult, leadingSpace, trailingSpace +1);
+
+	return theResult;
 }
 
 
@@ -1821,5 +1824,4 @@ isXMLWhitespace(
 }
 
 
-
 XALAN_CPP_NAMESPACE_END
