@@ -18,6 +18,7 @@
 
 
 
+#include "DoubleSupport.hpp"
 #include "XalanMessageLoader.hpp"
 #include "XalanTranscodingServices.hpp"
 
@@ -27,41 +28,43 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 
-unsigned long	PlatformSupportInit::s_initCounter = 0;
+unsigned long   PlatformSupportInit::s_initCounter = 0;
 
 
 
-PlatformSupportInit::PlatformSupportInit() :
-	m_xalanDOMInit()
+PlatformSupportInit::PlatformSupportInit(MemoryManagerType&      theManager) :
+    m_xalanDOMInit(theManager)
 {
-	++s_initCounter;
+    ++s_initCounter;
 
-	if (s_initCounter == 1)
-	{
-		initialize();
-	}
+    if (s_initCounter == 1)
+    {
+        initialize(theManager);
+    }
 }
 
 
 
 PlatformSupportInit::~PlatformSupportInit()
 {
-	--s_initCounter;
+    --s_initCounter;
 
-	if (s_initCounter == 0)
-	{
-		terminate();
-	}
+    if (s_initCounter == 0)
+    {
+        terminate();
+    }
 }
 
 
 
 void
-PlatformSupportInit::initialize()
+PlatformSupportInit::initialize(MemoryManagerType&      theManager)
 {
-	XalanMessageLoader::createLoader();
+    DoubleSupport::initialize();
 
-	XalanTranscodingServices::initialize();
+    XalanMessageLoader::initialize(theManager);
+
+    XalanTranscodingServices::initialize(theManager);
 }
 
 
@@ -69,9 +72,11 @@ PlatformSupportInit::initialize()
 void
 PlatformSupportInit::terminate()
 {
-	XalanTranscodingServices::terminate();
+    XalanTranscodingServices::terminate();
 
-	XalanMessageLoader::destroyLoader();
+    XalanMessageLoader::terminate();
+
+    DoubleSupport::terminate();
 }
 
 
