@@ -27,14 +27,14 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 // Pre-constructed masks for bit twiddling.  Update these if not using chars for storing the bits.
-static const int	theSetMasks[XalanBitmap::eBitsPerUnit] = { 1, 2, 4, 8, 16, 32, 64, 128 };
-static const int	theClearMasks[XalanBitmap::eBitsPerUnit] = { ~1, ~2, ~4, ~8, ~16, ~32, ~64, ~128 };
+const int	XalanBitmap::s_setMasks[XalanBitmap::eBitsPerUnit] = { 1, 2, 4, 8, 16, 32, 64, 128 };
+const int	XalanBitmap::s_clearMasks[XalanBitmap::eBitsPerUnit] = { ~1, ~2, ~4, ~8, ~16, ~32, ~64, ~128 };
 
 
 
-XalanBitmap::XalanBitmap(size_type	theSize) :
+XalanBitmap::XalanBitmap(MemoryManagerType& theManager, size_type	theSize) :
 	m_size(theSize),
-	m_bitmap(size_type((theSize + eBitsPerUnit) / eBitsPerUnit), BitmapVectorType::value_type(0))
+	m_bitmap(size_type((theSize + eBitsPerUnit) / eBitsPerUnit), BitmapVectorType::value_type(0), theManager)
 {
 }
 
@@ -46,58 +46,10 @@ XalanBitmap::~XalanBitmap()
 
 
 
-bool
-XalanBitmap::isSet(size_type	theBit) const
-{
-	if (theBit >= m_size)
-	{
-		return false;
-	}
-	else
-	{
-		return m_bitmap[theBit / eBitsPerUnit] & theSetMasks[theBit % eBitsPerUnit] ? true : false;
-	}
-}
-
-
-
-void
-XalanBitmap::set(size_type	theBit)
-{
-	if (theBit < m_size)
-	{
-		m_bitmap[theBit / eBitsPerUnit] |= theSetMasks[theBit % eBitsPerUnit];
-	}
-}
-
-
-
-void
-XalanBitmap::clear(size_type	theBit)
-{
-	if (theBit < m_size)
-	{
-		m_bitmap[theBit / eBitsPerUnit] &= theClearMasks[theBit % eBitsPerUnit];
-	}
-}
-
-
-
-void
-XalanBitmap::toggle(size_type	theBit)
-{
-	if (theBit < m_size)
-	{
-		m_bitmap[theBit / eBitsPerUnit] ^= theSetMasks[theBit % eBitsPerUnit];
-	}
-}
-
-
-
 void
 XalanBitmap::clearAll()
 {
-	XALAN_STD_QUALIFIER fill(m_bitmap.begin(), m_bitmap.end(), 0);
+	XALAN_STD_QUALIFIER fill(m_bitmap.begin(), m_bitmap.end(), '\0');
 }
 
 
