@@ -20,6 +20,7 @@
 
 #include <cstdio>
 #include <cstring>
+#include <algorithm>
 
 #if defined(XALAN_CLASSIC_IOSTREAMS)
 #include <iostream.h>
@@ -40,6 +41,10 @@
 
 
 
+#include <xalanc/Include/XalanVector.hpp>
+
+
+
 #include <xalanc/XalanDOM/XalanDOMException.hpp>
 
 
@@ -121,6 +126,7 @@
 //#define XALAN_USE_ICU
 #if defined(XALAN_USE_ICU)
 #include <xalanc/ICUBridge/ICUBridgeCollationCompareFunctor.hpp>
+#include <xalanc/ICUBridge/ICUBridgeCleanup.hpp>
 #endif
 
 
@@ -152,7 +158,7 @@ printArgOptions()
 		 << "TestXSLT options: "
 		 << endl
 		 << endl
-		 << "Options are not case-sensitive."
+		 << "Options are case-sensitive."
 		 << endl
 		 << endl
 		 << " [-? Shows this message.]"
@@ -161,71 +167,81 @@ printArgOptions()
 		 << " [-h Shows this message.]"
 		 << endl
 		 << endl
-		 << " [-IN inputXMLURL (If not specified, stdin is used.)]"
+		 << " [-in <source URL> (If not specified, stdin is used.)]"
 		 << endl
 		 << endl
-		 << " [-XSL XSLTransformationURL]"
+		 << " [-xsl <stylesheet URL>]"
 		 << endl
-		 << " [-OUT outputFileName]"
+		 << " [-out <output file>]"
 		 << endl
-		 << " [-V (Show version information only.)]"
+		 << " [-v  Show version information only.]"
 		 << endl
-		 << " [-QC (Quiet pattern conflicts warnings.)]"
+		 << " [-qc  Quiet pattern conflicts warnings.]"
 		 << endl
-		 << " [-Q (Use quiet mode.)]"
+		 << " [-q  Use quiet mode.]"
 		 << endl
-		 << " [-INDENT n (Controls how many spaces to indent. {default is 0})]"
+		 << " [-indent n  Controls how many spaces to indent. (default is 0)]"
 		 << endl
-		 << " [-VALIDATE (Controls whether validation occurs. Validation is off by default.)]"
+		 << " [-validate  Controls whether validation occurs. Validation is off by default.]"
 		 << endl
 		 << endl
-		 << " [-TT (Trace the templates as they are being called.)]"
+		 << " [-tt  Trace the templates as they are being called.]"
 		 << endl
-		 << " [-TG (Trace each generation event.)]"
+		 << " [-tg  Trace each generation event.]"
 		 << endl
-		 << " [-TS (Trace each selection event.)]"
+		 << " [-ts  Trace each selection event.]"
 		 << endl
-		 << " [-TTC (Trace the template children as they are being processed.)]"
+		 << " [-ttc  Trace the template children as they are being processed.]"
 		 << endl
 		 << endl
-		 << " [-XML (Use XML formatter and add XML header.)]"
+		 << " [-xml  Use XML formatter.]"
 		 << endl
-		 << " [-TEXT (Use Text formatter.)]"
+		 << " [-text  Use Text formatter.]"
 		 << endl
-		 << " [-HTML (Use HTML formatter.)]"
+		 << " [-html  Use HTML formatter.]"
 		 << endl
-		 << " [-DOM (Use DOM formatter.  Formats to DOM, then formats XML for output.)]"
+		 << " [-dom  Use DOM formatter.  Generates a DOM instance, then formats XML for output.]"
 		 << endl
-		 << " [-XST (Use source tree formatter.  Formats to Xalan source tree, then formats XML for output.)]"
+		 << " [-xst  Use source tree formatter.  Generates an instance of the default source tree, then formats XML for output.]"
 		 << endl
 		 << endl
-		 << " [-PARAM name expression (Sets a stylesheet parameter.)]"
+		 << " [-param name expression  Sets a stylesheet parameter.]"
 		 << endl
 		 << endl
-		 << " [-XD (Use Xerces DOM instead of Xalan source tree.)]"
+		 << " [-xd  Use Xerces DOM instead of Xalan source tree.]"
 		 << endl
 		 << endl
-		 << " [-DE (Disable built-in extension functions.)]"
+		 << " [-de  Disable built-in extension functions.]"
 		 << endl
-		 << "The following options are valid only with -HTML or -XML."
+		 << "The following option is valid only with -html."
 		 << endl
 		 << endl
-		 << "The following option is valid only with -HTML."
+		 << " [-noindent  Turns off HTML indenting."
 		 << endl
 		 << endl
-		 << " [-NOINDENT (Turns off HTML indenting..]"
+		 << "The following option is valid only with -xml."
 		 << endl
 		 << endl
-		 << "The following option is valid only with -XML."
-		 << endl
-		 << endl
-		 << " [-NH (Don't write XML header.)]"
+		 << " [-nh  Don't generate the XML declaration.]"
 		 << endl;
 }
 
 
 
-typedef vector<pair<const char*, const char*> >	StringPairVectorType;
+// We only need a few things from the Xerces namespace...
+XALAN_USING_XERCES(XMLPlatformUtils)
+XALAN_USING_XERCES(SAXParseException)
+XALAN_USING_XERCES(SAXException)
+XALAN_USING_XERCES(XMLException)
+
+
+
+// We need lots of things from the Xalan namespace, so hoist everything...
+XALAN_CPP_NAMESPACE_USE
+
+
+
+typedef vector<pair< const char*, const char*> >	StringPairVectorType;
 
 
 
@@ -282,19 +298,6 @@ struct CmdLineParams
 
 
 
-// We only need a few things from the Xerces namespace...
-XALAN_USING_XERCES(XMLPlatformUtils)
-XALAN_USING_XERCES(SAXParseException)
-XALAN_USING_XERCES(SAXException)
-XALAN_USING_XERCES(XMLException)
-
-
-
-// We need lots of things from the Xalan namespace, so hoist everything...
-XALAN_CPP_NAMESPACE_USE
-
-
-
 void
 warnPreviousOutputMethod(int	outputMethod)
 {
@@ -324,31 +327,6 @@ warnPreviousOutputMethod(int	outputMethod)
 
 
 
-#if defined(OS390)
-#include <strings.h>                                             
-                                                                  
-int
-compareNoCase(
-			const char*		str1,
-			const char*		str2)     
-{
-	return strcasecmp(str1, str2);
-}
-
-#else
-
-int
-compareNoCase(
-			const char*		str1,
-			const char*		str2)     
-{
-	return stricmp(str1, str2);
-}
-
-#endif
-
-
-
 bool
 getArgs(
 			int				argc,
@@ -359,11 +337,11 @@ getArgs(
 
 	for (int i = 1; i < argc && fSuccess == true; ++i)
 	{
-		if (!compareNoCase("-h", argv[i]) || !compareNoCase("-?", argv[i]))
+		if (!strcmp("-h", argv[i]) || !strcmp("-?", argv[i]))
 		{
 			fSuccess = false;
 		}
-		else if (!compareNoCase("-IN", argv[i]))
+		else if (!strcmp("-in", argv[i]))
 		{
 			++i;
 
@@ -376,7 +354,7 @@ getArgs(
 				fSuccess = false;
 			}
 		}
-		else if (!compareNoCase("-XSL", argv[i]))
+		else if (!strcmp("-xsl", argv[i]))
 		{
 			++i;
 
@@ -389,7 +367,7 @@ getArgs(
 				fSuccess = false;
 			}
 		}
-		else if (!compareNoCase("-OUT", argv[i]))
+		else if (!strcmp("-out", argv[i]))
 		{
 			++i;
 
@@ -402,11 +380,11 @@ getArgs(
 				fSuccess = false;
 			}
 		}
-		else if (!compareNoCase("-NOINDENT", argv[i]))
+		else if (!strcmp("-noindent", argv[i]))
 		{
 			p.noIndent = true;
 		} 
-		else if (!compareNoCase("-INDENT", argv[i]))
+		else if (!strcmp("-indent", argv[i]))
 		{
 			++i;
 
@@ -423,11 +401,11 @@ getArgs(
 				fSuccess = false;
 			}
 		}
-		else if(!compareNoCase("-VALIDATE", argv[i]))
+		else if(!strcmp("-validate", argv[i]))
 		{
 			p.doValidation = true;
 		}
-		else if (!compareNoCase("-PARAM", argv[i])) 
+		else if (!strcmp("-param", argv[i])) 
 		{
 			++i;
 
@@ -455,19 +433,19 @@ getArgs(
 				fSuccess = false;
 			}
 		}
-		else if(!compareNoCase("-V", argv[i]))
+		else if(!strcmp("-v", argv[i]))
 		{
 			p.versionOnly = true;
 		}
-		else if(!compareNoCase("-QC", argv[i]))
+		else if(!strcmp("-qc", argv[i]))
 		{
 			p.setQuietConflictWarnings = true;
 		}
-		else if(!compareNoCase("-Q", argv[i]))
+		else if(!strcmp("-q", argv[i]))
 		{
 			p.setQuietMode = true;
 		}
-		else if(!compareNoCase("-XML", argv[i]))
+		else if(!strcmp("-xml", argv[i]))
 		{
 			if (p.outputType != -1)
 			{
@@ -476,7 +454,7 @@ getArgs(
 
 			p.outputType = FormatterListener::OUTPUT_METHOD_XML;
 		}
-		else if(!compareNoCase("-TEXT", argv[i]))
+		else if(!strcmp("-text", argv[i]))
 		{
 			if (p.outputType != -1)
 			{
@@ -485,7 +463,7 @@ getArgs(
 
 			p.outputType = FormatterListener::OUTPUT_METHOD_TEXT;
 		}
-		else if(!compareNoCase("-HTML", argv[i]))
+		else if(!strcmp("-html", argv[i]))
 		{
 			if (p.outputType != -1)
 			{
@@ -494,7 +472,7 @@ getArgs(
 
 			p.outputType = FormatterListener::OUTPUT_METHOD_HTML;
 		}
-		else if(!compareNoCase("-DOM", argv[i]))
+		else if(!strcmp("-dom", argv[i]))
 		{
 			if (p.outputType != -1)
 			{
@@ -503,7 +481,7 @@ getArgs(
 
 			p.outputType = FormatterListener::OUTPUT_METHOD_DOM;
 		}
-		else if(!compareNoCase("-XST", argv[i]))
+		else if(!strcmp("-xst", argv[i]))
 		{
 			if (p.outputType != -1)
 			{
@@ -514,35 +492,35 @@ getArgs(
 
 			p.formatToSourceTree = true;
 		}
-		else if(!compareNoCase("-NULL", argv[i]))
+		else if(!strcmp("-null", argv[i]))
 		{
 			p.formatToNull = true;
 		}
-		else if (!compareNoCase("-NH", argv[i]))
+		else if (!strcmp("-nh", argv[i]))
 		{
 			p.shouldWriteXMLHeader = false;
 		}
-		else if(!compareNoCase("-TT", argv[i]))
+		else if(!strcmp("-tt", argv[i]))
 		{
 			p.traceTemplates = true;
 		}
-		else if(!compareNoCase("-TG", argv[i]))
+		else if(!strcmp("-tg", argv[i]))
 		{
 			p.traceGenerationEvent = true;
 		}
-		else if(!compareNoCase("-TS", argv[i]))
+		else if(!strcmp("-ts", argv[i]))
 		{
 			p.traceSelectionEvent = true;
 		}
-		else if(!compareNoCase("-TTC", argv[i]))
+		else if(!strcmp("-ttc", argv[i]))
 		{
 			p.traceTemplateChildren = true;
 		}
-		else if (!compareNoCase("-XD", argv[i]))
+		else if (!strcmp("-xd", argv[i]))
 		{
 			p.useDOM = true;
 		}
-		else if (!compareNoCase("-DE", argv[i]))
+		else if (!strcmp("-de", argv[i]))
 		{
 			p.disableExtensions = true;
 		}
@@ -573,6 +551,8 @@ createFormatter(
 			const PrefixResolver&			prefixResolver,
 			const XalanDocument*&			theResultDocument)
 {
+    MemoryManagerType& theManager = XalanMemMgrs::getDefaultXercesMemMgr();
+
 	FormatterListener*	formatter = 0;
 
 	if (formatToNull == true)
@@ -581,21 +561,21 @@ createFormatter(
 	}
 	else if(FormatterListener::OUTPUT_METHOD_XML == outputType)
 	{
-		XalanDOMString	version;
+		XalanDOMString	version(theManager);
 		bool			outputIndent = false;
-		XalanDOMString	mediatype;
-		XalanDOMString	doctypeSystem;
-		XalanDOMString	doctypePublic;
-		XalanDOMString	standalone;
+		XalanDOMString	mediatype(theManager);
+		XalanDOMString	doctypeSystem(theManager);
+		XalanDOMString	doctypePublic(theManager);
+		XalanDOMString	standalone(theManager);
 
 		if (stylesheet != 0)
 		{
-			version = stylesheet->getOutputVersion();
+			stylesheet->getOutputVersion(version);
 
-			mediatype = stylesheet->getOutputMediaType();
-			doctypeSystem = stylesheet->getOutputDoctypeSystem();
-			doctypePublic = stylesheet->getOutputDoctypePublic();
-			standalone = stylesheet->getOutputStandalone();
+			stylesheet->getOutputMediaType(mediatype);
+			stylesheet->getOutputDoctypeSystem(doctypeSystem);
+			stylesheet->getOutputDoctypePublic(doctypePublic);
+			stylesheet->getOutputStandalone(standalone);
 		}
 
 		FormatterToXML* const	fToXML =
@@ -609,7 +589,10 @@ createFormatter(
 					doctypeSystem,
 					doctypePublic,
 					true,	// xmlDecl
-					standalone);
+					standalone,
+                    FormatterToXML::OUTPUT_METHOD_XML,
+                    true,
+                    theManager);
 
 		fToXML->setShouldWriteXMLHeader(shouldWriteXMLHeader);
 
@@ -617,30 +600,35 @@ createFormatter(
 	}
 	else if(FormatterListener::OUTPUT_METHOD_TEXT == outputType)
 	{
-		formatter = new FormatterToText(resultWriter, mimeEncoding);
+		formatter = new FormatterToText(
+                            resultWriter,
+                            mimeEncoding,
+                            true,
+                            true,
+                            theManager);
 	}
 	else if(FormatterListener::OUTPUT_METHOD_HTML == outputType)
 	{
-		XalanDOMString	version;
+		XalanDOMString	version(theManager);
 		bool			outputIndent = !noIndent;
-		XalanDOMString	mediatype;
-		XalanDOMString	doctypeSystem;
-		XalanDOMString	doctypePublic;
-		XalanDOMString	standalone;
+		XalanDOMString	mediatype(theManager);
+		XalanDOMString	doctypeSystem(theManager);
+		XalanDOMString	doctypePublic(theManager);
+		XalanDOMString	standalone(theManager);
 
 		if (stylesheet != 0)
 		{
-			version = stylesheet->getOutputVersion();
+			stylesheet->getOutputVersion(version);
 
 			if (noIndent == false)
 			{
 				outputIndent = stylesheet->getOutputIndent();
 			}
 
-			mediatype = stylesheet->getOutputMediaType();
-			doctypeSystem = stylesheet->getOutputDoctypeSystem();
-			doctypePublic = stylesheet->getOutputDoctypePublic();
-			standalone = stylesheet->getOutputStandalone();
+			 stylesheet->getOutputMediaType(mediatype);
+			 stylesheet->getOutputDoctypeSystem(doctypeSystem);
+			 stylesheet->getOutputDoctypePublic(doctypePublic);
+			 stylesheet->getOutputStandalone(standalone);
 		}
 
 		FormatterToHTML* const	fToHTML =
@@ -651,7 +639,10 @@ createFormatter(
 						doctypeSystem,
 						doctypePublic,
 						outputIndent,
-						indentAmount);
+						indentAmount,
+                        true,
+                        false,
+                        theManager);
 
 		fToHTML->setPrefixResolver(&prefixResolver);
 
@@ -668,7 +659,7 @@ createFormatter(
 			theResultDocument = theDocument;
 
 			FormatterToSourceTree* const	fToSourceTree =
-				new FormatterToSourceTree(theDocument);
+				new FormatterToSourceTree(theManager, theDocument);
 
 			fToSourceTree->setPrefixResolver(&prefixResolver);
 
@@ -681,7 +672,7 @@ createFormatter(
 			assert(theDocument != 0);
 
 			FormatterToXercesDOM* const     fToDOM =
-				new FormatterToXercesDOM(theDocument, 0);
+				new FormatterToXercesDOM( theDocument, 0, theManager);
 
 			fToDOM->setPrefixResolver(&prefixResolver);
 
@@ -702,15 +693,19 @@ createFormatter(
 
 
 XalanOutputStream*
-createOutputStream(const CmdLineParams&		params)
+createOutputStream(MemoryManagerType& theManager , const CmdLineParams&		params)
 {
 	if (params.outFileName == 0)
 	{
-		return new XalanStdOutputStream(cout);
+		return new XalanStdOutputStream(cout, theManager);
 	}
 	else
 	{
-		return new XalanFileOutputStream(TranscodeFromLocalCodePage(params.outFileName));
+        XalanDOMString buffer(theManager);
+        
+        TranscodeFromLocalCodePage(params.outFileName, buffer); 
+
+		return new XalanFileOutputStream(buffer, theManager);
 	}
 }
 
@@ -718,6 +713,7 @@ createOutputStream(const CmdLineParams&		params)
 
 TraceListener*
 createTraceListener(
+            MemoryManagerType&      theManager ,
 			const CmdLineParams&	params,
 			PrintWriter&			diagnosticsWriter)
 {
@@ -731,7 +727,8 @@ createTraceListener(
 				params.traceTemplates,
 				params.traceTemplateChildren,
 				params.traceGenerationEvent,
-				params.traceSelectionEvent);
+				params.traceSelectionEvent,
+                theManager);
 	}
 	else
 	{
@@ -784,15 +781,17 @@ xsltMain(const CmdLineParams&	params)
 	// Initialize the XSLT subsystem.  This must stay in scope until
 	// we're done with the subsystem, since its destructor shuts down
 	// the subsystem.
-	XSLTInit	theInit;
+    MemoryManagerType& theManager = XalanMemMgrs::getDefaultXercesMemMgr();
 
-	const XalanDOMString	mimeEncoding(XALAN_STATIC_UCODE_STRING("UTF-8"));
-	const XalanDOMString	encoding(XALAN_STATIC_UCODE_STRING("UTF-8"));
+	XSLTInit	theInit(theManager);
+
+	const XalanDOMString	mimeEncoding(XALAN_STATIC_UCODE_STRING("UTF-8"), theManager);
+	const XalanDOMString	encoding(XALAN_STATIC_UCODE_STRING("UTF-8"), theManager);
 
 	/**
 	 * The default diagnostic writer...
 	 */
-	XalanStdOutputStream				theStdErr(cerr);
+	XalanStdOutputStream				theStdErr(cerr, theManager);
 	XalanOutputStreamPrintWriter		diagnosticsWriter(theStdErr);
 
 	// Make sure that error reporting, which includes any TraceListener output
@@ -805,17 +804,17 @@ xsltMain(const CmdLineParams&	params)
 	// Initialize the XalanSourceTree subsystem.  This must stay in scope until
 	// we're done with the subsystem, since its destructor shuts down the
 	// subsystem.
-	XalanSourceTreeInit				theXalanSourceTreeInit;
+	XalanSourceTreeInit				theXalanSourceTreeInit(theManager);
 
 	XalanSourceTreeDOMSupport		theXalanSourceTreeDOMSupport;
-	XalanSourceTreeParserLiaison	theXalanSourceTreeParserLiaison(theXalanSourceTreeDOMSupport);
+	XalanSourceTreeParserLiaison	theXalanSourceTreeParserLiaison(theXalanSourceTreeDOMSupport, theManager);
 
 	// Hookup the parser liaison instance to the support instance.
-	theXalanSourceTreeDOMSupport.setParserLiaison(&theXalanSourceTreeParserLiaison);
+	theXalanSourceTreeDOMSupport.setParserLiaison( &theXalanSourceTreeParserLiaison);
 
 
-	XercesDOMSupport		theXercesDOMSupport;
-	XercesParserLiaison		theXercesParserLiaison;
+	XercesDOMSupport		theXercesDOMSupport(theManager);
+	XercesParserLiaison		theXercesParserLiaison(theManager);
 
 	DOMSupport&				theDOMSupport = getDOMSupport(
 		theXalanSourceTreeDOMSupport,
@@ -827,27 +826,29 @@ xsltMain(const CmdLineParams&	params)
 		theXercesParserLiaison,
 		params);
 
-	XSLTProcessorEnvSupportDefault	theXSLProcessorSupport;
+	XSLTProcessorEnvSupportDefault	theXSLProcessorSupport(theManager);
 
 	if (params.disableExtensions == false)
 	{
-		XalanExtensionsInstaller::installGlobal();
-		XalanEXSLTCommonFunctionsInstaller::installGlobal();
-		XalanEXSLTMathFunctionsInstaller::installGlobal();
-		XalanEXSLTSetFunctionsInstaller::installGlobal();
-		XalanEXSLTStringFunctionsInstaller::installGlobal();
+		XalanExtensionsInstaller::installGlobal(theManager);
+		XalanEXSLTCommonFunctionsInstaller::installGlobal(theManager);
+		XalanEXSLTMathFunctionsInstaller::installGlobal(theManager);
+		XalanEXSLTSetFunctionsInstaller::installGlobal(theManager);
+		XalanEXSLTStringFunctionsInstaller::installGlobal(theManager);
 	}
 
-	XObjectFactoryDefault	theXObjectFactory;
+	XObjectFactoryDefault	theXObjectFactory(theManager);
 
-	XPathFactoryDefault		theXPathFactory;
+	XPathFactoryDefault		theXPathFactory(theManager);
 
 	const XalanAutoPtr<TraceListener>		theTraceListener(
 			createTraceListener(
+                theManager,
 				params,
 				diagnosticsWriter));
 
 	XSLTEngineImpl	processor(
+            theManager,
 			xmlParserLiaison,
 			theXSLProcessorSupport,
 			theDOMSupport,
@@ -865,9 +866,10 @@ xsltMain(const CmdLineParams&	params)
 	// Use a different factory type for the stylesheet.  This is an optimization, since
 	// stylesheet XPath instances are built all at once and are deleted all at once when
 	// the stylesheet is destroyed.
-	XPathFactoryBlock	theStylesheetXPathFactory;
+	XPathFactoryBlock	theStylesheetXPathFactory(theManager);
 
 	StylesheetConstructionContextDefault	theConstructionContext(
+            theManager,
 			processor,
 			theStylesheetXPathFactory);
 
@@ -885,8 +887,8 @@ xsltMain(const CmdLineParams&	params)
 			assert((*it).first != 0 && (*it).second != 0);
 
 			processor.setStylesheetParam(
-					XalanDOMString((*it).first),
-					XalanDOMString((*it).second));
+					XalanDOMString((*it).first, theManager),
+					XalanDOMString((*it).second, theManager));
 		}
 	}
 
@@ -905,7 +907,7 @@ xsltMain(const CmdLineParams&	params)
 		processor.setDiagnosticsOutput(&diagnosticsWriter);
 	}
 
-	XalanDOMString	xslFileName;
+	XalanDOMString	xslFileName(theManager);
 
 	if(params.xslFileName != 0)
 	{
@@ -919,7 +921,7 @@ xsltMain(const CmdLineParams&	params)
 		stylesheet = processor.processStylesheet(xslFileName, theConstructionContext);
 	}
 
-	XalanAutoPtr<XalanOutputStream>		outputFileStream(createOutputStream(params));
+	XalanAutoPtr<XalanOutputStream>		outputFileStream(createOutputStream(theManager, params));
 	assert(outputFileStream.get() != 0);
 
 	XalanOutputStreamPrintWriter	resultWriter(*outputFileStream.get());
@@ -942,7 +944,7 @@ xsltMain(const CmdLineParams&	params)
 				processor,
 				theResultDocument));
 
-	XSLTResultTarget	rTreeTarget;
+	XSLTResultTarget	rTreeTarget(theManager);
 
 	if(formatter.get() == 0)
 	{
@@ -958,7 +960,7 @@ xsltMain(const CmdLineParams&	params)
 
 	if (params.inFileName != 0)
 	{
-		theInputSource.setSystemId(XalanDOMString(params.inFileName).c_str());
+		theInputSource.setSystemId(XalanDOMString(params.inFileName, theManager).c_str());
 	}
 	else
 	{
@@ -967,7 +969,7 @@ xsltMain(const CmdLineParams&	params)
 		cerr << "Reading input document from stdin..." << endl;
 	}
 
-	StylesheetExecutionContextDefault	theExecutionContext(processor,
+	StylesheetExecutionContextDefault	theExecutionContext(theManager, processor,
 			theXSLProcessorSupport,
 			theDOMSupport,
 			theXObjectFactory);
@@ -975,7 +977,7 @@ xsltMain(const CmdLineParams&	params)
 #if defined(XALAN_USE_ICU)
 	// Create a collation function for the ICU, and have it
 	// cache collators...
-	ICUBridgeCollationCompareFunctor	theICUFunctor(true);
+	ICUBridgeCollationCompareFunctor	theICUFunctor(theManager, true);
 
 	theExecutionContext.installCollationCompareFunctor(&theICUFunctor);
 #endif
@@ -1048,7 +1050,7 @@ xsltMain(const CmdLineParams&	params)
 
 			// Create a FormatterTreeWalker with the the
 			// new formatter...
-			FormatterTreeWalker theTreeWalker(*formatter.get());
+			FormatterTreeWalker theTreeWalker(*formatter.get(), theManager);
 
 			// Walk the document and produce the XML...
 			theTreeWalker.traverse(theResultDocument);
@@ -1071,11 +1073,11 @@ xsltMain(const CmdLineParams&	params)
 
 	if (params.disableExtensions == false)
 	{
-		XalanExtensionsInstaller::uninstallGlobal();
-		XalanEXSLTCommonFunctionsInstaller::uninstallGlobal();
-		XalanEXSLTMathFunctionsInstaller::uninstallGlobal();
-		XalanEXSLTSetFunctionsInstaller::uninstallGlobal();
-		XalanEXSLTStringFunctionsInstaller::uninstallGlobal();
+		XalanExtensionsInstaller::uninstallGlobal(theManager);
+		XalanEXSLTCommonFunctionsInstaller::uninstallGlobal(theManager);
+		XalanEXSLTMathFunctionsInstaller::uninstallGlobal(theManager);
+		XalanEXSLTSetFunctionsInstaller::uninstallGlobal(theManager);
+		XalanEXSLTStringFunctionsInstaller::uninstallGlobal(theManager);
 	}
 
 	return 0;
@@ -1166,7 +1168,7 @@ main(
 
 			if (theSystemID != 0)
 			{
-				cout << XalanDOMString(theSystemID);
+				cout << theSystemID;
 			}
 			else
 			{
@@ -1220,5 +1222,9 @@ main(
 		XMLPlatformUtils::Terminate();
 	}
 
+#if defined(XALAN_USE_ICU)
+    ICUBridgeCleanup::cleanup();
+#endif
+
 	return theResult;
 }
