@@ -33,9 +33,8 @@
 
 
 
-#include <xalanc/Include/XalanAutoPtr.hpp>
-
 
+#include <xalanc/Include/XalanMemMgrAutoPtr.hpp>
 
 #include <xalanc/PlatformSupport/DOMStringHelper.hpp>
 #include <xalanc/PlatformSupport/PrefixResolver.hpp>
@@ -54,7 +53,7 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 
-const XalanDOMString	FormatterToHTML::s_emptyString;
+const XalanDOMString	FormatterToHTML::s_emptyString(XalanMemMgrs::getDummyMemMgr());
 
 
 
@@ -67,7 +66,8 @@ FormatterToHTML::FormatterToHTML(
 			bool					doIndent,
 			int						indent,
 			bool					escapeURLs,
-			bool					omitMetaTag) :
+			bool					omitMetaTag,
+            MemoryManagerType&      theManager) :
 	FormatterToXML(
 			writer,
 			s_emptyString,
@@ -79,19 +79,21 @@ FormatterToHTML::FormatterToHTML(
 			doctypePublic,
 			false,
 			s_emptyString,
-			OUTPUT_METHOD_HTML),
-	m_currentElementName(),
+			OUTPUT_METHOD_HTML,
+            true,
+            theManager),
+	m_currentElementName(theManager),
 	m_inBlockElem(false),
-	m_isRawStack(),
+	m_isRawStack(theManager),
 	m_isScriptOrStyleElem(false),
-	m_inScriptElemStack(),
+	m_inScriptElemStack(theManager),
 	m_escapeURLs(escapeURLs),
 	m_isFirstElement(false),
 	m_isUTF8(XalanTranscodingServices::encodingIsUTF8(m_encoding)),
 	m_elementLevel(0),
-	m_hasNamespaceStack(),
+	m_hasNamespaceStack(theManager),
 	m_omitMetaTag(omitMetaTag),
-	m_elementPropertiesStack()
+	m_elementPropertiesStack(theManager)
 {
 	initCharsMap();
 
@@ -100,7 +102,41 @@ FormatterToHTML::FormatterToHTML(
     m_shouldWriteXMLHeader = false;
 }
 
+FormatterToHTML*
+FormatterToHTML::create(
+            MemoryManagerType&      theManager,
+			Writer&					writer,
+			const XalanDOMString&	encoding, 
+			const XalanDOMString&	mediaType,
+			const XalanDOMString&	doctypeSystem,
+			const XalanDOMString&	doctypePublic,
+			bool					doIndent,
+			int						indent,
+			bool					escapeURLs,
+			bool					omitMetaTag) 
+{
+    typedef FormatterToHTML ThisType;
 
+    XalanMemMgrAutoPtr<ThisType, false> theGuard( theManager , (ThisType*)theManager.allocate(sizeof(ThisType)));
+
+    ThisType* theResult = theGuard.get();
+
+    new (theResult) ThisType(           
+  			            writer,
+			            encoding, 
+			            mediaType,
+			            doctypeSystem,
+			            doctypePublic,
+			            doIndent,
+			            indent,
+			            escapeURLs,
+			            omitMetaTag,
+                        theManager);
+
+   theGuard.release();
+
+    return theResult;
+}
 
 FormatterToHTML::~FormatterToHTML()
 {
@@ -395,10 +431,13 @@ FormatterToHTML::endElement(const XMLCh* const	name)
 				indent(m_currentIndent);
 			}
 
-			accumContent(XalanUnicode::charLessThanSign);
-			accumContent(XalanUnicode::charSolidus);
-			accumName(name);
-			accumContent(XalanUnicode::charGreaterThanSign);
+			if(elemProperties.is(XalanHTMLElementsProperties::EMPTY) == false)
+			{
+			    accumContent(XalanUnicode::charLessThanSign);
+			    accumContent(XalanUnicode::charSolidus);
+			    accumName(name);
+			    accumContent(XalanUnicode::charGreaterThanSign);
+            }
 		}
 		else
 		{
@@ -689,7 +728,7 @@ FormatterToHTML::writeCharacters(
 
 					if (i + 1 >= theLength) 
 					{
-						throwInvalidUTF16SurrogateException(ch);
+                        throwInvalidUTF16SurrogateException(ch, getMemoryManager());
 					}
 					else
 					{
@@ -697,7 +736,7 @@ FormatterToHTML::writeCharacters(
 
 						if (!(0xdc00 <= next && next < 0xe000))
 						{
-							throwInvalidUTF16SurrogateException(ch, next);
+                            throwInvalidUTF16SurrogateException(ch, next, getMemoryManager());
 						}
 
 						next = XalanDOMChar(((ch - 0xd800) << 10) + next - 0xdc00 + 0x00010000);
@@ -765,7 +804,7 @@ FormatterToHTML::writeAttrString(
 
 					if (i + 1 >= theStringLength) 
 					{
-						throwInvalidUTF16SurrogateException(ch);
+						throwInvalidUTF16SurrogateException(ch, getMemoryManager());
 					}
 					else 
 					{
@@ -773,7 +812,7 @@ FormatterToHTML::writeAttrString(
 
 						if (!(0xdc00 <= next && next < 0xe000))
 						{
-							throwInvalidUTF16SurrogateException(ch, next);
+							throwInvalidUTF16SurrogateException(ch, next, getMemoryManager());
 						}
 
 						next = XalanDOMChar(((ch - 0xd800) << 10) + next -0xdc00 + 0x00010000);
@@ -846,41 +885,33 @@ FormatterToHTML::processAttribute(
 			const XalanDOMChar*										value,
 			const XalanHTMLElementsProperties::ElementProperties&	elemProperties)
 {
-	// We add a fake attribute to the source tree to
-	// declare the xml prefix, so we filter it back out
-	// here...
-	// $$$ ToDo: It would be better if we didn't have to do
-	// this here.
 	const XalanDOMString::size_type		nameLength = length(name);
 
-	if (equals(name, nameLength, c_wstr(DOMServices::s_XMLNamespacePrefix), DOMServices::s_XMLNamespacePrefixLength) == false)
+	accumContent(XalanUnicode::charSpace);
+
+	const XalanDOMString::size_type		valueLength = length(value);
+
+	if((valueLength == 0 || equalsIgnoreCaseASCII(name, nameLength, value, valueLength)) &&
+	   elemProperties.isAttribute(name, XalanHTMLElementsProperties::ATTREMPTY) == true)
 	{
-		accumContent(XalanUnicode::charSpace);
+		accumName(name);
+	}
+	else
+	{
+		accumName(name, 0, nameLength);
+		accumContent(XalanUnicode::charEqualsSign);
+		accumContent(XalanUnicode::charQuoteMark);
 
-		const XalanDOMString::size_type		valueLength = length(value);
-
-		if((valueLength == 0 || equalsIgnoreCaseASCII(name, nameLength, value, valueLength)) &&
-		   elemProperties.isAttribute(name, XalanHTMLElementsProperties::ATTREMPTY) == true)
+		if(elemProperties.isAttribute(name, XalanHTMLElementsProperties::ATTRURL) == true)
 		{
-			accumName(name);
+			writeAttrURI(value, valueLength);
 		}
 		else
 		{
-			accumName(name, 0, nameLength);
-			accumContent(XalanUnicode::charEqualsSign);
-			accumContent(XalanUnicode::charQuoteMark);
-
-			if(elemProperties.isAttribute(name, XalanHTMLElementsProperties::ATTRURL) == true)
-			{
-				writeAttrURI(value, valueLength);
-			}
-			else
-			{
-				writeAttrString(value, valueLength);
-			}
-
-			accumContent(XalanUnicode::charQuoteMark);
+			writeAttrString(value, valueLength);
 		}
+
+		accumContent(XalanUnicode::charQuoteMark);
 	}
 }
 
