@@ -254,6 +254,11 @@ const XalanHTMLElementsProperties::InternalElementProperties	XalanHTMLElementsPr
 		{ XalanUnicode::charLetter_D, XalanUnicode::charLetter_L, 0 },
 		ElemDesc::BLOCK | ElemDesc::BLOCKFORM | ElemDesc::BLOCKFORMFIELDSET,
 		{
+			{
+			
+				{ XalanUnicode::charLetter_C, XalanUnicode::charLetter_O, XalanUnicode::charLetter_M, XalanUnicode::charLetter_P, XalanUnicode::charLetter_A, XalanUnicode::charLetter_C, XalanUnicode::charLetter_T, 0 },
+				ElemDesc::ATTREMPTY,
+			},
 			{
 				{ 0 },
 				0,
@@ -344,6 +349,11 @@ const XalanHTMLElementsProperties::InternalElementProperties	XalanHTMLElementsPr
 		{ XalanUnicode::charLetter_H, XalanUnicode::charLetter_R, 0 },
 		ElemDesc::EMPTY | ElemDesc::BLOCK | ElemDesc::BLOCKFORM | ElemDesc::BLOCKFORMFIELDSET,
 		{
+			{
+			
+				{ XalanUnicode::charLetter_N, XalanUnicode::charLetter_O, XalanUnicode::charLetter_S, XalanUnicode::charLetter_H, XalanUnicode::charLetter_A, XalanUnicode::charLetter_D, XalanUnicode::charLetter_E, 0 },
+				ElemDesc::ATTREMPTY,
+			},
 			{
 				{ 0 },
 				0,
@@ -364,6 +374,11 @@ const XalanHTMLElementsProperties::InternalElementProperties	XalanHTMLElementsPr
 		{ XalanUnicode::charLetter_O, XalanUnicode::charLetter_L, 0 },
 		ElemDesc::BLOCK | ElemDesc::LIST,
 		{
+			{
+			
+				{ XalanUnicode::charLetter_C, XalanUnicode::charLetter_O, XalanUnicode::charLetter_M, XalanUnicode::charLetter_P, XalanUnicode::charLetter_A, XalanUnicode::charLetter_C, XalanUnicode::charLetter_T, 0 },
+				ElemDesc::ATTREMPTY,
+			},
 			{
 				{ 0 },
 				0,
@@ -374,6 +389,11 @@ const XalanHTMLElementsProperties::InternalElementProperties	XalanHTMLElementsPr
 		{ XalanUnicode::charLetter_T, XalanUnicode::charLetter_D, 0 },
 		0,
 		{
+			{
+			
+				{ XalanUnicode::charLetter_N, XalanUnicode::charLetter_O, XalanUnicode::charLetter_W, XalanUnicode::charLetter_R, XalanUnicode::charLetter_A, XalanUnicode::charLetter_P, 0 },
+				ElemDesc::ATTREMPTY,
+			},
 			{
 				{ 0 },
 				0,
@@ -384,6 +404,11 @@ const XalanHTMLElementsProperties::InternalElementProperties	XalanHTMLElementsPr
 		{ XalanUnicode::charLetter_T, XalanUnicode::charLetter_H, 0 },
 		0,
 		{
+			{
+			
+				{ XalanUnicode::charLetter_N, XalanUnicode::charLetter_O, XalanUnicode::charLetter_W, XalanUnicode::charLetter_R, XalanUnicode::charLetter_A, XalanUnicode::charLetter_P, 0 },
+				ElemDesc::ATTREMPTY,
+			},
 			{
 				{ 0 },
 				0,
@@ -414,6 +439,11 @@ const XalanHTMLElementsProperties::InternalElementProperties	XalanHTMLElementsPr
 		{ XalanUnicode::charLetter_U, XalanUnicode::charLetter_L, 0 },
 		ElemDesc::BLOCK | ElemDesc::LIST,
 		{
+			{
+			
+				{ XalanUnicode::charLetter_C, XalanUnicode::charLetter_O, XalanUnicode::charLetter_M, XalanUnicode::charLetter_P, XalanUnicode::charLetter_A, XalanUnicode::charLetter_C, XalanUnicode::charLetter_T, 0 },
+				ElemDesc::ATTREMPTY,
+			},
 			{
 				{ 0 },
 				0,
@@ -479,6 +509,11 @@ const XalanHTMLElementsProperties::InternalElementProperties	XalanHTMLElementsPr
 		{ XalanUnicode::charLetter_D, XalanUnicode::charLetter_I, XalanUnicode::charLetter_R, 0 },
 		ElemDesc::BLOCK,
 		{
+			{
+			
+				{ XalanUnicode::charLetter_C, XalanUnicode::charLetter_O, XalanUnicode::charLetter_M, XalanUnicode::charLetter_P, XalanUnicode::charLetter_A, XalanUnicode::charLetter_C, XalanUnicode::charLetter_T, 0 },
+				ElemDesc::ATTREMPTY,
+			},
 			{
 				{ 0 },
 				0,
@@ -733,6 +768,11 @@ const XalanHTMLElementsProperties::InternalElementProperties	XalanHTMLElementsPr
 		{ XalanUnicode::charLetter_M, XalanUnicode::charLetter_E, XalanUnicode::charLetter_N, XalanUnicode::charLetter_U, 0 },
 		ElemDesc::BLOCK,
 		{
+			{
+			
+				{ XalanUnicode::charLetter_C, XalanUnicode::charLetter_O, XalanUnicode::charLetter_M, XalanUnicode::charLetter_P, XalanUnicode::charLetter_A, XalanUnicode::charLetter_C, XalanUnicode::charLetter_T, 0 },
+				ElemDesc::ATTREMPTY,
+			},
 			{
 				{ 0 },
 				0,
@@ -787,6 +827,11 @@ const XalanHTMLElementsProperties::InternalElementProperties	XalanHTMLElementsPr
 				{ XalanUnicode::charLetter_S, XalanUnicode::charLetter_R, XalanUnicode::charLetter_C, 0 },
 				ElemDesc::ATTRURL,
 			},
+			{
+			
+				{ XalanUnicode::charLetter_N, XalanUnicode::charLetter_O, XalanUnicode::charLetter_R, XalanUnicode::charLetter_E, XalanUnicode::charLetter_S, XalanUnicode::charLetter_I, XalanUnicode::charLetter_Z, XalanUnicode::charLetter_E, 0 },
+				ElemDesc::ATTREMPTY,
+			},
 			{
 				{ 0 },
 				0,
