@@ -23,8 +23,8 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 
-XNumberAllocator::XNumberAllocator(size_type	theBlockCount) :
-	m_allocator(theBlockCount)
+XNumberAllocator::XNumberAllocator(MemoryManagerType&      theManager, size_type	theBlockCount) :
+	m_allocator(theManager, theBlockCount)
 {
 }
 
@@ -42,7 +42,7 @@ XNumberAllocator::createNumber(double	theNumber)
 	number_type* const	theBlock = m_allocator.allocateBlock();
 	assert(theBlock != 0);
 
-	number_type* const	theResult = new(theBlock) number_type(theNumber);
+    number_type* const	theResult = new(theBlock) number_type(theNumber, m_allocator.getMemoryManager());
 
 	m_allocator.commitAllocation(theBlock);
 
@@ -51,20 +51,6 @@ XNumberAllocator::createNumber(double	theNumber)
 
 
 
-XNumberAllocator::number_type*
-XNumberAllocator::clone(const XNumber&	value)
-{
-	number_type* const		theBlock = m_allocator.allocateBlock();
-	assert(theBlock != 0);
-
-	value.clone(theBlock);
-
-	m_allocator.commitAllocation(theBlock);
-
-	return theBlock;
-}
-
-
 
 bool
 XNumberAllocator::destroy(number_type*	theNumber)
