@@ -65,9 +65,13 @@ public:
 
 	typedef XERCES_CPP_NAMESPACE_QUALIFIER Locator	LocatorType;
 
-    typedef XPathExpression::OpCodeMapPositionType      OpCodeMapPositionType;
-    typedef XPathExpression::OpCodeMapValueType         OpCodeMapValueType;
-    typedef XPathExpression::TokenQueuePositionType     TokenQueuePositionType;
+    typedef XPathExpression::OpCodeMapPositionType              OpCodeMapPositionType;
+    typedef XPathExpression::OpCodeMapValueType                 OpCodeMapValueType;
+    typedef XPathExpression::TokenQueuePositionType             TokenQueuePositionType;
+    typedef XPathExecutionContext::GetAndReleaseCachedString    GetCachedString;
+    typedef XPathExecutionContext::PrefixResolverSetAndRestore  PrefixResolverSetAndRestore;
+    typedef XPathExecutionContext::CurrentNodePushAndPop        CurrentNodePushAndPop;
+
 
 	static const XalanDOMChar	PSEUDONAME_ANY[];
 	static const XalanDOMChar	PSEUDONAME_ROOT[];
@@ -136,18 +140,13 @@ public:
 		eTargetType				m_targetType;
 	};
 
-#if defined(XALAN_NO_STD_NAMESPACE)
-	typedef vector<TargetData>		TargetDataVectorType;
-#else
-	typedef std::vector<TargetData>	TargetDataVectorType;
-#endif
-
+	typedef XalanVector<TargetData>		TargetDataVectorType;
 
 	/**
 	 * Perform static initialization.  See class XPathInit.
 	 */
 	static void
-	initialize();
+	initialize(MemoryManagerType& theManager);
 
 	/**
 	 * Perform static shut down.  See class XPathInit.
@@ -161,8 +160,16 @@ public:
 	 * @param theLocator The applicable LocatorType, if any.
 	 */
 	explicit
-	XPath(const LocatorType*	theLocator = 0);
+	XPath(MemoryManagerType& theManager, const LocatorType*	theLocator = 0);
 
+    static XPath*
+    create(MemoryManagerType& theManager, const LocatorType*	theLocator = 0);
+
+    MemoryManagerType&
+     getMemoryManager()
+    {
+        return m_expression.getMemoryManager();
+    }
 	~XPath();
 
 	/**
@@ -459,7 +466,7 @@ public:
 
 		return executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext);
 	}
 
@@ -482,7 +489,7 @@ public:
 
 		executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext,
                 result);
 	}
@@ -506,7 +513,7 @@ public:
 
 		executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext,
                 result);
 	}
@@ -531,7 +538,7 @@ public:
 
 		executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext,
                 result);
 	}
@@ -557,7 +564,7 @@ public:
 
 		executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext,
                 formatterListener,
                 function);
@@ -593,7 +600,7 @@ public:
 
 		return executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext,
                 result);
 	}
@@ -616,13 +623,13 @@ public:
 		assert(executionContext.getCurrentNode() != 0);
 
 		// Push and pop the PrefixResolver...
-		const XPathExecutionContext::PrefixResolverSetAndRestore	theResolverSetAndRestore(
-										executionContext,
-										&prefixResolver);
+		const PrefixResolverSetAndRestore	theResolverSetAndRestore(
+										        executionContext,
+										        &prefixResolver);
 
 		return executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext);
 	}
 
@@ -645,13 +652,13 @@ public:
 		assert(executionContext.getCurrentNode() != 0);
 
 		// Push and pop the PrefixResolver...
-		const XPathExecutionContext::PrefixResolverSetAndRestore	theResolverSetAndRestore(
-										executionContext,
-										&prefixResolver);
+		const PrefixResolverSetAndRestore	theResolverSetAndRestore(
+										        executionContext,
+										        &prefixResolver);
 
 		executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext,
                 result);
 	}
@@ -675,13 +682,13 @@ public:
 		assert(executionContext.getCurrentNode() != 0);
 
 		// Push and pop the PrefixResolver...
-		const XPathExecutionContext::PrefixResolverSetAndRestore	theResolverSetAndRestore(
-										executionContext,
-										&prefixResolver);
+		const PrefixResolverSetAndRestore	theResolverSetAndRestore(
+										        executionContext,
+										        &prefixResolver);
 
 		executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext,
                 result);
 	}
@@ -706,13 +713,13 @@ public:
 		assert(executionContext.getCurrentNode() != 0);
 
 		// Push and pop the PrefixResolver...
-		const XPathExecutionContext::PrefixResolverSetAndRestore	theResolverSetAndRestore(
-										executionContext,
-										&prefixResolver);
+		const PrefixResolverSetAndRestore	theResolverSetAndRestore(
+										        executionContext,
+										        &prefixResolver);
 
 		executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext,
                 result);
 	}
@@ -735,13 +742,13 @@ public:
 		assert(executionContext.getCurrentNode() != 0);
 
 		// Push and pop the PrefixResolver...
-		const XPathExecutionContext::PrefixResolverSetAndRestore	theResolverSetAndRestore(
-										executionContext,
-										&prefixResolver);
+		const PrefixResolverSetAndRestore	theResolverSetAndRestore(
+										        executionContext,
+										        &prefixResolver);
 
 		executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext,
                 formatterListener,
                 function);
@@ -777,13 +784,13 @@ public:
 		assert(executionContext.getCurrentNode() != 0);
 
 		// Push and pop the PrefixResolver...
-		const XPathExecutionContext::PrefixResolverSetAndRestore	theResolverSetAndRestore(
-										executionContext,
-										&prefixResolver);
+		const PrefixResolverSetAndRestore	theResolverSetAndRestore(
+										        executionContext,
+										        &prefixResolver);
 
 		return executeMore(
                 executionContext.getCurrentNode(),
-                m_expression.getInitialOpCodePosition(),
+                getInitialOpCodePosition(),
                 executionContext,
                 result);
 	}
@@ -2388,6 +2395,18 @@ private:
 		eDefaultTargetDataSize = 5
 	};
 
+    OpCodeMapPositionType
+    getInitialOpCodePosition() const
+    {
+#if defined(XALAN_XPATH_EXPRESSION_USE_ITERATORS)
+        assert(m_expression.getOpCodeMapValue(0) == XPathExpression::eOP_XPATH);
+#else
+        assert(m_expression.getOpCodeMapValue(
+                    m_expression.getInitialOpCodePosition()) == XPathExpression::eOP_XPATH);
+#endif
+        return m_expression.getInitialOpCodePosition() + 2;
+    }
+
 	eMatchScore
 	locationPathPattern(
 			XPathExecutionContext&	executionContext,
