@@ -61,9 +61,19 @@ public:
 	 * @return pointer to the new object
 	 */
 	virtual Function*
-	clone() const
+	clone(MemoryManagerType& theManager) const
 	{
-		return new FunctionNotImplemented(m_name);
+        typedef FunctionNotImplemented Type;
+
+        XalanMemMgrAutoPtr<Type, false> theGuard( theManager , (Type*)theManager.allocate(sizeof(Type)));
+
+        Type* theResult = theGuard.get();
+
+        new (theResult) Type(m_name);
+
+        theGuard.release();
+
+        return theResult;
 	}
 
 protected:
@@ -75,12 +85,13 @@ protected:
 	 *
 	 * @return function error message
 	 */
-	virtual const XalanDOMString
-	getError() const
+	virtual const XalanDOMString&
+	getError(XalanDOMString& theResult) const
 	{
-		XalanDOMString	theName(m_name);
-
-		return XalanMessageLoader::getMessage(XalanMessages::FunctionIsNotImplemented_1Param, theName);
+		return XalanMessageLoader::getMessage(
+                    theResult,
+                    XalanMessages::FunctionIsNotImplemented_1Param,
+                    m_name);
 	}
 
 private:
@@ -97,7 +108,8 @@ private:
 
 
 
-XPathFunctionTable::XPathFunctionTable(bool		fCreateTable) :
+XPathFunctionTable::XPathFunctionTable( bool fCreateTable) :
+    m_memoryManager(0),
 	m_functionTable(),
 	m_functionTableEnd(m_functionTable + (sizeof(m_functionTable) / sizeof(m_functionTable[0])) - 1)
 {
@@ -132,27 +144,29 @@ XPathFunctionTable::InstallFunction(
 	const int	theFunctionID =
 			getFunctionIndex(theFunctionName);
 
+    assert (m_memoryManager != 0);
+
 	if (theFunctionID == InvalidFunctionNumberID)
 	{
-		throw XPathExceptionFunctionNotSupported(theFunctionName);
+        XalanDOMString theResult(*m_memoryManager);
+
+		throw XPathExceptionFunctionNotSupported(theFunctionName, theResult);
 	}
 	else
 	{
 		if (m_functionTable[theFunctionID] == 0)
 		{
-			m_functionTable[theFunctionID] = theFunction.clone();
+			m_functionTable[theFunctionID] = theFunction.clone(*m_memoryManager);
 		}
 		else
 		{
 			const Function* const	theOldFunction = m_functionTable[theFunctionID];
 
-			m_functionTable[theFunctionID] = theFunction.clone();
+			m_functionTable[theFunctionID] = theFunction.clone(*m_memoryManager);
 
-#if defined(XALAN_CANNOT_DELETE_CONST)
-			delete (Function*)theOldFunction;
-#else
-			delete theOldFunction;
-#endif
+            const_cast<Function*>(theOldFunction)->~Function();
+
+            m_memoryManager->deallocate((void*)theOldFunction);
 		}
 	}
 }
@@ -175,12 +189,12 @@ XPathFunctionTable::UninstallFunction(const XalanDOMChar*	theFunctionName)
 
 		m_functionTable[theFunctionID] = 0;
 
-#if defined(XALAN_CANNOT_DELETE_CONST)
-		delete (Function*)theFunction;
-#else
-		delete theFunction;
-#endif
+        if( theFunction!=0 )
+        {
+            const_cast<Function*>(theFunction)->~Function();
 
+             m_memoryManager->deallocate((void*)theFunction);
+        }
 		return true;
 	}
 }
@@ -445,7 +459,7 @@ XPathFunctionTable::DestroyTable()
 		for_each(
 			m_functionTable,
 			m_functionTable + TableSize,
-			DeleteFunctorType());
+			DeleteFunctorType(*m_memoryManager));
 
 #if defined(XALAN_STRICT_ANSI_HEADERS)
 		std::memset(m_functionTable, 0, sizeof(m_functionTable));
@@ -504,37 +518,31 @@ XPathFunctionTable::getFunctionIndex(
 
 
 
-XPathExceptionFunctionNotAvailable::XPathExceptionFunctionNotAvailable(int	theFunctionNumber) :
-	XalanXPathException(XalanMessageLoader::getMessage(XalanMessages::FunctionNumberIsNotAvailable_1Param,LongToDOMString(theFunctionNumber)))
-{
-}
-
-
-
-XPathExceptionFunctionNotAvailable::XPathExceptionFunctionNotAvailable(const XalanDOMString&	theFunctionName) :
-	XalanXPathException(XalanMessageLoader::getMessage(XalanMessages::SpecifiedFuncIsNotAvailable_1Param, theFunctionName))
+XPathExceptionFunctionNotAvailable::XPathExceptionFunctionNotAvailable(
+            const XalanDOMString&    theFunctionNumber,
+            XalanDOMString&          theResult) :
+    XalanXPathException(
+        XalanMessageLoader::getMessage(
+            theResult,
+            XalanMessages::FunctionNumberIsNotAvailable_1Param,
+            theFunctionNumber),
+        theResult.getMemoryManager())
 {
 }
 
 
 
 XPathExceptionFunctionNotAvailable::XPathExceptionFunctionNotAvailable(
-			int					theFunctionNumber,
-			const LocatorType&	theLocator) :
+			const XalanDOMString&	theFunctionNumber,
+			const LocatorType&	    theLocator,
+            XalanDOMString&         theResult) :
 	XalanXPathException(
-					theLocator,
-					XalanMessageLoader::getMessage(XalanMessages::FunctionNumberIsNotAvailable_1Param,LongToDOMString(theFunctionNumber)))
-{
-}
-
-
-
-XPathExceptionFunctionNotAvailable::XPathExceptionFunctionNotAvailable(
-			const XalanDOMString&	theFunctionName,
-			const LocatorType&		theLocator) :
-	XalanXPathException(
-					theLocator,
-					XalanMessageLoader::getMessage(XalanMessages::SpecifiedFuncIsNotAvailable_1Param, theFunctionName))
+	    theLocator,
+		XalanMessageLoader::getMessage(
+            theResult,
+            XalanMessages::FunctionNumberIsNotAvailable_1Param,
+            theFunctionNumber),
+        theResult.getMemoryManager())
 {
 }
 
@@ -547,8 +555,15 @@ XPathExceptionFunctionNotAvailable::~XPathExceptionFunctionNotAvailable()
 
 
 
-XPathExceptionFunctionNotSupported::XPathExceptionFunctionNotSupported(const XalanDOMChar*	theFunctionName) :
-	XalanXPathException(XalanMessageLoader::getMessage(XalanMessages::FunctionIsNotSupported_1Param,XalanDOMString(theFunctionName)))
+XPathExceptionFunctionNotSupported::XPathExceptionFunctionNotSupported(
+            const XalanDOMChar*     theFunctionName,
+            XalanDOMString&         theResult) :
+    XalanXPathException(
+        XalanMessageLoader::getMessage(
+            theResult,
+            XalanMessages::FunctionIsNotSupported_1Param,
+            theFunctionName),
+        theResult.getMemoryManager())
 {
 }
 
