@@ -18,6 +18,7 @@
 
 
 
+#include "FunctionLang.hpp"
 #include "XObject.hpp"
 #include "XUnknown.hpp"
 #include "XPath.hpp"
@@ -34,20 +35,30 @@ unsigned long	XPathInit::s_initCounter = 0;
 
 
 
-XPathInit::XPathInit() :
-	m_platformSupportInit(),
-	m_domSupportInit()
+XPathInit::XPathInit(MemoryManagerType& theManager) :
+	m_platformSupportInit(theManager),
+	m_domSupportInit(theManager)
 {
 	++s_initCounter;
 
 	if (s_initCounter == 1)
 	{
-		initialize();
+		initialize(theManager);
 	}
 }
 
 
 
+XPathInit*
+XPathInit::create(MemoryManagerType&    theManager)
+{
+    XPathInit*  theResult;
+
+    return XalanConstruct(theManager, theResult, theManager);
+}
+
+
+
 XPathInit::~XPathInit()
 {
 	--s_initCounter;
@@ -61,15 +72,17 @@ XPathInit::~XPathInit()
 
 
 void
-XPathInit::initialize()
+XPathInit::initialize(MemoryManagerType& theManager)
 {
-	XObject::initialize();
+    FunctionLang::initialize(theManager);
 
-	XUnknown::initialize();
+    XObject::initialize(theManager);
 
-	XPath::initialize();
+	XUnknown::initialize(theManager);
 
-	XPathEnvSupportDefault::initialize();
+	XPath::initialize(theManager);
+
+	XPathEnvSupportDefault::initialize(theManager);
 }
 
 
@@ -84,6 +97,8 @@ XPathInit::terminate()
 	XUnknown::terminate();
 
 	XObject::terminate();
+
+    FunctionLang::terminate();
 }
 
 
