@@ -21,6 +21,31 @@
 XALAN_CPP_NAMESPACE_BEGIN
 
 
+const XalanDOMChar	XPathParserException::m_type[] = 
+{	
+	XalanUnicode::charLetter_X,
+	XalanUnicode::charLetter_P,
+	XalanUnicode::charLetter_a,
+	XalanUnicode::charLetter_t,
+	XalanUnicode::charLetter_h,
+	XalanUnicode::charLetter_P,
+	XalanUnicode::charLetter_a,
+	XalanUnicode::charLetter_r,
+	XalanUnicode::charLetter_s,
+	XalanUnicode::charLetter_e,
+	XalanUnicode::charLetter_r,
+	XalanUnicode::charLetter_E,
+	XalanUnicode::charLetter_x,
+	XalanUnicode::charLetter_c,
+	XalanUnicode::charLetter_e,
+	XalanUnicode::charLetter_p,
+	XalanUnicode::charLetter_t,
+	XalanUnicode::charLetter_i,
+	XalanUnicode::charLetter_o,
+	XalanUnicode::charLetter_n,
+	0
+};
+
 
 
 XPathParserException::XPathParserException(
@@ -28,8 +53,8 @@ XPathParserException::XPathParserException(
 			const XalanDOMString&	theURI,
 			int						theLineNumber,
 			int						theColumnNumber,
-			const XalanDOMString&	theType) :
-	XalanXPathException(message, theURI, theLineNumber, theColumnNumber, theType)
+            MemoryManagerType&      theManager) :
+	XalanXPathException(message, theURI, theLineNumber, theColumnNumber, theManager)
 {
 }
 
@@ -38,8 +63,8 @@ XPathParserException::XPathParserException(
 XPathParserException::XPathParserException(
 			const LocatorType&		theLocator,
 			const XalanDOMString&	theMessage,
-			const XalanDOMString&	theType) :
-	XalanXPathException(theLocator, theMessage, theType)
+            MemoryManagerType&      theManager) :
+	XalanXPathException(theLocator, theMessage, theManager)
 {
 }
 
@@ -47,8 +72,8 @@ XPathParserException::XPathParserException(
 
 XPathParserException::XPathParserException(
 			const XalanDOMString&	message,
-			const XalanDOMString&	theType) :
-	XalanXPathException(message, theType)
+            MemoryManagerType&      theManager) :
+	XalanXPathException(message, theManager)
 {
 }
 
