@@ -24,13 +24,14 @@
 
 
 
-#include <deque>
-#include <map>
-#include <vector>
-
-
-
 #include <xalanc/XalanDOM/XalanNode.hpp>
+#include <xalanc/XalanDOM/XalanDOMString.hpp>
+
+
+
+#include <xalanc/Include/XalanVector.hpp>
+#include <xalanc/Include/XalanMap.hpp>
+
 
 
 #include <xalanc/PlatformSupport/PrefixResolver.hpp>
@@ -45,6 +46,7 @@
 
 #include <xalanc/XSLT/NamespacesHandler.hpp>
 #include <xalanc/XSLT/KeyDeclaration.hpp>
+#include <xalanc/XSLT/StylesheetConstructionContext.hpp>
 #include <xalanc/XSLT/StylesheetExecutionContext.hpp>
 #include <xalanc/XSLT/XalanSpaceNodeTester.hpp>
 
@@ -65,11 +67,15 @@ class NodeRefListBase;
 class PrefixResolver;
 class StylesheetConstructionContext;
 class StylesheetRoot;
+class XalanMatchPatternData;
 class XalanQName;
 class XObject;
 class StylesheetExecutionContext;
 
 
+typedef XalanVector<const XalanMatchPatternData*>	PatternTableVectorTypeDecl;
+XALAN_USES_MEMORY_MANAGER(PatternTableVectorTypeDecl)
+
 
 /**
  * This class represents the base stylesheet or an "import" stylesheet.
@@ -80,45 +86,29 @@ class XALAN_XSLT_EXPORT Stylesheet : protected PrefixResolver
 
 public:
 
-#if defined(XALAN_STRICT_ANSI_HEADERS)
-	typedef std::size_t		size_type;
-#else
-	typedef size_t			size_type;
-#endif
-
+    typedef StylesheetConstructionContext::size_type        size_type;
 	typedef StylesheetExecutionContext::ParamVectorType		ParamVectorType;
 	typedef XalanQName::NamespaceVectorType					NamespaceVectorType;
 	typedef XalanQName::NamespacesStackType					NamespacesStackType;
 
-#if defined(XALAN_NO_STD_NAMESPACE)
-	typedef map<XalanDOMString,
-				ExtensionNSHandler*,
-				less<XalanDOMString> >				ExtensionNamespacesMapType;
-	typedef map<XalanQNameByReference,
-				const ElemTemplate*,
-				less<XalanQName> >					ElemTemplateMapType;
-	typedef vector<ElemVariable*> 					ElemVariableVectorType;
-	typedef vector<KeyDeclaration>					KeyDeclarationVectorType;
-	typedef map<const XalanNode*,
-				KeyTable*,
-				less<const XalanNode*> >			KeyTablesTableType;
-	typedef vector<Stylesheet*>						StylesheetVectorType;
-	typedef vector<XalanDOMString>					URLStackType;
-	typedef vector<ElemDecimalFormat*>				ElemDecimalFormatVectorType;
-	typedef vector<XalanSpaceNodeTester>			WhitespaceElementsVectorType;
-#else
-	typedef std::map<XalanDOMString, ExtensionNSHandler*>	ExtensionNamespacesMapType;
-	typedef std::map<XalanQNameByReference,
-					 const ElemTemplate*,
-					 std::less<XalanQName> >				ElemTemplateMapType;
-	typedef std::vector<ElemVariable*> 						ElemVariableVectorType;
-	typedef std::vector<KeyDeclaration>						KeyDeclarationVectorType;
-	typedef std::map<const XalanNode*, KeyTable*>			KeyTablesTableType;
-	typedef std::vector<Stylesheet*>						StylesheetVectorType;
-	typedef std::vector<XalanDOMString>						URLStackType;
-	typedef std::vector<ElemDecimalFormat*>					ElemDecimalFormatVectorType;
-	typedef std::vector<XalanSpaceNodeTester>				WhitespaceElementsVectorType;
-#endif
+	typedef XalanVector<ElemVariable*> 					ElemVariableVectorType;
+	typedef XalanVector<KeyDeclaration>					KeyDeclarationVectorType;
+	typedef XalanVector<Stylesheet*>					StylesheetVectorType;
+	typedef XalanVector<XalanDOMString>					URLStackType;
+	typedef XalanVector<ElemDecimalFormat*>				ElemDecimalFormatVectorType;
+	typedef XalanVector<XalanSpaceNodeTester>			WhitespaceElementsVectorType;
+    typedef PatternTableVectorTypeDecl					PatternTableVectorType;
+	
+	typedef  XalanMap<XalanDOMString, ExtensionNSHandler*>		ExtensionNamespacesMapType;
+
+    typedef  XalanMap<XalanQNameByReference,
+						 const ElemTemplate* >		ElemTemplateMapType;
+
+    typedef XalanMap<const XalanNode*, KeyTable* >	KeyTablesTableType;
+
+	typedef XalanMap<XalanDOMString, PatternTableVectorType> PatternTableMapType;
+
+    typedef StylesheetConstructionContext::GetAndReleaseCachedString    GetAndReleaseCachedString;
 
 	/**
 	 * Constructor for a Stylesheet needs a Document.
@@ -133,6 +123,18 @@ public:
 	virtual
 	~Stylesheet();
 
+    static Stylesheet*
+    create(MemoryManagerType& theManager,
+            StylesheetRoot& 				root,
+			const XalanDOMString&			baseIdentifier,
+			StylesheetConstructionContext&	constructionContext);
+
+    MemoryManagerType&
+    getMemoryManager()
+    {
+        return m_elementPatternTable.getMemoryManager();
+    }
+
 	/**
 	 * Retrieve XSLT version number
 	 * 
@@ -296,9 +298,10 @@ public:
 	 * @return namespace string for node, or null if not found.
 	 */
 	const XalanDOMString*
-	getNamespaceFromStack(const XalanDOMString& 	nodeName) const
+	getNamespaceFromStack(const XalanDOMString& 	nodeName,
+                            XalanDOMString&         theBuffer) const
 	{
-		return getNamespaceFromStack(c_wstr(nodeName));
+		return getNamespaceFromStack(c_wstr(nodeName), theBuffer);
 	}
 
 	/**
@@ -308,7 +311,8 @@ public:
 	 * @return namespace string for node, or null if not found.
 	 */
 	const XalanDOMString*
-	getNamespaceFromStack(const XalanDOMChar* 	nodeName) const;
+	getNamespaceFromStack(const XalanDOMChar* 	nodeName,
+                            XalanDOMString&     theBuffer) const;
 
 	/**
 	 * Get the namespace from a prefix by searching the stack of namespace
@@ -335,7 +339,7 @@ public:
 	{
 		assert(prefix != 0);
 
-		return XalanQName::getNamespaceForPrefix(m_namespaces, XalanDOMString(prefix));
+		return XalanQName::getNamespaceForPrefix(m_namespaces, (const XalanDOMChar*)prefix);
 	}
 
 	/**
@@ -568,147 +572,6 @@ public:
 			const XalanQName&				mode,
 			bool							onlyUseImports) const;
 
-	/**
-	 * A class to contain a match pattern and it's corresponding template.
-	 * This class also defines a node in a match pattern linked list.
-	 */
-	class MatchPattern2
-	{
-	public:
-
-		typedef XPath::eMatchScore	eMatchScore;
-
-		/**
-		 * Construct a match pattern from a pattern and template.
-		 *
-		 * @param theTemplate node that contains the template for this pattern
-		 * @param posInStylesheet position in stylesheet
-		 * @param targetString target string
-		 * @param matchPattern the match pattern
-		 * @param pattern the pattern string
-		 * @param priority the default priority
-		 */
-		MatchPattern2(
-				const ElemTemplate&		theTemplate,
-				size_type 				posInStylesheet,
-				const XalanDOMString&	targetString,
-				const XPath&			matchPattern,
-				const XalanDOMString&	pattern,
-				eMatchScore				priority) :
-			m_template(&theTemplate),
-			m_posInStylesheet(posInStylesheet),
-			m_targetString(targetString),
-			m_matchPattern(&matchPattern),
-			m_pattern(&pattern),
-			m_priority(priority)
-		{
-		}
-
-		MatchPattern2() :
-			m_template(0),
-			m_posInStylesheet(0),
-			m_targetString(),
-			m_matchPattern(0),
-			m_pattern(0),
-			m_priority(XPath::eMatchScoreNone)
-		{
-		}
-
-		~MatchPattern2()
-		{
-		}
-
-		/**
-		 * Retrieve string for target.
-		 * 
-		 * @return target string
-		 */
-		const XalanDOMString&
-		getTargetString() const
-		{
-			return m_targetString;
-		}
-
-		/**
-		 * Retrieve the match pattern associated with pattern.
-		 * 
-		 * @return XPath for pattern
-		 */
-		const XPath*
-		getExpression() const
-		{
-			return m_matchPattern;
-		}
-
-		/**
-		 * Retrieve position of pattern in stylesheet.
-		 * 
-		 * @return position in stylesheet
-		 */
-		size_type
-		getPositionInStylesheet() const
-		{
-			return m_posInStylesheet;
-		}
-
-		/**
-		 * Retrieve pattern string.
-		 * 
-		 * @return string that contains element pattern
-		 */
-		const XalanDOMString*
-		getPattern() const
-		{
-			return m_pattern;
-		}
-
-		/**
-		 * Retrieve node that contains the template for this pattern.
-		 * 
-		 * @return template node
-		 */
-		const ElemTemplate*
-		getTemplate() const
-		{
-			return m_template;
-		}
-
-		eMatchScore
-		getDefaultPriority() const
-		{
-			return m_priority;
-		}
-
-		double
-		getPriorityOrDefault() const;
-
-	private:
-
-		const ElemTemplate*		m_template;
-		size_type				m_posInStylesheet;
-		XalanDOMString			m_targetString;
-		const XPath*			m_matchPattern;
-		const XalanDOMString*	m_pattern;
-		eMatchScore				m_priority;
-	};
-
-#if defined(XALAN_NO_STD_NAMESPACE)
-	typedef vector<const MatchPattern2*>		PatternTableVectorType;
-
-	typedef map<XalanDOMString,
-			    PatternTableVectorType,
-				less<XalanDOMString> >			PatternTableMapType;
-
-	typedef deque<MatchPattern2>				MatchPattern2Container;
-#else
-	typedef std::vector<const MatchPattern2*>	PatternTableVectorType;
-
-	typedef std::map<XalanDOMString,
-					 PatternTableVectorType>	PatternTableMapType;
-
-	typedef std::deque<MatchPattern2>			MatchPattern2Container;
-#endif
-
 	/**
 	 * Add object to vector of match patterns if not already there.
 	 *
@@ -717,8 +580,8 @@ public:
 	 */
 	static void
 	addObjectIfNotFound(
-			const MatchPattern2*		thePattern,
-			PatternTableVectorType& 	theVector);
+			const XalanMatchPatternData*    thePattern,
+			PatternTableVectorType& 	    theVector);
 
 	/**
 	 * Add object to array of match patterns if not already there.
@@ -731,9 +594,9 @@ public:
 	 */
 	static void
 	addObjectIfNotFound(
-			const MatchPattern2*	thePattern,
-			const MatchPattern2* 	theArray[],
-			unsigned int&			theArraySize);
+			const XalanMatchPatternData*    thePattern,
+			const XalanMatchPatternData* 	theArray[],
+			unsigned int&			        theArraySize);
 
 	/**
 	 * Given a name, locate the start of a list of 
@@ -743,7 +606,7 @@ public:
 	 * @param theName The name to match
 	 */
 	const PatternTableVectorType*
-	locateElementMatchPatternList2(const XalanDOMString&	theName) const;
+	locateElementMatchPatternDataList(const XalanDOMString&	    theName) const;
 
 	/**
 	 * Given a name, locate the start of a list of 
@@ -753,7 +616,7 @@ public:
 	 * @param theName The name to match
 	 */
 	const PatternTableVectorType*
-	locateAttributeMatchPatternList2(const XalanDOMString&	theName) const;
+	locateAttributeMatchPatternDataList(const XalanDOMString&	theName) const;
 
 	/**
 	 * Given a XalanNode, locate the start of a list of 
@@ -762,7 +625,7 @@ public:
 	 * @param XalanNode The node to match
 	 */
 	const PatternTableVectorType*
-	locateMatchPatternList2(
+	locateMatchPatternDataList(
 			const XalanNode&		theNode,
 			XalanNode::NodeType		targetNodeType) const;
 
@@ -997,16 +860,7 @@ private:
 	 */
 	PatternTableVectorType					m_nodePatternList;
 
-	/**
-	 * This will hold all of the MatchPattern2 instances for the
-	 * stylesheet.
-	 */
-	MatchPattern2Container					m_matchPattern2Container;
-
-	/**
-	 * This caches the number of possible patterns we can match.
-	 */
-	MatchPattern2Container::size_type		m_patternCount;
+	size_type	                            m_patternCount;
 
 	ElemDecimalFormatVectorType				m_elemDecimalFormats;
 
