@@ -32,6 +32,7 @@
 
 
 #include <xalanc/XPath/XalanQName.hpp>
+#include <xalanc/XPath/XPath.hpp>
 #include <xalanc/XPath/XPathConstructionContext.hpp>
 
 
@@ -52,14 +53,15 @@ typedef XERCES_CPP_NAMESPACE_QUALIFIER DocumentHandler	DocumentHandlerType;
 
 class AVT;
 class AVTPart;
+class ElemTemplate;
 class ElemTemplateElement;
 class ExtensionNSHandler;
 class PrefixResolver;
 class Stylesheet;
 class StylesheetRoot;
 class XalanDocument;
+class XalanMatchPatternData;
 class XalanNode;
-class XPath;
 class XSLTInputSource;
 
 
@@ -151,7 +153,7 @@ public:
 	typedef URISupport::URLAutoPtrType	URLAutoPtrType;
 
 	explicit
-	StylesheetConstructionContext();
+	StylesheetConstructionContext(MemoryManagerType&  theManager);
 
 	virtual
 	~StylesheetConstructionContext();
@@ -224,8 +226,9 @@ public:
 	 * @param urlString string to qualify
 	 * @return string to fully qualified URI
 	 */
-	virtual XalanDOMString
-	getURLStringFromString(const XalanDOMString&	urlString) = 0;
+	virtual XalanDOMString&
+	getURLStringFromString(const XalanDOMString&	urlString,
+                            XalanDOMString& theResult) = 0;
 
 	/**
 	 * Determine the fully qualified URI for a string.
@@ -246,10 +249,11 @@ public:
 	 * @param base base location for URI
 	 * @return string to fully qualified URI
 	 */
-	virtual XalanDOMString
+	virtual XalanDOMString&
 	getURLStringFromString(
 			const XalanDOMString&	urlString,
-			const XalanDOMString&	base) = 0;
+			const XalanDOMString&	base,
+            XalanDOMString& theResult) = 0;
 
 	/**
 	 * Retrieve the URI for the current XSLT namespace, for example,
@@ -268,13 +272,17 @@ public:
 	 * @param locator the locator for the XPath. May be null.
 	 * @param str string to match
 	 * @param resolver resolver for namespace resolution
+     * @param allowVariableReferences If true, variable references are allowed.
+     * @param allowKeyFunction If true, calls to the key() function are allowed.
 	 * @return XPath for match pattern
 	 */
 	virtual XPath*
 	createMatchPattern(
 			const LocatorType*		locator,
 			const XalanDOMString&	str,
-			const PrefixResolver&	resolver) = 0;
+			const PrefixResolver&	resolver,
+            bool                    allowVariableReferences = true,
+            bool                    allowKeyFunction = true) = 0;
 
 	/**
 	 * Create and initialize an xpath for a match pattern and return it. This
@@ -284,13 +292,17 @@ public:
 	 * @param locator the locator for the XPath. May be null.
 	 * @param str string to match
 	 * @param resolver resolver for namespace resolution
+     * @param allowVariableReferences If true, variable references are allowed.
+     * @param allowKeyFunction If true, calls to the key() function are allowed.
 	 * @return XPath for match pattern
 	 */
 	virtual XPath*
 	createMatchPattern(
 			const LocatorType*		locator,
 			const XalanDOMChar*		str,
-			const PrefixResolver&	resolver) = 0;
+			const PrefixResolver&	resolver,
+            bool                    allowVariableReferences = true,
+            bool                    allowKeyFunction = true) = 0;
 
 	/**
 	 * Create and initialize an xpath and return it. This is to be used by
@@ -306,7 +318,9 @@ public:
 	createXPath(
 			const LocatorType*		locator,
 			const XalanDOMString&	str,
-			const PrefixResolver&	resolver) = 0;
+			const PrefixResolver&	resolver,
+            bool                    allowVariableReferences = true,
+            bool                    allowKeyFunction = true) = 0;
 
 	/**
 	 * Create and initialize an xpath and return it. This is to be used by
@@ -322,7 +336,9 @@ public:
 	createXPath(
 			const LocatorType*		locator,
 			const XalanDOMChar*		str,
-			const PrefixResolver&	resolver) = 0;
+			const PrefixResolver&	resolver,
+            bool                    allowVariableReferences = true,
+            bool                    allowKeyFunction = true) = 0;
 
 	/**
 	 * Create and initialize an xpath and return it. This is to be used by
@@ -339,7 +355,9 @@ public:
 			const LocatorType*			locator,
 			const XalanDOMChar*			str,
 			XalanDOMString::size_type	len,
-			const PrefixResolver&		resolver) = 0;
+			const PrefixResolver&		resolver,
+            bool                        allowVariableReferences = true,
+            bool                        allowKeyFunction = true) = 0;
 
 	/**
 	 * Get the locator from the top of the locator stack.
@@ -692,6 +710,32 @@ public:
 			ExtensionNSHandler&			handler,
 			const LocatorType*			locator = 0) = 0;
 
+	/**
+	 * Create an instance of XalanMatchPatternData, which describes
+	 * data related to a match pattern and template in stylesheet.
+	 * The instance owns the memory and will delete the element when
+	 * it goes out of scope and the containing stylesheet is
+	 * destroyed.
+     *
+     * @param theTemplate The ElemTemplate node that contains the template for this pattern
+     * @param thePosition The position in the stylesheet
+     * @param theTargetString The target string for match pattern
+     * @param TheMatchPattern The match pattern
+     * @param thePatternString the pattern string
+     * @param thePriority The priority for the match pattern.
+     *
+     * @return A pointer to the new instance.
+	 */
+    virtual const XalanMatchPatternData*
+    createXalanMatchPatternData(
+            const ElemTemplate&     theTemplate,
+            size_type               thePosition,
+            const XalanDOMString&   theTargetString,
+            const XPath&            theMatchPattern,
+            const XalanDOMString&   thePatternString,
+            XPath::eMatchScore      thePriority) = 0;
+
+
 	// These are inherited from XPathConstructionContext...
 
 	virtual void
@@ -706,18 +750,6 @@ public:
 			const XalanNode* 		sourceNode,
 			const LocatorType* 		locator) const = 0;
 
-	virtual void
-	error(
-			const char*					msg,
-			const XalanNode* 			sourceNode = 0,
-			const ElemTemplateElement* 	styleNode = 0) const = 0;
-
-	virtual void
-	error(
-			const char*			msg,
-			const XalanNode* 	sourceNode,
-			const LocatorType* 	locator) const = 0;
-
 	virtual void
 	warn(
 			const XalanDOMString&		msg,
@@ -730,18 +762,6 @@ public:
 			const XalanNode* 		sourceNode,
 			const LocatorType* 		locator) const = 0;
 
-	virtual void
-	warn(
-			const char*					msg,
-			const XalanNode* 			sourceNode = 0,
-			const ElemTemplateElement* 	styleNode = 0) const = 0;
-
-	virtual void
-	warn(
-			const char*			msg,
-			const XalanNode* 	sourceNode,
-			const LocatorType* 	locator) const = 0;
-
 	virtual void
 	message(
 			const XalanDOMString&		msg,
@@ -754,17 +774,6 @@ public:
 			const XalanNode* 		sourceNode,
 			const LocatorType* 		locator) const = 0;
 
-	virtual void
-	message(
-			const char*					msg,
-			const XalanNode* 			sourceNode = 0,
-			const ElemTemplateElement* 	styleNode = 0) const = 0;
-
-	virtual void
-	message(
-			const char*			msg,
-			const XalanNode* 	sourceNode,
-			const LocatorType* 	locator) const = 0;
 };
 
 
