@@ -23,7 +23,7 @@
 
 
 
-#include <vector>
+#include <xalanc/Include/XalanVector.hpp>
 
 
 
@@ -39,7 +39,7 @@
 
 
 
-#include <xalanc/Include/XalanAutoPtr.hpp>
+#include <xalanc/Include/XalanMemMgrAutoPtr.hpp>
 
 
 
@@ -74,6 +74,7 @@
 #include <xalanc/XSLT/XalanElemTextLiteralAllocator.hpp>
 #include <xalanc/XSLT/XalanElemValueOfAllocator.hpp>
 #include <xalanc/XSLT/XalanElemVariableAllocator.hpp>
+#include "xalanc/XSLT/XalanMatchPatternDataAllocator.hpp"
 
 
 
@@ -119,7 +120,8 @@ public:
 			eDefaultElemTemplateBlockSize = 10,
 			eDefaultElemTextLiteralBlockSize = 20,
 			eDefaultElemValueOfBlockSize = 10,
-			eDefaultElemVariableBlockSize = 10 };
+			eDefaultElemVariableBlockSize = 10,
+            eDefaultMatchPatternDataBlockSize = 10 };
 
 	/*
 	 * Construct an instance.  If the stylesheet(s) constructed is/are meant to be reused (a.k.a. "compiled"),
@@ -138,6 +140,7 @@ public:
 	 * @param thePointerVectorAllocatorBlockSize The block size to use for allocating vectors of pointers.
 	 */
 	StylesheetConstructionContextDefault(
+            MemoryManagerType&                      theManager,
 			XSLTEngineImpl&							processor,
 			XPathFactory&							xpathFactory,
 			VectorAllocatorSizeType					theXalanDOMCharVectorAllocatorBlockSize = eDefaultXalanDOMCharVectorBlockSize,
@@ -163,18 +166,6 @@ public:
 			const XalanNode* 		sourceNode,
 			const LocatorType* 		locator) const;
 
-	virtual void
-	error(
-			const char*					msg,
-			const XalanNode* 			sourceNode = 0,
-			const ElemTemplateElement* 	styleNode = 0) const;
-
-	virtual void
-	error(
-			const char*			msg,
-			const XalanNode* 	sourceNode,
-			const LocatorType* 	locator) const;
-
 	virtual void
 	warn(
 			const XalanDOMString&		msg,
@@ -187,18 +178,6 @@ public:
 			const XalanNode* 		sourceNode,
 			const LocatorType* 		locator) const;
 
-	virtual void
-	warn(
-			const char*					msg,
-			const XalanNode* 			sourceNode = 0,
-			const ElemTemplateElement* 	styleNode = 0) const;
-
-	virtual void
-	warn(
-			const char*			msg,
-			const XalanNode* 	sourceNode,
-			const LocatorType* 	locator) const;
-
 	virtual void
 	message(
 			const XalanDOMString&		msg,
@@ -211,18 +190,6 @@ public:
 			const XalanNode* 		sourceNode,
 			const LocatorType*		locator) const;
 
-	virtual void
-	message(
-			const char*					msg,
-			const XalanNode* 			sourceNode = 0,
-			const ElemTemplateElement* 	styleNode = 0) const;
-
-	virtual void
-	message(
-			const char*			msg,
-			const XalanNode* 	sourceNode,
-			const LocatorType* 	locator) const;
-
 	// These interfaces are inherited from StylesheetConstructionContext...
 
 	virtual void
@@ -245,18 +212,20 @@ public:
 	virtual URLAutoPtrType
 	getURLFromString(const XalanDOMString&	urlString);
 
-	virtual XalanDOMString
-	getURLStringFromString(const XalanDOMString&	urlString);
+	virtual XalanDOMString&
+	getURLStringFromString(const XalanDOMString&	urlString,
+                            XalanDOMString& theResult);
 
 	virtual URLAutoPtrType
 	getURLFromString(
 			const XalanDOMString&	urlString,
 			const XalanDOMString&	base);
 
-	virtual XalanDOMString
+	virtual XalanDOMString&
 	getURLStringFromString(
 			const XalanDOMString&	urlString,
-			const XalanDOMString&	base);
+			const XalanDOMString&	base,
+            XalanDOMString& theResult);
 
 	virtual const XalanDOMString&
 	getXSLTNamespaceURI() const;
@@ -265,32 +234,42 @@ public:
 	createMatchPattern(
 			const LocatorType*		locator,
 			const XalanDOMString&	str,
-			const PrefixResolver&	resolver);
+			const PrefixResolver&	resolver,
+            bool                    allowVariableReferences = true,
+            bool                    allowKeyFunction = true);
 
 	virtual XPath*
 	createMatchPattern(
 			const LocatorType*		locator,
 			const XalanDOMChar*		str,
-			const PrefixResolver&	resolver);
+			const PrefixResolver&	resolver,
+            bool                    allowVariableReferences = true,
+            bool                    allowKeyFunction = true);
 
 	virtual XPath*
 	createXPath(
 			const LocatorType*		locator,
 			const XalanDOMString&	str,
-			const PrefixResolver&	resolver);
+			const PrefixResolver&	resolver,
+            bool                    allowVariableReferences = true,
+            bool                    allowKeyFunction = true);
+
+	virtual XPath*
+	createXPath(
+			const LocatorType*		locator,
+			const XalanDOMChar*		str,
+			const PrefixResolver&	resolver,
+            bool                    allowVariableReferences = true,
+            bool                    allowKeyFunction = true);
 
 	virtual XPath*
 	createXPath(
 			const LocatorType*			locator,
 			const XalanDOMChar*			str,
 			XalanDOMString::size_type	len,
-			const PrefixResolver&		resolver);
-
-	virtual XPath*
-	createXPath(
-			const LocatorType*		locator,
-			const XalanDOMChar*		str,
-			const PrefixResolver&	resolver);
+			const PrefixResolver&		resolver,
+            bool                        allowVariableReferences = true,
+            bool                        allowKeyFunction = true);
 
 	virtual const LocatorType*
 	getLocatorFromStack() const;
@@ -436,16 +415,20 @@ public:
 			ExtensionNSHandler&			handler,
 			const LocatorType*			locator = 0);
 
+    virtual const XalanMatchPatternData*
+    createXalanMatchPatternData(
+            const ElemTemplate&     theTemplate,
+            size_type               thePosition,
+            const XalanDOMString&   theTargetString,
+            const XPath&            theMatchPattern,
+            const XalanDOMString&   thePatternString,
+            XPath::eMatchScore      thePriority);
+
 	static eElementToken
 	getElementNameToken(const XalanDOMString&	name);
 
-#if defined(XALAN_NO_STD_NAMESPACE)
-	typedef vector<StylesheetRoot*>			StylesheetVectorType;
-	typedef vector<ElemTemplateElement*>	ElemTemplateElementVectorType;
-#else
-	typedef std::vector<StylesheetRoot*>		StylesheetVectorType;
-	typedef std::vector<ElemTemplateElement*>	ElemTemplateElementVectorType;
-#endif
+	typedef XalanVector<StylesheetRoot*>			StylesheetVectorType;
+	typedef XalanVector<ElemTemplateElement*>	ElemTemplateElementVectorType;
 
 private:
 
@@ -490,7 +473,7 @@ private:
 
 	XPathFactory&							m_xpathFactory;
 
-	typedef XalanAutoPtr<XPathProcessor>	XPathProcessAutoPtr;
+	typedef XalanMemMgrAutoPtr<XPathProcessor, true>	XPathProcessAutoPtr;
 
 	XPathProcessAutoPtr						m_xpathProcessor;
 
@@ -540,6 +523,8 @@ private:
 
 	XalanElemVariableAllocator				m_elemVariableAllocator;
 
+    XalanMatchPatternDataAllocator          m_matchPatternDataAllocator;
+
 	const XalanQNameByReference				m_spaceAttrQName;
 
 	// Static strings for stylesheet compilation...
