@@ -31,9 +31,6 @@
 
 // Standard library headers
 #include <cassert>
-#include <ctime>
-#include <map>
-#include <set>
 
 
 
@@ -47,7 +44,8 @@
 
 
 
-#include <xalanc/Include/XalanAutoPtr.hpp>
+#include <xalanc/Include/XalanMemMgrAutoPtr.hpp>
+#include <xalanc/Include/XalanMap.hpp>
 
 
 
@@ -96,7 +94,6 @@ class DOMSupport;
 class GenerateEvent;
 class PrintWriter;
 class StylesheetConstructionContext;
-class StylesheetExecutionContext;
 class StylesheetRoot;
 class XalanAttr;
 class XalanSourceTreeDocument;
@@ -126,12 +123,6 @@ class XALAN_XSLT_EXPORT XSLTEngineImpl : public XSLTProcessor, public PrefixReso
 {
 public:
 
-#if defined(XALAN_STRICT_ANSI_HEADERS)
-	typedef std::clock_t	ClockType;
-#else
-	typedef clock_t			ClockType;
-#endif
-
 	struct LessXalanDOMStringPointers
 	{
 		bool
@@ -154,29 +145,11 @@ public:
 		}
 	};
 
-#if defined(XALAN_NO_STD_NAMESPACE)
-	typedef map<const void*,
-				ClockType,
-				less<const void*> >			DurationsTableMapType;
-	typedef vector<const LocatorType*>		LocatorStack;
-	typedef vector<TraceListener*>			TraceListenerVectorType;
-#if defined(XALAN_USE_DEQUE_FOR_VECTOR_BOOL)
-	typedef deque<bool>						BoolVectorType;
-#else
-	typedef vector<bool>					BoolVectorType;
-#endif
-	typedef vector<const XalanDOMString*>	XalanDOMStringPointerVectorType;
-#else
-	typedef std::map<const void*, ClockType>	DurationsTableMapType;
-	typedef std::vector<const LocatorType*>		LocatorStack;
-	typedef std::vector<TraceListener*>			TraceListenerVectorType;
-#if defined(XALAN_USE_DEQUE_FOR_VECTOR_BOOL)
-	typedef std::deque<bool>					BoolVectorType;
-#else
-	typedef std::vector<bool>					BoolVectorType;
-#endif
-	typedef std::vector<const XalanDOMString*>	XalanDOMStringPointerVectorType;
-#endif
+	typedef XalanVector<const LocatorType*>		LocatorStack;
+	typedef XalanVector<TraceListener*>			TraceListenerVectorType;
+	typedef XalanVector<const XalanDOMString*>	XalanDOMStringPointerVectorType;
+
+	typedef XalanVector<bool>							BoolVectorType;
 
 	struct FindStringPointerFunctor
 	{
@@ -198,9 +171,11 @@ public:
 		const XalanDOMString&	m_string;
 	};
 
-	typedef XalanAutoPtr<XPathProcessor>				XPathProcessorPtrType;
+	typedef XalanMemMgrAutoPtr<XPathProcessor, true>				XPathProcessorPtrType;
 	typedef Function::XObjectArgVectorType				XObjectArgVectorType;
 	typedef StylesheetExecutionContext::ParamVectorType	ParamVectorType;
+    typedef XPathConstructionContext::GetAndReleaseCachedString     CCGetAndReleaseCachedString;
+    typedef XPathExecutionContext::GetAndReleaseCachedString        ECGetAndReleaseCachedString;
 
 	// Public members
 	//---------------------------------------------------------------------
@@ -218,6 +193,7 @@ public:
 	 * @param xpathFactory	   object responsible for XPath objects
 	 */
 	XSLTEngineImpl(
+            MemoryManagerType&  theManager,
 			XMLParserLiaison&	parserLiaison,
 			XPathEnvSupport&	xpathEnvSupport,
 			DOMSupport&			domSupport,
@@ -227,12 +203,18 @@ public:
 	virtual
 	~XSLTEngineImpl();
 
+    MemoryManagerType&
+    getMemoryManager()
+    {
+        return m_xpathConstructionContext.getMemoryManager();
+    }
+
 	/**
 	 * Perform initialization of statics -- must be called before any
 	 * processing occurs.  See class XSLTInit.
 	 */
 	static void
-	initialize();
+	initialize(MemoryManagerType&      theManager);
 
 	/**
 	 * Perform termination of statics.  See class XSLTInit.
@@ -275,9 +257,6 @@ public:
 	virtual XMLParserLiaison&
 	getXMLParserLiaison() const;
 
-	virtual const XalanDOMString
-	getUniqueNamespaceValue();
-
 	virtual void
 	getUniqueNamespaceValue(XalanDOMString&		theValue);
 
@@ -461,17 +440,23 @@ public:
 	 * @param attList attribute list added to
 	 * @param aname   name of attribute
 	 * @param value   value of attribute
+     * @param fromCopy true if the attribute is being copied from the source tree
+     * @param locator The Locator for reporting errors.
 	 */
 	void
 	addResultAttribute(
 			AttributeListImpl&		attList,
 			const XalanDOMString&	aname,
-			const XalanDOMString&	value)
+			const XalanDOMString&	value,
+            bool                    fromCopy = false,
+			const LocatorType*	    locator = 0)
 	{
 		addResultAttribute(
 			attList,
 			aname,
-			value.c_str());
+			value.c_str(),
+            fromCopy,
+            locator);
 	}
 
 	/**
@@ -481,12 +466,45 @@ public:
 	 * @param attList attribute list added to
 	 * @param aname name of attribute
 	 * @param value value of attribute
+     * @param fromCopy true if the attribute is being copied from the source tree
+     * @param locator The Locator for reporting errors.
+	 */
+	void
+	addResultAttribute(
+			AttributeListImpl&		attList,
+			const XalanDOMString&	aname,
+			const XalanDOMChar*	    value,
+            bool                    fromCopy = false,
+			const LocatorType*	    locator = 0)
+    {
+	    addResultAttribute(
+			attList,
+			aname,
+            value,
+            length(value),
+            fromCopy,
+            locator);
+    }
+
+	/**
+	 * Add attribute to attribute list, and if it is a namespace, add it to the
+	 * namespaces stack.
+	 *
+	 * @param attList attribute list added to
+	 * @param aname name of attribute
+	 * @param value value of attribute
+     * @param theLength The length of the value
+     * @param fromCopy true if the attribute is being copied from the source tree
+     * @param locator The Locator for reporting errors.
 	 */
 	void
 	addResultAttribute(
 			AttributeListImpl&			attList,
 			const XalanDOMString&		aname,
-			const XalanDOMChar*			value);
+			const XalanDOMChar*			value,
+            XalanDOMString::size_type   theLength,
+            bool                        fromCopy = false,
+			const LocatorType*	        locator = 0);
 
 	/**
 	 * Add attribute to pending attributes list, and if it is a namespace, add
@@ -494,18 +512,24 @@ public:
 	 *
 	 * @param aname name of attribute
 	 * @param value value of attribute
+     * @param fromCopy true if the attribute is being copied from the source tree
+     * @param locator The Locator for reporting errors.
 	 */
 	void
 	addResultAttribute(
 			const XalanDOMString&		aname,
-			const XalanDOMChar*			value)
+			const XalanDOMChar*			value,
+            bool                        fromCopy = false,
+			const LocatorType*	        locator = 0)
 	{
 		assert(m_outputContextStack.empty() == false);
 
 		addResultAttribute(
 				getPendingAttributesImpl(),
 				aname,
-				value);
+				value,
+                fromCopy,
+                locator);
 	}
 
 	/**
@@ -514,20 +538,36 @@ public:
 	 *
 	 * @param aname   name of attribute
 	 * @param value   value of attribute
+     * @param fromCopy true if the attribute is being copied from the source tree
+     * @param locator The Locator for reporting errors.
 	 */
 	void
 	addResultAttribute(
 			const XalanDOMString&	aname,
-			const XalanDOMString&	value)
+			const XalanDOMString&	value,
+            bool                    fromCopy = false,
+			const LocatorType*	    locator = 0)
 	{
 		assert(m_outputContextStack.empty() == false);
 
 		addResultAttribute(
 				getPendingAttributesImpl(),
 				aname,
-				value);
+				value,
+                fromCopy,
+                locator);
 	}
 
+	/**
+	 * Report an error copying a duplicate namespace node.
+	 *
+	 * @param theName The name of the node.
+	 */
+    void
+    reportDuplicateNamespaceNodeError(
+            const XalanDOMString&   theName,
+			const LocatorType*	    locator);
+
 	void
 	setDocumentLocator(const LocatorType*	locator);
 
@@ -814,18 +854,6 @@ public:
 			const XalanNode*			sourceNode = 0,
 			const ElemTemplateElement*	styleNode = 0) const;
 
-	/**
-	 * Report a message
-	 * 
-	 * @param msg		 text of message to output
-	 * @param sourceNode node in source where error occurred
-	 * @param styleNode  node in stylesheet where error occurred
-	 */
-	virtual void
-	warn(
-			const char*					msg,
-			const XalanNode*			sourceNode = 0,
-			const ElemTemplateElement*	styleNode = 0) const;
 
 	virtual void
 	warn(
@@ -847,63 +875,6 @@ public:
 
 public:
 
-	/**
-	 * Mark the time, so that displayDuration can later display the elapsed
-	 * clock ticks.
-	 * 
-	 * @param theKey pointer to element to push
-	 */
-	void
-	pushTime(const void*	key);
-
-	/**
-	 * Returns the duration since pushTime was called for element
-	 * in milliseconds.
-	 *
-	 * @param key pointer to element involved
-	 */
-	ClockType
-	popDuration(const void* 	key);
-
-	/**
-	 * Display the duration since pushTime was called for element in
-	 * milliseconds, and a descriptive message
-	 *
-	 * @param info message to display
-	 * @param key pointer to element involved
-	 */
-	void
-	displayDuration(
-			const XalanDOMString&	info,
-			const void* 			key);
-
-
-	/**
-	 * Whether diagnostic output is to be generated
-	 * 
-	 * @return true for diagnostics output 
-	 */
-	bool doDiagnosticsOutput()
-	{
-		return 0 != m_diagnosticsPrintWriter ? true : false;
-	}
-
-	/**
-	 * Print a diagnostics string to the output device
-	 * 
-	 * @param s string to print
-	 */
-	void
-	diag(const XalanDOMString&	s) const;
-
-	/**
-	 * Print a diagnostics string to the output device
-	 * 
-	 * @param s string to print
-	 */
-	void
-	diag(const char*	s) const;
-
 	/**
 	 * Retrieve the result namespace corresponding to a prefix.
 	 * 
@@ -1537,9 +1508,6 @@ private:
 	 */
 	PrintWriter*	m_diagnosticsPrintWriter;
 
-	/* For diagnostics */
-	DurationsTableMapType	m_durationsTable;
-
 	/**
 	 * List of listeners who are interested in tracing what's 
 	 * being generated.
@@ -1644,17 +1612,6 @@ private:
 			const XalanDOMString&	theElementName,
 			const XalanDOMString&	theElementNamespaceURI);
 
-	void
-	error(
-			const char*			theMessage,
-			const LocatorType*	theLocator,
-			const XalanNode*	theSourceNode);
-
-	void
-	warn(
-			const char*			theMessage,
-			const LocatorType*	theLocator,
-			const XalanNode*	theSourceNode);
 
 
 	// Data members...
@@ -1693,7 +1650,7 @@ private:
 	XPathConstructionContextDefault		m_xpathConstructionContext;
 
 	static void
-	installFunctions();
+	installFunctions(MemoryManagerType& theManager);
 
 	static void
 	uninstallFunctions();
