@@ -23,8 +23,8 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 
-XalanAVTAllocator::XalanAVTAllocator(size_type	theBlockCount) :
-	m_allocator(theBlockCount)
+XalanAVTAllocator::XalanAVTAllocator(MemoryManagerType&  theManager, size_type	theBlockCount) :
+	m_allocator(theManager, theBlockCount)
 {
 }
 
