@@ -23,8 +23,8 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 
-XalanAVTPartSimpleAllocator::XalanAVTPartSimpleAllocator(size_type	theBlockCount) :
-	m_allocator(theBlockCount)
+XalanAVTPartSimpleAllocator::XalanAVTPartSimpleAllocator(MemoryManagerType&  theManager, size_type	theBlockCount) :
+	m_allocator(theManager, theBlockCount)
 {
 }
 
