@@ -23,8 +23,8 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 
-XalanAVTPartXPathAllocator::XalanAVTPartXPathAllocator(size_type	theBlockCount) :
-	m_allocator(theBlockCount)
+XalanAVTPartXPathAllocator::XalanAVTPartXPathAllocator(MemoryManagerType&  theManager, size_type	theBlockCount) :
+	m_allocator(theManager, theBlockCount)
 {
 }
 
