@@ -23,8 +23,8 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 
-XalanElemElementAllocator::XalanElemElementAllocator(size_type	theBlockCount) :
-	m_allocator(theBlockCount)
+XalanElemElementAllocator::XalanElemElementAllocator(MemoryManagerType&  theManager, size_type	theBlockCount) :
+	m_allocator(theManager, theBlockCount)
 {
 }
 
