@@ -23,8 +23,8 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 
-XalanElemVariableAllocator::XalanElemVariableAllocator(size_type	theBlockCount) :
-	m_allocator(theBlockCount)
+XalanElemVariableAllocator::XalanElemVariableAllocator(MemoryManagerType&  theManager, size_type	theBlockCount) :
+	m_allocator(theManager, theBlockCount)
 {
 }
 
