@@ -22,8 +22,7 @@
 
 
 
-#include <xalanc/Include/XalanAutoPtr.hpp>
-
+#include <xalanc/Include/XalanMemMngArrayAllocate.hpp>
 
 
 #include <cstdlib>
@@ -42,8 +41,8 @@ const XalanDOMString::size_type     XalanDOMString::npos;
  
 
 
-XalanDOMString::XalanDOMString() :
-	m_data(),
+XalanDOMString::XalanDOMString(MemoryManagerType&  theManager) :
+	m_data(theManager),
 	m_size(0)
 {
 }
@@ -52,9 +51,10 @@ XalanDOMString::XalanDOMString() :
 
 XalanDOMString::XalanDOMString(
 			const XalanDOMString&	theSource,
+            MemoryManagerType&      theManager,
 			size_type				theStartPosition,
 			size_type				theCount) :
-	m_data(),
+	m_data(theManager),
 	m_size(0)
 {
 	if (theSource.length() != 0)
@@ -67,8 +67,9 @@ XalanDOMString::XalanDOMString(
 
 XalanDOMString::XalanDOMString(
 			const XalanDOMChar*		theString,
+            MemoryManagerType&      theManager,
 			size_type				theCount) :
-	m_data(),
+	m_data(theManager),
 	m_size(0)
 {
 	assert(theString != 0);
@@ -82,9 +83,10 @@ XalanDOMString::XalanDOMString(
 
 
 XalanDOMString::XalanDOMString(
-			const char*		theString,
-			size_type		theCount) :
-	m_data(),
+			const char*		    theString,
+            MemoryManagerType&  theManager,
+			size_type		    theCount) :
+	m_data(theManager),
 	m_size(0)
 {
 	assert(theString != 0);
@@ -97,17 +99,32 @@ XalanDOMString::XalanDOMString(
 	invariants();
 }
 
+XalanDOMString*
+XalanDOMString::clone(MemoryManagerType&  theManager)
+{
+        typedef XalanDOMString ThisType;
+        
+        XalanMemMgrAutoPtr<ThisType, false> theGuard( theManager , (ThisType*)theManager.allocate(sizeof(ThisType)));
 
+        ThisType* theResult = theGuard.get();
+
+        new (theResult) ThisType(*this, theManager);
+
+        theGuard.release();
+
+        return theResult;
+}
 
 XalanDOMString::XalanDOMString(
-			size_type		theCount,
-			XalanDOMChar	theChar) :
-	m_data(),
+			size_type		    theCount,
+			XalanDOMChar	    theChar,
+            MemoryManagerType&  theManager) :
+	m_data(theManager),
 	m_size(0)
 {
 	if (theCount != 0)
 	{
-		XalanDOMCharVectorType(theCount + 1, theChar).swap(m_data);
+		XalanDOMCharVectorType(theCount + 1, theChar, theManager).swap(m_data);
 
 		// Null-terminate it...
 		m_data.back() = 0;
@@ -247,29 +264,11 @@ XalanDOMString::assign(
 
 XalanDOMString&
 XalanDOMString::assign(
-		const_iterator	theFirstPosition,
-		const_iterator	theLastPosition)
+		    iterator	theFirstPosition,
+		    iterator	theLastPosition)
 {
 	invariants();
 
-#if defined(__SGI_STL_PORT) && __SGI_STL_PORT <= 0x400
-	XalanDOMString  temp;
-
-	temp.m_data.reserve(theLastPosition - theFirstPosition + 1);
-
-	while(theFirstPosition != theLastPosition)
-	{
-		temp.m_data.push_back(*theFirstPosition);
-
-		++theFirstPosition;
-	}
-
-	temp.m_data.push_back(XalanDOMChar(0));
-
-	temp.m_size = temp.m_data.size() - 1;
-
-	swap(temp);
-#else
 	m_data.reserve(theLastPosition - theFirstPosition + 1);
 
 	m_data.assign(theFirstPosition, theLastPosition);
@@ -279,8 +278,6 @@ XalanDOMString::assign(
 	m_size = size_type(m_data.size()) - 1;
     assert(m_data.size() - 1 == m_size);
 
-#endif
-
 	invariants();
 
 	return *this;
@@ -370,7 +367,7 @@ XalanDOMString::append(
 		}
 		else
 		{
-			XalanDOMCharVectorType	theTempVector;
+			XalanDOMCharVectorType	theTempVector(getMemoryManager());
 
 			doTranscode(theString, theLength, theTempVector, false);
 
@@ -490,14 +487,18 @@ XalanDOMString::insert(
 		assign(1, theChar);
 
 		assert(length() == 1);
+
+        thePosition = m_data.begin();
 	}
 	else
 	{
-		m_data.insert(thePosition, theChar);
+		thePosition = m_data.insert(thePosition, theChar);
 
 		++m_size;
 	}
 
+    assert(*thePosition == theChar);
+
 	invariants();
 
 	return thePosition;
@@ -536,8 +537,8 @@ XalanDOMString::insert(
 void
 XalanDOMString::insert(
 		iterator		theInsertPosition,
-		const_iterator	theFirstPosition,
-		const_iterator	theLastPosition)
+		iterator	theFirstPosition,
+		iterator	theLastPosition)
 {
 	invariants();
 
@@ -643,22 +644,30 @@ XalanDOMString::compare(
 	return doCompare(c_str() + thePosition1, theCount1, theString, theCount2);
 }
 
-
-
-XalanDOMString::CharVectorType
-XalanDOMString::transcode() const
+template<class Type>
+void
+reset_func(XalanDOMString& obj, MemoryManagerType&    theManager, Type string)
 {
-	invariants();
+    assert( string != 0 );
 
-	CharVectorType	theResult;
+    XalanDOMString tmpString(string, theManager);
 
-	transcode(theResult);
-
-	return theResult;
+    obj.swap(tmpString);
 }
 
+void 
+XalanDOMString::reset(MemoryManagerType&    theManager,
+                      const char*		    theString)
+{
+    reset_func(*this, theManager, theString);
+}
 
-
+void 
+XalanDOMString::reset(MemoryManagerType&    theManager,
+                      const XalanDOMChar*   theString)
+{
+    reset_func(*this, theManager, theString);
+}
 void
 XalanDOMString::transcode(CharVectorType&	theResult) const
 {
@@ -798,7 +807,6 @@ XalanDOMString::hash(
 
 
 
-#if defined(XALAN_USE_XERCES_LOCAL_CODEPAGE_TRANSCODERS)
 
 
 
@@ -812,26 +820,25 @@ XALAN_CPP_NAMESPACE_END
 
 XALAN_CPP_NAMESPACE_BEGIN
 
-
-
+// The template function should never fail.
+// In case of the unconvertable characters we add the substitution char
+// and in case of too small result vector we resize it 
 template <class SourceType, class TargetType>
-bool
+void
 doXercesTranscode(
-			const SourceType*			theSourceString,
-			XalanDOMString::size_type	theSourceStringLength,
-			bool						theSourceStringIsNullTerminated,
-#if defined(XALAN_NO_STD_NAMESPACE)
-			vector<TargetType>&			theTargetVector,
-#else
-			std::vector<TargetType>&	theTargetVector,
-#endif
-			bool						terminate)
+            const SourceType*           theSourceString,
+            XalanDOMString::size_type   theSourceStringLength,
+            bool                        theSourceStringIsNullTerminated,
+            XalanVector<TargetType>&    theTargetVector,
+            bool                        terminate,
+            char                        theSubstitutionChar)
 {
+
 	const SourceType*	theRealSourceString = theSourceString;
 
 	XalanDOMString::size_type	theRealSourceStringLength = theSourceStringLength;
 
-	XalanArrayAutoPtr<SourceType>		theGuard;
+	XalanMemMgrAutoPtrArray<SourceType>		theGuard;
 
 	if (theSourceStringIsNullTerminated == true)
 	{
@@ -839,7 +846,121 @@ doXercesTranscode(
 	}
 	else
 	{
-		theGuard.reset(new SourceType[theRealSourceStringLength + 1]);
+        typedef XalanMemMngArrayAllocate<SourceType> ArrayAllocateSourceType;
+
+        theGuard.reset( &( theTargetVector.getMemoryManager()), 
+                        ArrayAllocateSourceType::allocate(theRealSourceStringLength + 1, theTargetVector.getMemoryManager()),
+                        theRealSourceStringLength + 1);
+
+        assert(theGuard.get() != 0);
+
+        for (XalanDOMString::size_type index = 0; index < theRealSourceStringLength; ++index)
+        {
+            theGuard[index] = theSourceString[index];
+        }
+
+        theGuard[theRealSourceStringLength] = SourceType(0);
+
+        theRealSourceString = theGuard.get(); 
+    }
+
+    // wild guessing about the size of the result transcoded vector
+    theTargetVector.resize(2*(theRealSourceStringLength + 1), TargetType(0));
+
+    assert(theRealSourceString != 0);
+
+    bool			fSuccess = false;
+
+    XALAN_USING_XERCES(XMLString)
+
+    // $$$ ToDo: We should use the Xerces transcoder interface
+    // instead of XMLString::transcode(), so we can better control
+    // error handling and failures due to inadequate space.
+
+    fSuccess = XMLString::transcode(
+        theRealSourceString,
+        &*theTargetVector.begin(),
+        (unsigned int)(theTargetVector.size() - 1),
+        & (theTargetVector.getMemoryManager()));
+
+    if (fSuccess == false)
+    {
+        // Do the "manual" transcoding. First , clean uo form the previose phase
+        theTargetVector.clear();
+
+        //check if there is illegal caracters for the local code page encoding
+        SourceType oneCharArray[2];
+
+        oneCharArray[1] = SourceType(0);
+
+        const size_t theOneTranslatedWbCharLen = 10;
+
+        TargetType theOneTranslatedWbChar[theOneTranslatedWbCharLen]; 
+
+        for (size_t i = 0 ; i <= theRealSourceStringLength ; ++i)
+        {
+            oneCharArray[0] = theRealSourceString[i];
+
+            theOneTranslatedWbChar[0] = TargetType(0);
+
+            fSuccess = XMLString::transcode(
+                oneCharArray,
+                theOneTranslatedWbChar,
+                theOneTranslatedWbCharLen - 1,
+                & (theTargetVector.getMemoryManager()));
+
+            if( fSuccess == false )
+            {
+                theTargetVector.push_back(theSubstitutionChar);
+            }
+            else
+            {
+                // append the translated set of characters
+                theTargetVector.insert(
+                    theTargetVector.end(),
+                    theOneTranslatedWbChar,
+                    theOneTranslatedWbChar + XalanDOMString::length(theOneTranslatedWbChar));
+            }
+        }
+
+    }
+
+    if (terminate == false)
+	{
+		while(theTargetVector.back() == TargetType(0))
+		{
+			theTargetVector.pop_back();
+		}
+	}
+}
+
+template <class SourceType, class TargetType>
+bool
+doXercesTranscode(
+			const SourceType*			theSourceString,
+			XalanDOMString::size_type	theSourceStringLength,
+			bool						theSourceStringIsNullTerminated,
+			XalanVector<TargetType>&	theTargetVector,
+			bool						terminate)
+{
+	const SourceType*	theRealSourceString = theSourceString;
+
+	XalanDOMString::size_type	theRealSourceStringLength = theSourceStringLength;
+
+	XalanMemMgrAutoPtrArray<SourceType>		theGuard;
+
+	if (theSourceStringIsNullTerminated == true)
+	{
+		theRealSourceStringLength = XalanDOMString::length(theSourceString);
+	}
+	else
+	{
+        typedef XalanMemMngArrayAllocate<SourceType> ArrayAllocateSourceType;
+
+        theGuard.reset( &( theTargetVector.getMemoryManager()), 
+                        ArrayAllocateSourceType::allocate(theRealSourceStringLength + 1, theTargetVector.getMemoryManager()),
+                        theRealSourceStringLength + 1);
+
 		assert(theGuard.get() != 0);
 
 		for (XalanDOMString::size_type index = 0; index < theRealSourceStringLength; ++index)
@@ -871,7 +992,8 @@ doXercesTranscode(
 		fSuccess = XMLString::transcode(
 					theRealSourceString,
 					&*theTargetVector.begin(),
-					theTargetVector.size() - 1);
+					(unsigned int)(theTargetVector.size() - 1),
+                    & (theTargetVector.getMemoryManager()));
 
 		if (fSuccess == false)
 		{
@@ -903,9 +1025,41 @@ doXercesTranscode(
 	return fSuccess;
 }
 
-#endif
 
+static void
+doTranscodeToLocalCodePage(
+			const XalanDOMChar*			theSourceString,
+			XalanDOMString::size_type	theSourceStringLength,
+			bool						theSourceStringIsNullTerminated,
+			CharVectorType&				theTargetVector,
+			bool						terminate,
+            char                        theSubstitutionChar)
+{
+    // Short circuit if it's a null pointer, or of length 0.
+    if (!theSourceString || (!theSourceString[0]))
+    {
+		if (terminate == true)
+		{
+			theTargetVector.resize(1);
 
+			theTargetVector.back() = '\0';
+		}
+		else
+		{
+			theTargetVector.clear();
+		}
+	}
+	else
+	{
+		doXercesTranscode(
+					theSourceString,
+					theSourceStringLength,
+					theSourceStringIsNullTerminated,
+					theTargetVector,
+					terminate,
+                    theSubstitutionChar);
+	}
+}
 
 static bool
 doTranscodeToLocalCodePage(
@@ -915,10 +1069,6 @@ doTranscodeToLocalCodePage(
 			CharVectorType&				theTargetVector,
 			bool						terminate)
 {
-#if defined(XALAN_STRICT_ANSI_HEADERS)
-	using std::wcstombs;
-#endif
-
     // Short circuit if it's a null pointer, or of length 0.
     if (!theSourceString || (!theSourceString[0]))
     {
@@ -935,7 +1085,6 @@ doTranscodeToLocalCodePage(
 
         return true;
 	}
-#if defined(XALAN_USE_XERCES_LOCAL_CODEPAGE_TRANSCODERS)
 	else
 	{
 		return doXercesTranscode(
@@ -945,75 +1094,43 @@ doTranscodeToLocalCodePage(
 					theTargetVector,
 					terminate);
 	}
-#else
-	const wchar_t*	theTempSource = 0;
+}
 
-	// If our char sizes are not the same, or the input string is not null-terminated,
-	// we have to use a temporary buffer.
-	XalanArrayAutoPtr<wchar_t>	theTempSourceJanitor;
-
-#if !defined(XALAN_XALANDOMCHAR_USHORT_MISMATCH)
-	// This is a short-cut for when the theSourceString is mull-terminated _and_
-	// XalanDOMChar and wchar_t are the same thing.
-	if (theSourceStringIsNullTerminated == true)
-	{
-		theTempSource = theSourceString;
-	}
-	else
-#endif
-	{
-		if (theSourceStringIsNullTerminated == true)
-		{
-			theSourceStringLength = length(theSourceString);
-		}
-
-		theTempSourceJanitor.reset(new wchar_t[theSourceStringLength + 1]);
-
-		for (size_t	index = 0; index < theSourceStringLength; ++index)
-		{
-			theTempSourceJanitor[index] = wchar_t(theSourceString[index]);
-		}
-
-		theTempSourceJanitor[theSourceStringLength] = 0;
-
-		theTempSource = theTempSourceJanitor.get();
-	}
-
-    // See how many chars we need to transcode.
-    const size_t	targetLen = wcstombs(0, theTempSource, 0);
-
-	if (targetLen == ~size_t(0))
-	{
-		return false;
-	}
-	else
-	{
-		// Resize, adding one byte if terminating...
-		theTargetVector.resize(terminate == true ? targetLen + 1 : targetLen);
-
-		//  And transcode our temp source buffer to the local buffer. Terminate
-		//
-		if (wcstombs(&theTargetVector[0], theTempSource, targetLen) == ~size_t(0))
-		{
-			theTargetVector.clear();
-
-			return false;
-		}
-		else
-		{
-			if (terminate == true)
-			{
-				theTargetVector.back() = '\0';
-			}
-
-			return true;
-		}
-	}
-#endif
+XALAN_DOM_EXPORT_FUNCTION(void)
+TranscodeToLocalCodePage(
+			const XalanDOMChar*			theSourceString,
+			XalanDOMString::size_type	theSourceStringLength,
+			CharVectorType&				theTargetVector,
+			bool						terminate,
+            char                        theSubstitutionChar)
+{
+	doTranscodeToLocalCodePage(
+                            theSourceString, 
+                            theSourceStringLength, 
+                            false, 
+                            theTargetVector, 
+                            terminate,
+                            theSubstitutionChar);
 }
 
 
 
+XALAN_DOM_EXPORT_FUNCTION(void)
+TranscodeToLocalCodePage(
+			const XalanDOMChar*		theSourceString,
+			CharVectorType&			theTargetVector,
+			bool					terminate,
+            char                    theSubstitutionChar)
+{
+	doTranscodeToLocalCodePage(
+                            theSourceString, 
+                            0, 
+                            true, 
+                            theTargetVector, 
+                            terminate,
+                            theSubstitutionChar);
+}
+
 XALAN_DOM_EXPORT_FUNCTION(bool)
 TranscodeToLocalCodePage(
 			const XalanDOMChar*			theSourceString,
@@ -1045,10 +1162,6 @@ doTranscodeFromLocalCodePage(
 			XalanDOMCharVectorType&		theTargetVector,
 			bool						terminate)
 {
-#if defined(XALAN_STRICT_ANSI_HEADERS)
-	using std::mbstowcs;
-#endif
-
 	typedef XalanDOMString::size_type	size_type;
 
     // Short circuit if it's a null pointer, or of length 0.
@@ -1067,7 +1180,6 @@ doTranscodeFromLocalCodePage(
 
         return true;
 	}
-#if defined(XALAN_USE_XERCES_LOCAL_CODEPAGE_TRANSCODERS)
 	else
 	{
 		return doXercesTranscode(
@@ -1077,80 +1189,6 @@ doTranscodeFromLocalCodePage(
 					theTargetVector,
 					terminate);
 	}
-#else
-	XalanArrayAutoPtr<char>		tempString;
-
-	if (theSourceStringIsNullTerminated == true)
-	{
-		theSourceStringLength = XalanDOMString::length(theSourceString);
-	}
-	else
-	{
-		tempString.reset(new char[theSourceStringLength + 1]);
-
-#if defined(XALAN_STRICT_ANSI_HEADERS)
-		std::strncpy(tempString.get(), theSourceString, theSourceStringLength);
-#else
-		strncpy(tempString.get(), theSourceString, theSourceStringLength);
-#endif
-
-		tempString[theSourceStringLength] = '\0';
-
-		theSourceString = tempString.get();
-	}
-
-    // See how many chars we need to transcode.
-	const size_t	theTargetLength =
-			mbstowcs(0, theSourceString, size_t(theSourceStringLength));
-
-	if (theTargetLength == ~size_t(0))
-	{
-		return false;
-	}
-	else
-	{
-#if defined(XALAN_XALANDOMCHAR_USHORT_MISMATCH)
-		typedef XalanDOMString::WideCharVectorType	WideCharVectorType;
-
-		WideCharVectorType	theTempResult;
-
-		theTempResult.resize(terminate == true ? theTargetLength + 1 : theTargetLength);
-
-		wchar_t* const	theTargetPointer = &theTempResult[0];
-#else
-		theTargetVector.resize(terminate == true ? theTargetLength + 1 : theTargetLength);
-
-		wchar_t* const	theTargetPointer = &theTargetVector[0];
-#endif
-
-		if (mbstowcs(theTargetPointer, theSourceString, size_t(theSourceStringLength)) == ~size_t(0))
-		{
-			theTargetVector.clear();
-
-			return false;
-		}
-		else
-		{
-#if defined(XALAN_XALANDOMCHAR_USHORT_MISMATCH)
-			const WideCharVectorType::size_type		theTempSize = theTempResult.size();
-
-			theTargetVector.reserve(theTempSize);
-
-			for(WideCharVectorType::size_type i = 0; i < theTempSize; ++i)
-			{
-				theTargetVector.push_back(theTempResult[i]);
-			}
-#endif
-
-			if (terminate == true)
-			{
-				theTargetVector.back() = '\0';
-			}
-
-			return true;
-		}
-	}
-#endif
 }
 
 
@@ -1178,12 +1216,15 @@ TranscodeFromLocalCodePage(
 
 
 
-XALAN_DOM_EXPORT_FUNCTION(const XalanDOMString)
-TranscodeFromLocalCodePage(const CharVectorType&	theSourceString)
+XALAN_DOM_EXPORT_FUNCTION(const XalanDOMString&)
+TranscodeFromLocalCodePage(const CharVectorType&	theSourceString,
+                           XalanDOMString&          result)
 {
 	if (theSourceString.empty() == true)
 	{
-		return XalanDOMString();
+        result.erase();
+
+        return result;
 	}
 	else
 	{
@@ -1193,11 +1234,11 @@ TranscodeFromLocalCodePage(const CharVectorType&	theSourceString)
 
 		if (theSourceString[theSize - 1] == CharVectorType::value_type(0))
 		{
-			return TranscodeFromLocalCodePage(&*theSourceString.begin(), size_type(theSize) - 1);
+			return TranscodeFromLocalCodePage(&*theSourceString.begin(), result , size_type(theSize) - 1);
 		}
 		else
 		{
-			return TranscodeFromLocalCodePage(&*theSourceString.begin(), size_type(theSize));
+			return TranscodeFromLocalCodePage(&*theSourceString.begin(), result , size_type(theSize));
 		}
 	}
 }
