@@ -23,7 +23,11 @@
 
 
 #include <cassert>
-#include <vector>
+
+
+
+#include <xalanc/Include/XalanMemoryManagement.hpp>
+#include <xalanc/Include/XalanVector.hpp>
 
 
 
@@ -38,16 +42,9 @@ XALAN_CPP_NAMESPACE_BEGIN
 class XALAN_DOM_EXPORT XalanDOMString
 {
 public:
-
-#if defined(XALAN_NO_STD_NAMESPACE)
-	typedef vector<XalanDOMChar>		XalanDOMCharVectorType;
-	typedef vector<char>				CharVectorType;
-	typedef vector<wchar_t>				WideCharVectorType;
-#else
-	typedef std::vector<XalanDOMChar>	XalanDOMCharVectorType;
-	typedef std::vector<char>			CharVectorType;
-	typedef std::vector<wchar_t>		WideCharVectorType;
-#endif
+	typedef XalanVector<XalanDOMChar>		XalanDOMCharVectorType;
+	typedef XalanVector<char>				CharVectorType;
+	typedef XalanVector<wchar_t>			WideCharVectorType;
 
 	typedef XalanDOMChar				value_type;
 	typedef XalanDOMChar&				reference;
@@ -66,27 +63,33 @@ public:
 	enum { npos = -1 };
 #endif
 
-	explicit
-	XalanDOMString();
+	XalanDOMString(MemoryManagerType&  theManager XALAN_DEFAULT_CONSTRACTOR_MEMORY_MGR );
 
 	explicit
 	XalanDOMString(
-			const char*		theString,
-			size_type		theCount = size_type(npos));
+			const char*		    theString,
+            MemoryManagerType&  theManager XALAN_DEFAULT_MEMMGR,
+			size_type		    theCount = size_type(npos));
 
 	XalanDOMString(
 			const XalanDOMString&	theSource,
+            MemoryManagerType&      theManager XALAN_DEFAULT_CONSTRACTOR_MEMORY_MGR,
 			size_type				theStartPosition = 0,
 			size_type				theCount = size_type(npos));
 
 	explicit
 	XalanDOMString(
 			const XalanDOMChar*		theString,
+            MemoryManagerType&      theManager XALAN_DEFAULT_MEMMGR,
 			size_type				theCount = size_type(npos));
 
 	XalanDOMString(
 			size_type		theCount,
-			XalanDOMChar	theChar);
+			XalanDOMChar	theChar,
+            MemoryManagerType&  theManager XALAN_DEFAULT_MEMMGR);
+
+    XalanDOMString*
+    clone(MemoryManagerType&  theManager);
 
 	~XalanDOMString()
 	{
@@ -236,7 +239,10 @@ public:
 	{
 		invariants();
 
-		return size_type(m_data.capacity()) - 1;
+        const XalanDOMCharVectorType::size_type     theCapacity =
+                m_data.capacity();
+
+        return theCapacity == 0 ? 0 : size_type(theCapacity - 1);
 	}
 
 	void
@@ -288,9 +294,6 @@ public:
 		return m_data[theIndex];
 	}
 
-#if 0
-	// $$$ ToDo: at() is not supported in the current version of GCC's vector<>
-	// implementation.  Eventually, it should be.
 	const_reference
 	at(size_type	theIndex) const
 	{
@@ -306,7 +309,6 @@ public:
 
 		return m_data.at(theIndex);
 	}
-#endif
 
 	const XalanDOMChar*
 	c_str() const
@@ -449,8 +451,8 @@ public:
 
 	XalanDOMString&
 	assign(
-		const_iterator	theFirstPosition,
-		const_iterator	theLastPosition);
+		iterator	theFirstPosition,
+		iterator	theLastPosition);
 
 	XalanDOMString&
 	append(const XalanDOMString&	theSource)
@@ -559,21 +561,9 @@ public:
 	void
 	insert(
 		iterator		theInsertPosition,
-		const_iterator	theFirstPosition,
-		const_iterator	theLastPosition);
+		iterator	theFirstPosition,
+		iterator	theLastPosition);
 
-	XalanDOMString
-	substr(
-			size_type	thePosition = 0,
-			size_type	theCount = size_type(npos)) const
-	{
-		assert(theCount == size_type(npos) && thePosition < length() ||
-			   thePosition + theCount <= length());
-
-		invariants();
-
-		return XalanDOMString(*this, thePosition, theCount);
-	}
 
 	XalanDOMString&
 	substr(
@@ -631,25 +621,12 @@ public:
 			const XalanDOMChar*		theString,
 			size_type				theCount2 = size_type(npos)) const;
 
-	int
-	compare(const char*		theString) const
-	{
-		invariants();
 
-		return compare(XalanDOMString(theString));
-	}
+    void 
+    reset(MemoryManagerType& theManager, const char*	theString);
 
-	int
-	compare(
-			size_type		thePosition1,
-			size_type		theCount1,
-			const char*		theString,
-			size_type		theCount2 = size_type(npos)) const
-	{
-		invariants();
-
-		return compare(thePosition1, theCount1, XalanDOMString(theString, theCount2));
-	}
+    void 
+    reset(MemoryManagerType& theManager, const XalanDOMChar* theString);
 
 	class TranscodingError : public XalanDOMException
 	{
@@ -666,15 +643,7 @@ public:
 		}
 	};
 
-	/**
-	 * Transcode the string to the local code page.  If the string
-	 * cannot be properly transcoded, and the transcoder can detect
-	 * the error a TranscodingError exception is thrown.
-	 *
-	 * @return A null-terminated CharVectorType instance.
-	 */
-	CharVectorType
-	transcode() const;
+
 
 	/**
 	 * Transcode the string to the local code page.  If the string
@@ -686,6 +655,12 @@ public:
 	void
 	transcode(CharVectorType&	theResult) const;
 
+    MemoryManagerType&
+    getMemoryManager()
+    {
+        return m_data.getMemoryManager();
+    }
+
 	size_type
 	hash() const
 	{
@@ -806,8 +781,15 @@ protected:
 		return m_data.begin() + thePosition;
 	}
 
+#if defined (XALAN_DEVELOPMENT)
+    // not defined
+    XalanDOMString();
+    XalanDOMString(const XalanDOMString&);
+#endif
+
 private:
 
+
 	XalanDOMCharVectorType		m_data;
 
 	size_type					m_size;
@@ -878,72 +860,81 @@ operator!=(
 
 
 
-inline XalanDOMString
-operator+(
+inline XalanDOMString&
+add(
 			const XalanDOMString&	theLHS,
-			const XalanDOMString&	theRHS)
+			const XalanDOMString&	theRHS,
+            XalanDOMString&         result)
 {
-	XalanDOMString	theTemp(theLHS);
+    result.assign(theLHS);
 
-	return theTemp += theRHS;
+	return result += theRHS;
 }
 
 
 
-inline XalanDOMString
-operator+(
+inline XalanDOMString&
+add(
 			const XalanDOMString&	theLHS,
-			const XalanDOMChar*		theRHS)
+			const XalanDOMChar*		theRHS,
+            XalanDOMString&         result)
 {
-	XalanDOMString	theTemp(theLHS);
+    result.assign(theLHS);
 
-	return theTemp += theRHS;
+	return result += theRHS;
 }
 
 
 
-inline XalanDOMString
-operator+(
+inline XalanDOMString&
+add(
 			const XalanDOMChar*		theLHS,
-			const XalanDOMString&	theRHS)
+			const XalanDOMString&	theRHS,
+            XalanDOMString&         result)
 {
-	XalanDOMString	theTemp(theLHS);
+    result.assign(theLHS);
 
-	return theTemp += theRHS;
+	return result += theRHS;
 }
 
 
 
-inline const XalanDOMString
-operator+(
+inline const XalanDOMString&
+add(
 			const char*				theLHS,
-			const XalanDOMString&	theRHS)
+			const XalanDOMString&	theRHS,
+            XalanDOMString&         result)
 {
-	return XalanDOMString(theLHS) + theRHS;
+    result.assign(theLHS);
+
+    result.append(theRHS);
+
+	return result;
 }
 
 
 
-inline const XalanDOMString
-operator+(
+inline const XalanDOMString&
+add(
 			const XalanDOMString&	theLHS,
-			const char*				theRHS)
+			const char*				theRHS,
+            XalanDOMString&         result)
 {
-	return theLHS + XalanDOMString(theRHS);
+    result.assign(theLHS);
+    
+    result.append(theRHS);
+
+	return result;
 }
 
 
 
 // Standard vector of XalanDOMChars and chars
-#if defined(XALAN_NO_STD_NAMESPACE)
-typedef vector<XalanDOMChar>		XalanDOMCharVectorType;
+typedef XalanVector<XalanDOMChar>	XalanDOMCharVectorType;
+
+typedef XalanVector<char>			CharVectorType;
 
-typedef vector<char>				CharVectorType;
-#else
-typedef std::vector<XalanDOMChar>	XalanDOMCharVectorType;
 
-typedef std::vector<char>			CharVectorType;
-#endif
 
 
 
@@ -965,6 +956,44 @@ TranscodeToLocalCodePage(
 			CharVectorType&				targetVector,
 			bool						terminate = false);
 
+/**
+ * Convert a XalanDOMChar string to C++ standard library
+ * vector, transcoding to the default local code
+ * page. If the source string contines code points, that can't be 
+ * represented in the local code page, the substitution character will be used
+ *
+ * @param sourceString The source string
+ * @param sourceStringLength The source string length.
+ * @param targetVector The target string
+ * @param terminate If true, the transcoded string will be null-terminated
+ * @param theSubstitutionChar The substitution character for code points that are not presentable
+ *                              in the local page
+ */
+XALAN_DOM_EXPORT_FUNCTION(void)
+TranscodeToLocalCodePage(
+            const XalanDOMChar*         theSourceString,
+            XalanDOMString::size_type   theSourceStringLength,
+            CharVectorType&             targetVector,
+            bool                        terminate,
+            char                        theSubstitutionChar);
+
+/**
+ * Convert a string to a XalanDOMString, transcoding from
+ * the default local code page.
+ * 
+ * @param theSourceString The source string
+ * @param theSourceStringLength The source string length.
+ * @return The new string.
+ */
+#if !defined(XALAN_DEVELOPMENT)
+inline const XalanDOMString
+TranscodeFromLocalCodePage(
+			const char*					theSourceString,
+			XalanDOMString::size_type	theSourceStringLength = XalanDOMString::npos)
+{
+	return XalanDOMString(theSourceString,XalanMemMgrs::getDefaultXercesMemMgr(), theSourceStringLength);
+}
+#endif
 
 
 /**
@@ -983,7 +1012,21 @@ TranscodeToLocalCodePage(
 			CharVectorType&			targetVector,
 			bool					terminate = false);
 
-
+/**
+ * Convert a XalanDOMChar string to C++ standard library
+ * vector, transcoding to the default local code
+ * page.  The string _must_ be null-terminated.
+ * 
+ * @param theSourceString The source string
+ * @param targetVector The target string
+ * @param terminate If true, the transcoded string will be null-terminated
+ */
+XALAN_DOM_EXPORT_FUNCTION(void)
+TranscodeToLocalCodePage(
+            const XalanDOMChar*     theSourceString,
+            CharVectorType&         targetVector,
+            bool                    terminate,
+            char                    theSubstitutionChar);
 
 /**
  * Convert XalanDOMString to C++ standard library
@@ -993,16 +1036,17 @@ TranscodeToLocalCodePage(
  * @param theSourceString source string
  * @return The transcoded string.
  */
+#if !defined(XALAN_DEVELOPMENT)
 inline const CharVectorType
 TranscodeToLocalCodePage(const XalanDOMChar*	theSourceString)
 {
 	CharVectorType	theResult;
 
-	TranscodeToLocalCodePage(theSourceString, theResult, true);
+	TranscodeToLocalCodePage(theSourceString, theResult, true, '?');
 
 	return theResult;
 }
-
+#endif
 
 
 /**
@@ -1023,7 +1067,25 @@ TranscodeToLocalCodePage(
 	return TranscodeToLocalCodePage(theSourceString.c_str(), targetVector, terminate);
 }
 
-
+/**
+ * Convert XalanDOMString to C++ standard library
+ * vector, transcoding to the default local code
+ * page.
+ * 
+ * @param theSourceString The source string
+ * @param targetVector The target string
+ * @param theSubstitutionChar The substitution character for code points that are not presentable
+ *                              in the local page
+ */
+inline void
+TranscodeToLocalCodePage(
+			const XalanDOMString&	theSourceString,
+			CharVectorType&			targetVector,
+			bool					terminate ,
+            char                    theSubstitutionChar)
+{
+	TranscodeToLocalCodePage(theSourceString.c_str(), targetVector, terminate, theSubstitutionChar);
+}
 
 /**
  * Convert XalanDOMString to C++ standard library
@@ -1033,16 +1095,17 @@ TranscodeToLocalCodePage(
  * @param thetheSourceString source string
  * @return The transcoded string.
  */
+#if !defined(XALAN_DEVELOPMENT)
 inline const CharVectorType
 TranscodeToLocalCodePage(const XalanDOMString&	theSourceString)
 {
 	CharVectorType	theResult;
 
-	TranscodeToLocalCodePage(theSourceString, theResult, true);
+	TranscodeToLocalCodePage(theSourceString.c_str(), theResult, true, '?');
 
 	return theResult;
 }
-
+#endif
 
 
 /**
@@ -1053,12 +1116,15 @@ TranscodeToLocalCodePage(const XalanDOMString&	theSourceString)
  * @param theSourceStringLength The source string length.
  * @return The new string.
  */
-inline const XalanDOMString
+inline const XalanDOMString&
 TranscodeFromLocalCodePage(
 			const char*					theSourceString,
+             XalanDOMString&            result,
 			XalanDOMString::size_type	theSourceStringLength = XalanDOMString::npos)
 {
-	return XalanDOMString(theSourceString, theSourceStringLength);
+    result.assign(theSourceString, theSourceStringLength);
+
+	return result;
 }
 
 
@@ -1081,8 +1147,6 @@ TranscodeFromLocalCodePage(
 			XalanDOMCharVectorType&		theTargetVector,
 			bool						terminate = false);
 
-
-
 /**
  * Convert a string to a C++ standard library
  * vector, transcoding from the default local code
@@ -1099,8 +1163,6 @@ TranscodeFromLocalCodePage(
 			XalanDOMCharVectorType&		theTargetVector,
 			bool						terminate = false);
 
-
-
 /**
  * Convert a vector of characters to a XalanDOMString,
  * transcoding from the default local code
@@ -1108,8 +1170,12 @@ TranscodeFromLocalCodePage(
  * @param theSourceString source string
  * @return The transcoded string.
  */
-XALAN_DOM_EXPORT_FUNCTION(const XalanDOMString)
-TranscodeFromLocalCodePage(const CharVectorType&	theSourceString);
+XALAN_DOM_EXPORT_FUNCTION(const XalanDOMString&)
+TranscodeFromLocalCodePage(const CharVectorType&	theSourceString,
+                           XalanDOMString&          result);
+
+
+XALAN_USES_MEMORY_MANAGER(XalanDOMString)
 
 
 
