@@ -38,13 +38,16 @@ public:
 	installLocal(XPathEnvSupportDefault&	theSupport);
 
 	static void
-	installGlobal();
+	installGlobal(MemoryManagerType& theManager);
 
 	static void
 	uninstallLocal(XPathEnvSupportDefault&	theSupport);
 
 	static void
-	uninstallGlobal();
+	uninstallGlobal(MemoryManagerType& theManager);
+
+private:
+
 };
 
 
