@@ -43,11 +43,16 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 
-static const XalanDOMString		s_emptyString;
+static const XalanDOMString		s_emptyString(XalanMemMgrs::getDummyMemMgr());
+
+
+
+bool    XalanSourceTreeDocument::s_poolAllTextNodes = false;
 
 
 
 XalanSourceTreeDocument::XalanSourceTreeDocument(
+            MemoryManagerType&  theManager,
 			bool				fPoolAllText,
 			block_size_type		theNamesStringPoolBlockSize,
 			bucket_count_type	theNamesStringPoolBucketCount,
@@ -58,31 +63,60 @@ XalanSourceTreeDocument::XalanSourceTreeDocument(
 	XalanDocument(),
 	m_firstChild(0),
 	m_documentElement(0),
-	m_attributeAllocator(eDefaultAttributeAllocatorBlockSize),
-	m_attributeNSAllocator(eDefaultAttributeNSAllocatorBlockSize),
-	m_commentAllocator(eDefaultCommentAllocatorBlockSize),
-	m_elementAAllocator(eDefaultElementAllocatorBlockSize),
-	m_elementANSAllocator(eDefaultElementNSAllocatorBlockSize),
-	m_elementNAAllocator(eDefaultElementAllocatorBlockSize),
-	m_elementNANSAllocator(eDefaultElementNSAllocatorBlockSize),
-	m_piAllocator(eDefaultPIAllocatorBlockSize),
-	m_textAllocator(eDefaultTextAllocatorBlockSize),
-	m_textIWSAllocator(eDefaultTextIWSAllocatorBlockSize),
-	m_namesStringPool(theNamesStringPoolBlockSize, theNamesStringPoolBucketCount, theNamesStringPoolBucketSize),
-	m_valuesStringPool(theValuesStringPoolBlockSize, theValuesStringPoolBucketCount, theValuesStringPoolBucketSize),
-	m_attributesVector(),
+	m_attributeAllocator(theManager, eDefaultAttributeAllocatorBlockSize),
+	m_attributeNSAllocator(theManager, eDefaultAttributeNSAllocatorBlockSize),
+	m_commentAllocator(theManager, eDefaultCommentAllocatorBlockSize),
+	m_elementAAllocator(theManager, eDefaultElementAllocatorBlockSize),
+	m_elementANSAllocator(theManager, eDefaultElementNSAllocatorBlockSize),
+	m_elementNAAllocator(theManager, eDefaultElementAllocatorBlockSize),
+	m_elementNANSAllocator(theManager, eDefaultElementNSAllocatorBlockSize),
+	m_piAllocator(theManager, eDefaultPIAllocatorBlockSize),
+	m_textAllocator(theManager, eDefaultTextAllocatorBlockSize),
+	m_textIWSAllocator(theManager, eDefaultTextIWSAllocatorBlockSize),
+	m_namesStringPool(theManager, theNamesStringPoolBlockSize, theNamesStringPoolBucketCount, theNamesStringPoolBucketSize),
+	m_valuesStringPool(theManager, theValuesStringPoolBlockSize, theValuesStringPoolBucketCount, theValuesStringPoolBucketSize),
+	m_attributesVector(theManager),
 	m_nextIndexValue(2),
 	m_poolAllText(fPoolAllText),
-	m_elementsByID(),
-	m_unparsedEntityURIs(),
-	m_nonPooledStrings(),
-	m_stringBuffer()
+	m_elementsByID(theManager),
+	m_unparsedEntityURIs(theManager),
+	m_nonPooledStrings(theManager, theValuesStringPoolBlockSize),
+	m_stringBuffer(theManager)
 {
 }
 
+XalanSourceTreeDocument*
+XalanSourceTreeDocument::create( 
+            MemoryManagerType&  theManager,
+			bool				fPoolAllText,
+			block_size_type		theNamesStringPoolBlockSize ,
+			bucket_count_type	theNamesStringPoolBucketCount,
+			bucket_size_type	theNamesStringPoolBucketSize,
+			block_size_type		theValuesStringPoolBlockSize,
+			bucket_count_type	theValuesStringPoolBucketCount,
+			bucket_size_type	theValuesStringPoolBucketSize)
+{
+        typedef XalanSourceTreeDocument ThisType;
+        
+        XalanMemMgrAutoPtr<ThisType, false> theGuard( theManager , (ThisType*)theManager.allocate(sizeof(ThisType)));
 
+        ThisType* theResult = theGuard.get();
+
+        new (theResult) ThisType(theManager,
+                                 fPoolAllText,
+                                 theNamesStringPoolBlockSize,
+                                 theNamesStringPoolBucketCount,
+                                 theNamesStringPoolBucketSize,
+                                 theValuesStringPoolBlockSize,
+                                 theValuesStringPoolBucketCount,
+                                 theValuesStringPoolBucketSize); 
+        theGuard.release();
+
+        return theResult;
+}
 
 XalanSourceTreeDocument::XalanSourceTreeDocument(
+            MemoryManagerType&      theManager,
 			allocator_size_type		theAttributeBlockSize,
 			allocator_size_type		theAttributeNSBlockSize,
 			allocator_size_type		theCommentBlockSize,
@@ -95,25 +129,25 @@ XalanSourceTreeDocument::XalanSourceTreeDocument(
 	XalanDocument(),
 	m_firstChild(0),
 	m_documentElement(0),
-	m_attributeAllocator(theAttributeBlockSize),
-	m_attributeNSAllocator(theAttributeNSBlockSize),
-	m_commentAllocator(theCommentBlockSize),
-	m_elementAAllocator(theElementBlockSize),
-	m_elementANSAllocator(theElementNSBlockSize),
-	m_elementNAAllocator(theElementBlockSize),
-	m_elementNANSAllocator(theElementNSBlockSize),
-	m_piAllocator(thePIBlockSize),
-	m_textAllocator(theTextBlockSize),
-	m_textIWSAllocator(theTextIWSBlockSize),
-	m_namesStringPool(eDefaultNamesStringPoolBlockSize, eDefaultNamesStringPoolBucketCount, eDefaultNamesStringPoolBucketSize),
-	m_valuesStringPool(eDefaultValuesStringPoolBlockSize, eDefaultValuesStringPoolBucketCount, eDefaultValuesStringPoolBucketSize),
-	m_attributesVector(),
+	m_attributeAllocator(theManager, theAttributeBlockSize),
+	m_attributeNSAllocator(theManager, theAttributeNSBlockSize),
+	m_commentAllocator(theManager, theCommentBlockSize),
+	m_elementAAllocator(theManager, theElementBlockSize),
+	m_elementANSAllocator(theManager, theElementNSBlockSize),
+	m_elementNAAllocator(theManager, theElementBlockSize),
+	m_elementNANSAllocator(theManager, theElementNSBlockSize),
+	m_piAllocator(theManager, thePIBlockSize),
+	m_textAllocator(theManager, theTextBlockSize),
+	m_textIWSAllocator(theManager, theTextIWSBlockSize),
+	m_namesStringPool(theManager, eDefaultNamesStringPoolBlockSize, eDefaultNamesStringPoolBucketCount, eDefaultNamesStringPoolBucketSize),
+	m_valuesStringPool(theManager, eDefaultValuesStringPoolBlockSize, eDefaultValuesStringPoolBucketCount, eDefaultValuesStringPoolBucketSize),
+	m_attributesVector(theManager),
 	m_nextIndexValue(2),
 	m_poolAllText(fPoolAllText),
-	m_elementsByID(),
-	m_unparsedEntityURIs(),
-	m_nonPooledStrings(),
-	m_stringBuffer()
+	m_elementsByID(theManager),
+	m_unparsedEntityURIs(theManager),
+	m_nonPooledStrings(theManager, eDefaultValuesStringPoolBlockSize),
+	m_stringBuffer(theManager)
 {
 }
 
@@ -890,6 +924,7 @@ XalanSourceTreeDocument::createElementNode(
 
 inline const XalanDOMString&
 getElementNodePrefix(
+            MemoryManagerType&          theManager,
 			const XalanDOMChar*			qname,
 			XalanDOMStringPool*			theStringPool,
 			XalanDOMString::size_type	theLength,			
@@ -897,7 +932,7 @@ getElementNodePrefix(
 {
 	if(theColonIndex == theLength)
 	{
-		return theStringPool->get(XalanDOMString()); 
+		return theStringPool->get(XalanDOMString( theManager)); 
 	}
 	else
 	{
@@ -951,7 +986,7 @@ XalanSourceTreeDocument::createElementNode(
 				m_namesStringPool.get(localname),
 				m_namesStringPool.get(uri),
 				// This is the prefix...
-				getElementNodePrefix(qname, &m_namesStringPool, theLength, theColonIndex),
+				getElementNodePrefix( getMemoryManager() , qname, &m_namesStringPool, theLength, theColonIndex),
 				this,
 				theParentNode,
 				thePreviousSibling,
@@ -967,7 +1002,7 @@ XalanSourceTreeDocument::createElementNode(
 				m_namesStringPool.get(localname),
 				m_namesStringPool.get(uri),
 				// This is the prefix...
-				getElementNodePrefix(qname, &m_namesStringPool, theLength, theColonIndex),
+				getElementNodePrefix( getMemoryManager() ,qname, &m_namesStringPool, theLength, theColonIndex),
 				this,
 				theAttributeVector,
 				theAttributeCount,
@@ -1101,16 +1136,11 @@ XalanSourceTreeDocument::getTextNodeString(
 	}
 	else
 	{
-		const StringCollectionType::iterator	theIterator =
-				m_nonPooledStrings.insert(m_nonPooledStrings.end(), XalanDOMString());
+		XalanDOMString* const   theString =
+				m_nonPooledStrings.create(chars, length);
+        assert(theString != 0);
 
-		XalanDOMString&		theString = *theIterator;
-
-		assign(theString, chars, length);
-
-		assert(length == theString.length());
-
-		return theString;
+		return *theString;
 	}
 }
 
@@ -1223,7 +1253,7 @@ XalanSourceTreeDocument::unparsedEntityDeclaration(
 			const XalanDOMChar*		systemId,
 			const XalanDOMChar*		/* notationName */)
 {
-	m_unparsedEntityURIs[XalanDOMString(name)] = XalanDOMString(systemId);
+	m_unparsedEntityURIs[XalanDOMString(name, getMemoryManager())] = XalanDOMString(systemId, getMemoryManager());
 }
 
 
@@ -1591,7 +1621,7 @@ XalanSourceTreeDocument::appendChildNode(XalanSourceTreeProcessingInstruction*	t
 
 
 
-static XalanDOMString	s_staticNameString;
+static XalanDOMString	s_staticNameString(XalanMemMgrs::getDummyMemMgr());
 
 
 
@@ -1616,9 +1646,11 @@ static const XalanDOMChar	s_document[] =
 
 
 void
-XalanSourceTreeDocument::initialize()
+XalanSourceTreeDocument::initialize(MemoryManagerType& theManager)
 {
-	s_staticNameString = s_document;
+    XalanDOMString tmpString(s_document, theManager);
+
+	s_staticNameString.swap(tmpString);
 }
 
 
@@ -1626,7 +1658,7 @@ XalanSourceTreeDocument::initialize()
 void
 XalanSourceTreeDocument::terminate()
 {
-	releaseMemory(s_staticNameString);
+	releaseMemory(s_staticNameString, XalanMemMgrs::getDummyMemMgr());
 }
 
 
