@@ -453,19 +453,22 @@ const XalanDOMChar	XalanSourceTreeParserLiaison::s_externalNoNamespaceSchemaLoca
 
 
 XalanSourceTreeParserLiaison::XalanSourceTreeParserLiaison(
-			XalanSourceTreeDOMSupport&	/* theSupport */) :
-	m_xercesParserLiaison(),
-	m_documentMap(),
-	m_poolAllText(true)
+			XalanSourceTreeDOMSupport&	/* theSupport */,
+            MemoryManagerType&          theManager) :
+	m_xercesParserLiaison(theManager),
+	m_documentMap(theManager),
+	m_poolAllText(true),
+	m_xmlReader(0)
 {
 }
 
 
 
-XalanSourceTreeParserLiaison::XalanSourceTreeParserLiaison() :
-	m_xercesParserLiaison(),
-	m_documentMap(),
-	m_poolAllText(true)
+XalanSourceTreeParserLiaison::XalanSourceTreeParserLiaison(MemoryManagerType&   theManager) :
+	m_xercesParserLiaison(theManager),
+	m_documentMap(theManager),
+	m_poolAllText(true),
+	m_xmlReader(0)
 {
 }
 
@@ -474,6 +477,8 @@ XalanSourceTreeParserLiaison::XalanSourceTreeParserLiaison() :
 XalanSourceTreeParserLiaison::~XalanSourceTreeParserLiaison()
 {
 	reset();
+
+	delete m_xmlReader;
 }
 
 
@@ -483,13 +488,23 @@ XalanSourceTreeParserLiaison::reset()
 {
 	XALAN_USING_STD(for_each)
 
-	// Delete any documents.
-	for_each(
-			m_documentMap.begin(),
-			m_documentMap.end(),
-			makeMapValueDeleteFunctor(m_documentMap));
+    typedef XalanSourceTreeParserLiaison::DocumentMapType::iterator Iterator;
 
-	m_documentMap.clear();
+    MemoryManagerType& theManager = getMemoryManager();
+
+    for ( Iterator i = m_documentMap.begin(); i != m_documentMap.end(); ++i)
+    {
+        assert( (*i).second != 0);
+
+        (*i).second->~XalanSourceTreeDocument();
+
+        theManager.deallocate((*i).second);
+
+        (*i).second = 0;
+
+    }
+
+    m_documentMap.clear();
 
 	m_xercesParserLiaison.reset();
 }
@@ -523,22 +538,98 @@ XalanSourceTreeParserLiaison::parseXMLStream(
 
 
 
+void
+XalanSourceTreeParserLiaison::ensureReader()
+{
+	if (m_xmlReader == 0)
+	{
+		m_xmlReader = createReader();
+	}
+
+	const bool	fValidate = m_xercesParserLiaison.getUseValidation();
+
+	if (fValidate == false)
+	{
+		m_xmlReader->setFeature(
+			s_validationString,
+			false);
+
+		m_xmlReader->setFeature(
+			s_schemaString,
+			false);
+	}
+	else
+	{
+		m_xmlReader->setFeature(
+			s_dynamicValidationString,
+			true);
+
+		m_xmlReader->setFeature(
+			s_schemaString,
+			true);
+	}
+
+	ErrorHandlerType* const		theHandler = getErrorHandler();
+
+	if (theHandler == 0)
+	{
+		m_xmlReader->setErrorHandler(&m_xercesParserLiaison);
+	}
+	else
+	{
+		m_xmlReader->setErrorHandler(theHandler);
+	}
+
+	m_xmlReader->setEntityResolver(getEntityResolver());
+
+	{
+		const XalanDOMChar* const	theLocation =
+			getExternalSchemaLocation();
+
+		if (theLocation != 0)
+		{
+			m_xmlReader->setProperty(
+				s_externalSchemaLocationString,
+#if defined(XALAN_OLD_STYLE_CASTS)
+				(void*)theLocation);
+#else
+				const_cast<XalanDOMChar*>(theLocation));
+#endif
+		}
+	}
+
+	{
+		const XalanDOMChar* const	theLocation =
+			getExternalNoNamespaceSchemaLocation();
+
+		if (theLocation != 0)
+		{
+			m_xmlReader->setProperty(
+				s_externalNoNamespaceSchemaLocationString,
+#if defined(XALAN_OLD_STYLE_CASTS)
+				(void*)theLocation);
+#else
+				const_cast<XalanDOMChar*>(theLocation));
+#endif
+		}
+	}
+}
+
+
+
 XalanDocument*
 XalanSourceTreeParserLiaison::parseXMLStream(
 			const InputSourceType&	inputSource,
-			const XalanDOMString&	/* identifier */)
+			const XalanDOMString&	identifier)
 {
-	XalanSourceTreeContentHandler	theContentHandler(createXalanSourceTreeDocument());
+	XalanSourceTreeContentHandler	theContentHandler( getMemoryManager(), createXalanSourceTreeDocument());
 
-	XalanAutoPtr<SAX2XMLReaderType>	theReader(createReader());
-
-	theReader->setContentHandler(&theContentHandler);
-
-	theReader->setDTDHandler(&theContentHandler);
-
-	theReader->setLexicalHandler(&theContentHandler);
-
-	theReader->parse(inputSource);
+	parseXMLStream(
+		inputSource,
+		theContentHandler,
+		identifier,
+		&theContentHandler,
+		&theContentHandler);
 
 	return theContentHandler.getDocument();
 }
@@ -552,7 +643,16 @@ XalanSourceTreeParserLiaison::destroyDocument(XalanDocument*	theDocument)
 	{
 		m_documentMap.erase(theDocument);
 
-		delete theDocument;
+        if( theDocument!= 0 )
+        {
+            theDocument->~XalanDocument();
+            
+            MemoryManagerType& theManager = m_documentMap.getMemoryManager();
+
+            theManager.deallocate(theDocument);
+
+        }
+		
 	}
 	else
 	{
@@ -594,10 +694,12 @@ XalanSourceTreeParserLiaison::setUseValidation(bool		b)
 
 
 
-const XalanDOMString
-XalanSourceTreeParserLiaison::getParserDescription() const
+const XalanDOMString&
+XalanSourceTreeParserLiaison::getParserDescription(XalanDOMString& theResult) const
 {
-	return StaticStringToDOMString(XALAN_STATIC_UCODE_STRING("XalanSourceTree"));
+    theResult.assign("XalanSourceTree");
+    
+    return theResult;
 }
 
 
@@ -606,19 +708,21 @@ void
 XalanSourceTreeParserLiaison::parseXMLStream(
 			const InputSourceType&	theInputSource,
 			ContentHandlerType&		theContentHandler,
+            const XalanDOMString&	/* theIdentifier */,
 			DTDHandlerType*			theDTDHandler,
-			LexicalHandlerType*		theLexicalHandler,
-			const XalanDOMString&	/* theIdentifier */)
+			LexicalHandlerType*		theLexicalHandler)
 {
-	XalanAutoPtr<SAX2XMLReaderType>		theReader(createReader());
+	ensureReader();
 
-	theReader->setContentHandler(&theContentHandler);
+	assert(m_xmlReader != 0);
 
-	theReader->setDTDHandler(theDTDHandler);
+	m_xmlReader->setContentHandler(&theContentHandler);
 
-	theReader->setLexicalHandler(theLexicalHandler);
+	m_xmlReader->setDTDHandler(theDTDHandler);
 
-	theReader->parse(theInputSource);
+	m_xmlReader->setLexicalHandler(theLexicalHandler);
+
+	m_xmlReader->parse(theInputSource);
 }
 
 
@@ -766,7 +870,7 @@ XalanSourceTreeDocument*
 XalanSourceTreeParserLiaison::createXalanSourceTreeDocument()
 {
 	XalanSourceTreeDocument* const	theNewDocument =
-		new XalanSourceTreeDocument(m_poolAllText);
+        XalanSourceTreeDocument::create( getMemoryManager(), m_poolAllText);
 
 	m_documentMap[theNewDocument] = theNewDocument;
 
@@ -778,30 +882,7 @@ XalanSourceTreeParserLiaison::createXalanSourceTreeDocument()
 SAX2XMLReaderType*
 XalanSourceTreeParserLiaison::createReader()
 {
-	XalanAutoPtr<SAX2XMLReaderType>		theReader(XERCES_CPP_NAMESPACE_QUALIFIER XMLReaderFactory::createXMLReader());
-
-	const bool	fValidate = m_xercesParserLiaison.getUseValidation();
-
-	if (fValidate == false)
-	{
-		theReader->setFeature(
-			s_validationString,
-			false);
-
-		theReader->setFeature(
-			s_schemaString,
-			false);
-	}
-	else
-	{
-		theReader->setFeature(
-			s_dynamicValidationString,
-			true);
-
-		theReader->setFeature(
-			s_schemaString,
-			true);
-	}
+	XalanAutoPtr<SAX2XMLReaderType>		theReader(XERCES_CPP_NAMESPACE_QUALIFIER XMLReaderFactory::createXMLReader( &(getMemoryManager())));
 
 	theReader->setFeature(
 		s_namespacesString,
@@ -811,51 +892,6 @@ XalanSourceTreeParserLiaison::createReader()
 		s_namespacePrefixesString,
 		true);
 
-	ErrorHandlerType* const		theHandler = getErrorHandler();
-
-	if (theHandler == 0)
-	{
-		theReader->setErrorHandler(&m_xercesParserLiaison);
-	}
-	else
-	{
-		theReader->setErrorHandler(theHandler);
-	}
-
-	theReader->setEntityResolver(getEntityResolver());
-
-	{
-		const XalanDOMChar* const	theLocation =
-			getExternalSchemaLocation();
-
-		if (theLocation != 0)
-		{
-			theReader->setProperty(
-				s_externalSchemaLocationString,
-#if defined(XALAN_OLD_STYLE_CASTS)
-				(void*)theLocation);
-#else
-				const_cast<XalanDOMChar*>(theLocation));
-#endif
-		}
-	}
-
-	{
-		const XalanDOMChar* const	theLocation =
-			getExternalNoNamespaceSchemaLocation();
-
-		if (theLocation != 0)
-		{
-			theReader->setProperty(
-				s_externalNoNamespaceSchemaLocationString,
-#if defined(XALAN_OLD_STYLE_CASTS)
-				(void*)theLocation);
-#else
-				const_cast<XalanDOMChar*>(theLocation));
-#endif
-		}
-	}
-
 	return theReader.release();
 }
 
