@@ -23,8 +23,8 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 
-XercesAttrWrapperAllocator::XercesAttrWrapperAllocator(size_type	theBlockCount) :
-	m_allocator(theBlockCount)
+XercesAttrWrapperAllocator::XercesAttrWrapperAllocator(MemoryManagerType&  theManager, size_type	theBlockCount) :
+	m_allocator(theManager, theBlockCount)
 {
 }
 
