@@ -21,6 +21,8 @@
 #include <xalanc/XercesParserLiaison/XercesParserLiaisonDefinitions.hpp>
 
 
+#include <xalanc/Include/XalanMemMgrAutoPtr.hpp>
+
 
 #include <xalanc/XalanDOM/XalanCDATASection.hpp>
 
@@ -46,6 +48,11 @@ public:
 			const DOMCDATASectionType*		theXercesCDATASection,
 			const XercesWrapperNavigator&	theNavigator);
 
+    static XercesCDATASectionWrapper*
+    create( MemoryManagerType& theManager,
+			const DOMCDATASectionType*		theXercesCDATASection,
+			const XercesWrapperNavigator&	theNavigator);
+
 	virtual
 	~XercesCDATASectionWrapper();
 
@@ -441,10 +448,11 @@ public:
 	 *	 <br>DOMSTRING_SIZE_ERR: Raised if the specified range of text does not 
 	 *	 fit into a <code>DOMString</code>.
 	 */
-	virtual XalanDOMString
+	virtual XalanDOMString&
 	substringData(
 			unsigned int	offset, 
-			unsigned int	count) const;
+			unsigned int	count,
+            XalanDOMString& theResult) const;
 
 	//@}
 	/** @name Functions that set or change data. */
