@@ -73,6 +73,7 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 XercesDocumentWrapper::XercesDocumentWrapper(
+            MemoryManagerType&          theManager,
 			const DOMDocument_Type*		theXercesDocument,
 			bool						threadSafe,
 			bool						buildWrapper,
@@ -80,24 +81,26 @@ XercesDocumentWrapper::XercesDocumentWrapper(
 	XalanDocument(),
 	m_xercesDocument(theXercesDocument),
 	m_documentElement(0),
-	m_nodeMap(),
-	m_domImplementation(new XercesDOMImplementationWrapper(theXercesDocument->getImplementation())),
-	m_navigators(1, XercesWrapperNavigator(this)),
-	m_navigator(&m_navigators.front()),
+	m_nodeMap(theManager),
+    m_domImplementation(theManager, XercesDOMImplementationWrapper::create(theManager, theXercesDocument->getImplementation())),
+	m_navigatorAllocator(theManager, 25),
+	m_navigator(0),
 	m_children(theXercesDocument->getChildNodes(),
 			   *m_navigator),
-	m_nodes(),
+	m_nodes(theManager),
 	m_doctype(0),
 	m_mappingMode(threadSafe == true ? false : !buildWrapper),
 	m_indexValid(false),
 	m_buildMaps(m_mappingMode == true ? true : buildMaps),
-	m_elementAllocator(25),
-	m_textAllocator(25),
-	m_attributeAllocator(25),
-	m_stringPool(threadSafe == true ? new XercesLiaisonXalanDOMStringPool : new XalanDOMStringPool)
+	m_elementAllocator(theManager, 25),
+	m_textAllocator(theManager, 25),
+	m_attributeAllocator(theManager, 25),
+    m_stringPool(theManager, threadSafe == true ? XercesLiaisonXalanDOMStringPool::create(theManager) : XalanDOMStringPool::create(theManager))
 {
 	assert(theXercesDocument != 0);
 
+    m_navigator = m_navigatorAllocator.create(this);
+
 	if (m_mappingMode == false)
 	{
 		// The document index is always 1...
@@ -113,7 +116,30 @@ XercesDocumentWrapper::XercesDocumentWrapper(
 	}
 }
 
+XercesDocumentWrapper*
+XercesDocumentWrapper::create( 
+            MemoryManagerType&          theManager,
+			const DOMDocument_Type*		theXercesDocument,
+			bool						threadSafe,
+			bool						buildWrapper,
+ 			bool						buildMaps)
+{
+    typedef XercesDocumentWrapper ThisType;
 
+    XalanMemMgrAutoPtr<ThisType, false> theGuard( theManager , (ThisType*)theManager.allocate(sizeof(ThisType)));
+
+    ThisType* theResult = theGuard.get();
+
+    new (theResult) ThisType(theManager,
+                            theXercesDocument,
+                            threadSafe,
+                            buildWrapper,
+                            buildMaps);
+        
+    theGuard.release();
+
+    return theResult;
+}
 
 XercesDocumentWrapper::~XercesDocumentWrapper()
 {
@@ -315,15 +341,15 @@ XercesDocumentWrapper::destroyWrapper()
 	for_each(
 			m_nodes.begin(),
 			m_nodes.end(),
-			DeleteFunctor<XalanNode>());
+            DeleteFunctor<XalanNode>(m_nodes.getMemoryManager()));
 
 	// Clear everything out, since we just delete everything...
 	m_nodes.clear();
 
 	// Clear out all of the navigators, except ours...
-	m_navigators.erase(m_navigators.begin() + 1, m_navigators.end());
+	m_navigatorAllocator.reset();
 
-	m_navigator = &m_navigators.front();
+	m_navigator = m_navigatorAllocator.create(this);
 
 	// Clear the node map...
 	m_nodeMap.clear();
@@ -348,7 +374,7 @@ XercesDocumentWrapper::rebuildWrapper()
 
 
 XercesWrapperNavigator&
-XercesDocumentWrapper::pushNavigator() const
+XercesDocumentWrapper::createNavigator() const
 {
 	XercesDocumentWrapper* const		This =
 #if defined(XALAN_OLD_STYLE_CASTS)
@@ -357,9 +383,7 @@ XercesDocumentWrapper::pushNavigator() const
 		const_cast<XercesDocumentWrapper*>(this);
 #endif
 
-	This->m_navigators.push_back(XercesWrapperNavigator(This));
-
-	return This->m_navigators.back();
+	return *This->m_navigatorAllocator.create(This);
 }
 
 
@@ -368,7 +392,8 @@ XercesDocumentTypeWrapper*
 XercesDocumentWrapper::createWrapperNode(
 			const DOMDocumentType_Type*		theDoctype,
 			IndexType						theIndex,
-			bool							mapNode) const
+			bool							mapNode,
+            XercesWrapperNavigator**        theWrapperNodeNavigator) const
 {
 	// This is a special case, since there is only one
 	// doctype node allowed...
@@ -377,7 +402,7 @@ XercesDocumentWrapper::createWrapperNode(
 		   m_xercesDocument->getDoctype() == theDoctype);
 
 	// Create a navigator...
-	XercesWrapperNavigator&	theNavigator = pushNavigator();
+	XercesWrapperNavigator&	theNavigator = createNavigator();
 
 	theNavigator.setIndex(theIndex);
 
@@ -390,7 +415,7 @@ XercesDocumentWrapper::createWrapperNode(
 #endif
 
 	// Update the member variable for the new instance.
-	This->m_doctype = new XercesDocumentTypeWrapper(theDoctype, theNavigator);
+    This->m_doctype =  XercesDocumentTypeWrapper::create( getMemoryManager(), theDoctype, theNavigator);
 
 	if (mapNode == true)
 	{
@@ -399,6 +424,11 @@ XercesDocumentWrapper::createWrapperNode(
 
 	This->m_nodes.push_back(m_doctype);
 
+    if (theWrapperNodeNavigator != 0)
+    {
+        *theWrapperNodeNavigator = &theNavigator;
+    }
+
 	return m_doctype;
 }
 
@@ -406,12 +436,13 @@ XercesDocumentWrapper::createWrapperNode(
 
 XercesElementWrapper*
 XercesDocumentWrapper::createWrapperNode(
-			const DOMElementType* 	theXercesNode,
-			IndexType				theIndex,
-			bool					mapNode) const
+			const DOMElementType* 	    theXercesNode,
+			IndexType				    theIndex,
+			bool					    mapNode,
+            XercesWrapperNavigator**    theWrapperNodeNavigator) const
 {
 	// Create a navigator...
-	XercesWrapperNavigator&	theNavigator = pushNavigator();
+	XercesWrapperNavigator&	theNavigator = createNavigator();
 
 	theNavigator.setIndex(theIndex);
 
@@ -434,6 +465,11 @@ XercesDocumentWrapper::createWrapperNode(
 		This->m_nodeMap.addAssociation(theXercesNode, theWrapper);
 	}
 
+    if (theWrapperNodeNavigator != 0)
+    {
+        *theWrapperNodeNavigator = &theNavigator;
+    }
+
 	return theWrapper;
 }
 
@@ -441,12 +477,13 @@ XercesDocumentWrapper::createWrapperNode(
 
 XercesTextWrapper*
 XercesDocumentWrapper::createWrapperNode(
-			const DOMTextType*	theXercesNode,
-			IndexType			theIndex,
-			bool				mapNode) const
+			const DOMTextType*	        theXercesNode,
+			IndexType			        theIndex,
+			bool				        mapNode,
+            XercesWrapperNavigator**    theWrapperNodeNavigator) const
 {
 	// Create a navigator...
-	XercesWrapperNavigator&	theNavigator = pushNavigator();
+	XercesWrapperNavigator&	theNavigator = createNavigator();
 
 	theNavigator.setIndex(theIndex);
 
@@ -468,6 +505,11 @@ XercesDocumentWrapper::createWrapperNode(
 		This->m_nodeMap.addAssociation(theXercesNode, theWrapper);
 	}
 
+    if (theWrapperNodeNavigator != 0)
+    {
+        *theWrapperNodeNavigator = &theNavigator;
+    }
+
 	return theWrapper;
 }
 
@@ -475,17 +517,20 @@ XercesDocumentWrapper::createWrapperNode(
 
 XercesCommentWrapper*
 XercesDocumentWrapper::createWrapperNode(
-			const DOMCommentType*	theXercesNode,
-			IndexType				theIndex,
-			bool					mapNode) const
+			const DOMCommentType*	    theXercesNode,
+ 			IndexType				    theIndex,
+			bool					    mapNode,
+            XercesWrapperNavigator**    theWrapperNodeNavigator) const
 {
 	// Create a navigator...
-	XercesWrapperNavigator&	theNavigator = pushNavigator();
+	XercesWrapperNavigator&	theNavigator = createNavigator();
 
 	theNavigator.setIndex(theIndex);
 
 	XercesCommentWrapper* const	theWrapper =
-		new XercesCommentWrapper(theXercesNode,
+        XercesCommentWrapper::create(
+                                getMemoryManager(),
+                                theXercesNode,
 								theNavigator);
 
 #if defined(XALAN_NO_MUTABLE)
@@ -504,6 +549,11 @@ XercesDocumentWrapper::createWrapperNode(
 		This->m_nodeMap.addAssociation(theXercesNode, theWrapper);
 	}
 
+    if (theWrapperNodeNavigator != 0)
+    {
+        *theWrapperNodeNavigator = &theNavigator;
+    }
+
 	return theWrapper;
 }
 
@@ -513,15 +563,18 @@ XercesCDATASectionWrapper*
 XercesDocumentWrapper::createWrapperNode(
 			const DOMCDATASectionType*	theXercesNode,
 			IndexType					theIndex,
-			bool						mapNode) const
+			bool						mapNode,
+            XercesWrapperNavigator**    theWrapperNodeNavigator) const
 {
 	// Create a navigator...
-	XercesWrapperNavigator&	theNavigator = pushNavigator();
+	XercesWrapperNavigator&	theNavigator = createNavigator();
 
 	theNavigator.setIndex(theIndex);
 
 	XercesCDATASectionWrapper* const		theWrapper =
-		new XercesCDATASectionWrapper(theXercesNode,
+        XercesCDATASectionWrapper::create(
+                                     getMemoryManager(),
+                                     theXercesNode,
 									 theNavigator);
 
 #if defined(XALAN_NO_MUTABLE)
@@ -540,6 +593,11 @@ XercesDocumentWrapper::createWrapperNode(
 		This->m_nodeMap.addAssociation(theXercesNode, theWrapper);
 	}
 
+    if (theWrapperNodeNavigator != 0)
+    {
+        *theWrapperNodeNavigator = &theNavigator;
+    }
+
 	return theWrapper;
 }
 
@@ -549,15 +607,18 @@ XercesProcessingInstructionWrapper*
 XercesDocumentWrapper::createWrapperNode(
 			const DOMProcessingInstructionType*		theXercesNode,
 			IndexType								theIndex,
-			bool									mapNode) const
+			bool									mapNode,
+            XercesWrapperNavigator**                theWrapperNodeNavigator) const
 {
 	// Create a navigator...
-	XercesWrapperNavigator&	theNavigator = pushNavigator();
+	XercesWrapperNavigator&	theNavigator = createNavigator();
 
 	theNavigator.setIndex(theIndex);
 
 	XercesProcessingInstructionWrapper* const	theWrapper =
-		new XercesProcessingInstructionWrapper(theXercesNode,
+        XercesProcessingInstructionWrapper::create(
+                                              getMemoryManager(),
+                                              theXercesNode,
 											  theNavigator);
 
 #if defined(XALAN_NO_MUTABLE)
@@ -576,6 +637,11 @@ XercesDocumentWrapper::createWrapperNode(
 		This->m_nodeMap.addAssociation(theXercesNode, theWrapper);
 	}
 
+    if (theWrapperNodeNavigator != 0)
+    {
+        *theWrapperNodeNavigator = &theNavigator;
+    }
+
 	return theWrapper;
 }
 
@@ -583,12 +649,13 @@ XercesDocumentWrapper::createWrapperNode(
 
 XercesAttrWrapper*
 XercesDocumentWrapper::createWrapperNode(
-			const DOMAttrType*	theXercesNode,
-			IndexType			theIndex,
-			bool				/* mapNode */) const
+			const DOMAttrType*	        theXercesNode,
+			IndexType			        theIndex,
+			bool				        /* mapNode */,
+            XercesWrapperNavigator**    theWrapperNodeNavigator) const
 {
 	// Create a navigator...
-	XercesWrapperNavigator&	theNavigator = pushNavigator();
+	XercesWrapperNavigator&	theNavigator = createNavigator();
 
 	theNavigator.setIndex(theIndex);
 
@@ -608,6 +675,11 @@ XercesDocumentWrapper::createWrapperNode(
 	// for now...
 	This->m_nodeMap.addAssociation(theXercesNode, theWrapper);
 
+    if (theWrapperNodeNavigator != 0)
+    {
+        *theWrapperNodeNavigator = &theNavigator;
+    }
+
 	return theWrapper;
 }
 
@@ -615,17 +687,20 @@ XercesDocumentWrapper::createWrapperNode(
 
 XercesEntityWrapper*
 XercesDocumentWrapper::createWrapperNode(
-			const DOMEntityType*	theXercesNode,
-			IndexType				theIndex,
-			bool					/* mapNode */) const
+			const DOMEntityType*	    theXercesNode,
+			IndexType				    theIndex,
+			bool					    /* mapNode */,
+            XercesWrapperNavigator**    theWrapperNodeNavigator) const
 {
 	// Create a navigator...
-	XercesWrapperNavigator&	theNavigator = pushNavigator();
+	XercesWrapperNavigator&	theNavigator = createNavigator();
 
 	theNavigator.setIndex(theIndex);
 
 	XercesEntityWrapper* const	theWrapper =
-		new XercesEntityWrapper(theXercesNode,
+        XercesEntityWrapper::create(
+                               getMemoryManager(),
+                               theXercesNode,
 							   theNavigator);
 
 #if defined(XALAN_NO_MUTABLE)
@@ -642,6 +717,11 @@ XercesDocumentWrapper::createWrapperNode(
 	// for now...
 	This->m_nodeMap.addAssociation(theXercesNode, theWrapper);
 
+    if (theWrapperNodeNavigator != 0)
+    {
+        *theWrapperNodeNavigator = &theNavigator;
+    }
+
 	return theWrapper;
 }
 
@@ -651,15 +731,18 @@ XercesEntityReferenceWrapper*
 XercesDocumentWrapper::createWrapperNode(
 			const DOMEntityReferenceType* 	theXercesNode,
 			IndexType						theIndex,
-			bool							mapNode) const
+			bool							mapNode,
+            XercesWrapperNavigator**        theWrapperNodeNavigator) const
 {
 	// Create a navigator...
-	XercesWrapperNavigator&	theNavigator = pushNavigator();
+	XercesWrapperNavigator&	theNavigator = createNavigator();
 
 	theNavigator.setIndex(theIndex);
 
 	XercesEntityReferenceWrapper* const	theWrapper =
-		new XercesEntityReferenceWrapper(theXercesNode,
+        XercesEntityReferenceWrapper::create(
+                                        getMemoryManager(),
+                                        theXercesNode,
 										theNavigator);
 
 #if defined(XALAN_NO_MUTABLE)
@@ -678,6 +761,11 @@ XercesDocumentWrapper::createWrapperNode(
 		This->m_nodeMap.addAssociation(theXercesNode, theWrapper);
 	}
 
+    if (theWrapperNodeNavigator != 0)
+    {
+        *theWrapperNodeNavigator = &theNavigator;
+    }
+
 	return theWrapper;
 }
 
@@ -685,17 +773,20 @@ XercesDocumentWrapper::createWrapperNode(
 
 XercesNotationWrapper*
 XercesDocumentWrapper::createWrapperNode(
-			const DOMNotationType*	theXercesNode,
-			IndexType				theIndex,
-			bool					/* mapNode */) const
+			const DOMNotationType*	    theXercesNode,
+			IndexType				    theIndex,
+			bool					    /* mapNode */,
+            XercesWrapperNavigator**    theWrapperNodeNavigator) const
 {
 	// Create a navigator...
-	XercesWrapperNavigator&	theNavigator = pushNavigator();
+	XercesWrapperNavigator&	theNavigator = createNavigator();
 
 	theNavigator.setIndex(theIndex);
 
 	XercesNotationWrapper* const		theWrapper =
-		new XercesNotationWrapper(theXercesNode,
+        XercesNotationWrapper::create(
+                                 getMemoryManager(),
+                                 theXercesNode,
 								 theNavigator);
 
 #if defined(XALAN_NO_MUTABLE)
@@ -712,6 +803,11 @@ XercesDocumentWrapper::createWrapperNode(
 	// for now...
 	This->m_nodeMap.addAssociation(theXercesNode, theWrapper);
 
+    if (theWrapperNodeNavigator != 0)
+    {
+        *theWrapperNodeNavigator = &theNavigator;
+    }
+
 	return theWrapper;
 }
 
@@ -719,9 +815,10 @@ XercesDocumentWrapper::createWrapperNode(
 
 XalanNode*
 XercesDocumentWrapper::createWrapperNode(
-			const DOMNodeType*	theXercesNode,
-			IndexType			theIndex,
-			bool				mapNode) const
+			const DOMNodeType*	        theXercesNode,
+			IndexType			        theIndex,
+			bool				        mapNode,
+            XercesWrapperNavigator**    theWrapperNodeNavigator) const
 {
 	assert(theXercesNode != 0);
 
@@ -738,7 +835,7 @@ XercesDocumentWrapper::createWrapperNode(
 						static_cast<const DOMAttrType*>(theXercesNode);
 #endif
 
-			theNewNode = createWrapperNode(theAttrNode, theIndex, mapNode);
+			theNewNode = createWrapperNode(theAttrNode, theIndex, mapNode, theWrapperNodeNavigator);
 			assert(theNewNode != 0);
 		}
 		break;
@@ -752,7 +849,7 @@ XercesDocumentWrapper::createWrapperNode(
 						static_cast<const DOMCDATASectionType*>(theXercesNode);
 #endif
 
-			theNewNode = createWrapperNode(theCDATASectionNode, theIndex, mapNode);
+			theNewNode = createWrapperNode(theCDATASectionNode, theIndex, mapNode, theWrapperNodeNavigator);
 			assert(theNewNode != 0);
 
 		}
@@ -767,7 +864,7 @@ XercesDocumentWrapper::createWrapperNode(
 						static_cast<const DOMCommentType*>(theXercesNode);
 #endif
 
-			theNewNode = createWrapperNode(theCommentNode, theIndex, mapNode);
+			theNewNode = createWrapperNode(theCommentNode, theIndex, mapNode, theWrapperNodeNavigator);
 			assert(theNewNode != 0);
 		}
 		break;
@@ -785,7 +882,7 @@ XercesDocumentWrapper::createWrapperNode(
 						static_cast<const DOMElementType*>(theXercesNode);
 #endif
 
-			theNewNode = createWrapperNode(theElementNode, theIndex, mapNode);
+			theNewNode = createWrapperNode(theElementNode, theIndex, mapNode, theWrapperNodeNavigator);
 			assert(theNewNode != 0);
 		}
 		break;
@@ -799,7 +896,7 @@ XercesDocumentWrapper::createWrapperNode(
 						static_cast<const DOMEntityType*>(theXercesNode);
 #endif
 
-			theNewNode = createWrapperNode(theEntityNode, theIndex, mapNode);
+			theNewNode = createWrapperNode(theEntityNode, theIndex, mapNode, theWrapperNodeNavigator);
 			assert(theNewNode != 0);
 		}
 		break;
@@ -813,7 +910,7 @@ XercesDocumentWrapper::createWrapperNode(
 						static_cast<const DOMEntityReferenceType*>(theXercesNode);
 #endif
 
-			theNewNode = createWrapperNode(theEntityReferenceNode, theIndex, mapNode);
+			theNewNode = createWrapperNode(theEntityReferenceNode, theIndex, mapNode, theWrapperNodeNavigator);
 			assert(theNewNode != 0);
 		}
 		break;
@@ -827,7 +924,7 @@ XercesDocumentWrapper::createWrapperNode(
 						static_cast<const DOMNotationType*>(theXercesNode);
 #endif
 
-			theNewNode = createWrapperNode(theNotationNode, theIndex, mapNode);
+			theNewNode = createWrapperNode(theNotationNode, theIndex, mapNode, theWrapperNodeNavigator);
 			assert(theNewNode != 0);
 		}
 		break;
@@ -841,7 +938,7 @@ XercesDocumentWrapper::createWrapperNode(
 						static_cast<const DOMProcessingInstructionType*>(theXercesNode);
 #endif
 
-			theNewNode = createWrapperNode(thePINode, theIndex, mapNode);
+			theNewNode = createWrapperNode(thePINode, theIndex, mapNode, theWrapperNodeNavigator);
 			assert(theNewNode != 0);
 		}
 		break;
@@ -855,7 +952,7 @@ XercesDocumentWrapper::createWrapperNode(
 						static_cast<const DOMTextType*>(theXercesNode);
 #endif
 
-			theNewNode = createWrapperNode(theTextNode, theIndex, mapNode);
+			theNewNode = createWrapperNode(theTextNode, theIndex, mapNode, theWrapperNodeNavigator);
 			assert(theNewNode != 0);
 		}
 		break;
@@ -869,7 +966,7 @@ XercesDocumentWrapper::createWrapperNode(
 						static_cast<const DOMDocumentType_Type*>(theXercesNode);
 #endif
 
-			theNewNode = createWrapperNode(theDoctypeNode, theIndex, mapNode);
+			theNewNode = createWrapperNode(theDoctypeNode, theIndex, mapNode, theWrapperNodeNavigator);
 
 			assert(theNewNode != 0);
 		}
@@ -901,7 +998,17 @@ XercesDocumentWrapper::destroyNode(XalanNode*	theNode)
 	else
 	{
 		// Delete the node...
-		delete *i;
+        XalanNode* ptrToDelete = *i;
+
+        if ( ptrToDelete != 0 )
+        {
+            MemoryManagerType& theManager = m_nodes.getMemoryManager();
+
+            ptrToDelete->~XalanNode();
+
+            theManager.deallocate(ptrToDelete);
+
+        }
 
 		// Erase it from the map...
 		m_nodes.erase(i);
@@ -1358,15 +1465,13 @@ XercesDocumentWrapper::buildWrapperNodes()
 	if (theStartChild != 0)
 	{
 		assert(m_navigator != 0);
-		assert(m_navigators.size() == 1);
 
 		m_navigator->setIndex(1);
 		m_navigator->setFirstChild(0);
 
 		BuildWrapperTreeWalker	theTreeWalker(
 				this,
-				&m_navigators.back(),
-				m_navigators,
+				m_navigator,
 				2,
 				m_buildMaps);
 
@@ -1395,16 +1500,14 @@ XercesDocumentWrapper::buildWrapperNodes()
 
 
 XercesDocumentWrapper::BuildWrapperTreeWalker::BuildWrapperTreeWalker(
-			XercesDocumentWrapper*			theDocument,
-			XercesWrapperNavigator*			theDocumentNavigator,
-			WrapperNavigatorVectorType&		theNavigators,
-			IndexType						theStartIndex,
-			bool							theBuildMapsFlag) :
+			XercesDocumentWrapper*			    theDocument,
+			XercesWrapperNavigator*			    theDocumentNavigator,
+			IndexType						    theStartIndex,
+			bool							    theBuildMapsFlag) :
 	m_document(theDocument),
-	m_navigators(theNavigators),
 	m_currentIndex(theStartIndex),
-	m_parentNavigatorStack(),
-	m_siblingNavigatorStack(),
+	m_parentNavigatorStack(theDocument->getMemoryManager()),
+	m_siblingNavigatorStack(theDocument->getMemoryManager()),
 	m_buildMaps(theBuildMapsFlag)
 {
 	assert(theDocument != 0 && theDocumentNavigator != 0);
@@ -1431,10 +1534,15 @@ XercesDocumentWrapper::BuildWrapperTreeWalker::~BuildWrapperTreeWalker()
 bool
 XercesDocumentWrapper::BuildWrapperTreeWalker::startNode(const DOMNodeType*		node)
 {
-	XalanNode* const	theWrapperNode =
-		m_document->createWrapperNode(node, m_currentIndex, m_buildMaps);
+    XercesWrapperNavigator*     theWrapperNodeNavigator;
 
-	XercesWrapperNavigator&	theCurrentNodeNavigator = m_navigators.back();
+	XalanNode* const	theWrapperNode =
+		m_document->createWrapperNode(
+                node,
+                m_currentIndex,
+                m_buildMaps,
+                &theWrapperNodeNavigator);
+    assert(theWrapperNodeNavigator != 0);
 
 	assert(m_parentNavigatorStack.empty() == false);
 	assert(m_siblingNavigatorStack.empty() == false);
@@ -1443,7 +1551,7 @@ XercesDocumentWrapper::BuildWrapperTreeWalker::startNode(const DOMNodeType*		nod
 	NavigatorStackEntryType&	theParentEntry = m_parentNavigatorStack.back();
 	NavigatorStackEntryType&	theSiblingEntry = m_siblingNavigatorStack.back();
 
-	theCurrentNodeNavigator.setParentNode(theParentEntry.m_node);
+	theWrapperNodeNavigator->setParentNode(theParentEntry.m_node);
 
 	// If the first child has not been set, then set it
 	// now...
@@ -1457,7 +1565,7 @@ XercesDocumentWrapper::BuildWrapperTreeWalker::startNode(const DOMNodeType*		nod
 	// Always set the last child...
 	theParentEntry.m_navigator->setLastChild(theWrapperNode);
 
-	theCurrentNodeNavigator.setPreviousSibling(theSiblingEntry.m_node);
+	theWrapperNodeNavigator->setPreviousSibling(theSiblingEntry.m_node);
 
 	if (theSiblingEntry.m_navigator != 0)
 	{
@@ -1465,7 +1573,7 @@ XercesDocumentWrapper::BuildWrapperTreeWalker::startNode(const DOMNodeType*		nod
 	}
 
 	// Build an entry for the stacks...
-	const NavigatorStackEntryType	theCurrentEntry(&theCurrentNodeNavigator, theWrapperNode);
+	const NavigatorStackEntryType	theCurrentEntry(theWrapperNodeNavigator, theWrapperNode);
 
 	// My child nodes will now be visited, so push the current
 	// context on the parent stack...
@@ -1532,31 +1640,33 @@ XercesDocumentWrapper::BuildWrapperTreeWalker::startNode(const DOMNodeType*		nod
 			const DOMNodeType* const	theAttr = theAttributes->item(i);
 			assert(theAttr != 0);
 
+            XercesWrapperNavigator*     theCurrentAttrNavigator;
+
 			// Create a wrapper node.
 			XalanNode* const	theCurrentAttr =
-				m_document->createWrapperNode(theAttr, m_currentIndex, m_buildMaps);
-			assert(theCurrentAttr != 0);
-
-			// Get the attribute node's navigator...
-			XercesWrapperNavigator&	theCurrentAttrNavigator =
-				m_navigators.back();
+				m_document->createWrapperNode(
+                    theAttr,
+                    m_currentIndex,
+                    m_buildMaps,
+                    &theCurrentAttrNavigator);
+			assert(theCurrentAttr != 0 && theCurrentAttrNavigator != 0);
 
 			// Set the parent node...
-			theCurrentAttrNavigator.setParentNode(theWrapperNode);
+			theCurrentAttrNavigator->setParentNode(theWrapperNode);
 
 			if (thePreviousAttr != 0)
 			{
 				assert(thePreviousAttrNavigator != 0);
 
 				// Link in the previous attribute...
-				theCurrentAttrNavigator.setPreviousSibling(thePreviousAttr);
+				theCurrentAttrNavigator->setPreviousSibling(thePreviousAttr);
 
 				thePreviousAttrNavigator->setNextSibling(theCurrentAttr);
 			}
 
 			// Update the pointers so they point to this attribute...
 			thePreviousAttr = theCurrentAttr;
-			thePreviousAttrNavigator = &theCurrentAttrNavigator;
+			thePreviousAttrNavigator = theCurrentAttrNavigator;
 
 			// Finally, increment the index...
 			++m_currentIndex;
