@@ -23,8 +23,8 @@ XALAN_CPP_NAMESPACE_BEGIN
 
 
 
-XercesElementWrapperAllocator::XercesElementWrapperAllocator(size_type	theBlockCount) :
-	m_allocator(theBlockCount)
+XercesElementWrapperAllocator::XercesElementWrapperAllocator(MemoryManagerType&  theManager, size_type	theBlockCount) :
+	m_allocator(theManager, theBlockCount)
 {
 }
 
