@@ -23,7 +23,7 @@
 
 
 // Standard Library header files.
-#include <map>
+#include <xalanc/Include/XalanMap.hpp>
 
 
 
@@ -71,6 +71,7 @@ class XALAN_XERCESPARSERLIAISON_EXPORT XercesParserLiaison :
 	public XMLParserLiaison,
 	public ErrorHandlerType
 {
+    
 public:
 
 	typedef XERCES_CPP_NAMESPACE_QUALIFIER SAXParser			SAXParserType;
@@ -82,17 +83,24 @@ public:
 	 *
 	 * @deprecated This constructor is deprecated.  Use the next constructor instead.
 	 */
-	XercesParserLiaison(XercesDOMSupport&	theSupport);
+	XercesParserLiaison( XercesDOMSupport&	theSupport, MemoryManagerType& theManager XALAN_DEFAULT_MEMMGR);
 
 	/**
 	 * Construct a XercesParserLiaison instance.
 	 */
-	XercesParserLiaison();
+	XercesParserLiaison(MemoryManagerType& theManager XALAN_DEFAULT_MEMMGR);
 
 	virtual
 	~XercesParserLiaison();
 
+
+
 	// These interfaces are inherited from XMLParserLiaison...
+    MemoryManagerType&
+    getMemoryManager()
+    {
+        return m_externalSchemaLocation.getMemoryManager();
+    }
 
 	virtual void
 	reset();
@@ -106,13 +114,13 @@ public:
 	virtual XalanDocument*
 	parseXMLStream(
 			const InputSourceType&	reader,
-			const XalanDOMString&	identifier = XalanDOMString());
+			const XalanDOMString&	identifier = XalanDOMString(XalanMemMgrs::getDummyMemMgr()));
 
 	virtual void
 	parseXMLStream(
 			const InputSourceType&	urlInputSource,
 			DocumentHandlerType&	handler,
-			const XalanDOMString&	identifier = XalanDOMString());
+			const XalanDOMString&	identifier = XalanDOMString(XalanMemMgrs::getDummyMemMgr()));
 
 	virtual void
 	destroyDocument(XalanDocument*	theDocument);
@@ -129,8 +137,8 @@ public:
 	virtual void
 	setUseValidation(bool	b);
 
-	virtual const XalanDOMString
-	getParserDescription() const;
+	virtual const XalanDOMString&
+	getParserDescription(XalanDOMString& theResult) const;
 
 	virtual EntityResolverType*
 	getEntityResolver() const;
@@ -529,14 +537,7 @@ public:
 #endif
 	};
 
-#if defined(XALAN_NO_STD_NAMESPACE)
-	typedef map<const XalanDocument*,
-				DocumentEntry,
-				less<const XalanDocument*> >	DocumentMapType;
-#else
-	typedef std::map<const XalanDocument*,
-					 DocumentEntry> 			DocumentMapType;
-#endif
+	typedef XalanMap<const XalanDocument*, DocumentEntry>	DocumentMapType;
 
 	/**
 	 * This API is deprecated.
@@ -689,12 +690,6 @@ protected:
 			const SAXParseExceptionType&	e,
 			XalanDOMString& 				theMessage);
 
-	DOMParserType*
-	CreateDOMParser();
-
-	virtual SAXParserType*
-	CreateSAXParser();
-
 #if defined(XALAN_BUILD_DEPRECATED_DOM_BRIDGE)
 	/**
 	 * Create a XalanDocument proxy for an existing Xerces document.
@@ -732,6 +727,20 @@ protected:
 
 private:
 
+	void
+	ensureSAXParser();
+
+	void
+	ensureDOMParser();
+
+	DOMParserType*
+	createDOMParser();
+
+	SAXParserType*
+	createSAXParser();
+
+
+
 	// Data members...
 	int 				m_indent;
 
@@ -762,6 +771,10 @@ private:
 	bool				m_buildMaps;
 
 	ExecutionContext*	m_executionContext;
+
+	SAXParserType*		m_saxParser;
+
+	DOMParserType*		m_domParser;
 };
 
 
